<?xml version="1.0" encoding="UTF-8"?>
<!--
Licensed Materials - Property of IBM
5724-L01
(C) Copyright IBM Corporation 2005, 2010. All Rights Reserved.
US Government Users Restricted Rights- Use, duplication or disclosure
restricted by GSA ADP Schedule Contract with IBM Corp.
-->

<xsl:transform xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
               xmlns:xalan="http://xml.apache.org/xslt" 
               xmlns:staff="http://www.ibm.com/schemas/workflow/wswf/plugins/staff" 
               xmlns:svmm="http://www.ibm.com/schemas/workflow/wswf/plugins/staff/vmm" 
               version="1.0">
    

    <xsl:strip-space elements="*"/>    
    <xsl:output standalone="no" encoding="UTF-8" omit-xml-declaration="no" media-type="text/xml" method="xml" indent="yes" version="1.0"/>
    
    <!-- End global constants -->
        
    <!-- Begin global variables, adapt if needed -->
    <xsl:variable name="Threshold">1000000</xsl:variable>
    
    <xsl:variable name="VMMUserEntityType">PersonAccount</xsl:variable>
    <xsl:variable name="VMMUserIdType">uniqueName</xsl:variable>    
    <xsl:variable name="VMMUserIdAttribute">uid</xsl:variable>
    <xsl:variable name="VMMUserManagerAttribute">manager</xsl:variable>
    <xsl:variable name="VMMMailAttribute">mail</xsl:variable>
    <xsl:variable name="VMMLocaleAttribute">preferredLanguage</xsl:variable>  

    <xsl:variable name="VMMGroupIdType">uniqueName</xsl:variable>
    <xsl:variable name="VMMGroupEntityType">Group</xsl:variable>

    <xsl:variable name="PS_UserID">uid</xsl:variable>
    <xsl:variable name="PS_Profile">unknown</xsl:variable>
    <xsl:variable name="PS_LastName">sn</xsl:variable>
    <xsl:variable name="PS_FirstName">givenName</xsl:variable>
    <xsl:variable name="PS_MiddleName">initials</xsl:variable>
    <xsl:variable name="PS_Email">mail</xsl:variable>
    <xsl:variable name="PS_Company">unknown</xsl:variable>
    <xsl:variable name="PS_DisplayName">displayName</xsl:variable>
    <xsl:variable name="PS_Assistant">unknown</xsl:variable>
    <xsl:variable name="PS_Secretary">secretary</xsl:variable>
    <xsl:variable name="PS_Manager">manager</xsl:variable>
    <xsl:variable name="PS_Department">departmentNumber</xsl:variable>
    <xsl:variable name="PS_EmployeeID">unknown</xsl:variable>
    <xsl:variable name="PS_TaxPayerID">unknown</xsl:variable>
    <xsl:variable name="PS_Phone">telephoneNumber</xsl:variable>
    <xsl:variable name="PS_Fax">facsimileTelephoneNumber</xsl:variable>
    <xsl:variable name="PS_Gender">unknown</xsl:variable>
    <xsl:variable name="PS_Timezone">unknown</xsl:variable>
    <xsl:variable name="PS_PreferredLanguage">preferredLanguage</xsl:variable>

    <xsl:variable name="GS_GroupID">cn</xsl:variable>
    <xsl:variable name="GS_Type">unknown</xsl:variable>
    <xsl:variable name="GS_IndustryType">unknown</xsl:variable>
    <xsl:variable name="GS_BusinessType">unknown</xsl:variable>
    <xsl:variable name="GS_GeographicLocation">unknown</xsl:variable>
    <xsl:variable name="GS_Affiliates">unknown</xsl:variable>
    <xsl:variable name="GS_DisplayName">displayName</xsl:variable>
    <xsl:variable name="GS_Secretary">unknown</xsl:variable>
    <xsl:variable name="GS_Assistant">unknown</xsl:variable>
    <xsl:variable name="GS_Manager">unknown</xsl:variable>
    <xsl:variable name="GS_BusinessCategory">businessCategory</xsl:variable>
    <xsl:variable name="GS_ParentCompany">unknown</xsl:variable>

    <!-- End global variables -->
    
    <!-- set retrieval attribute to point to a user id attribute or, for email verbs, to an email attribute -->    
    <xsl:variable name="verb" select="normalize-space(/staff:verb/staff:name/text())"/>
    <xsl:variable name="returnAttribute">
            <xsl:choose>                            
            <xsl:when test="$verb='Email Address for Users by user ID'"> <xsl:value-of select="$VMMMailAttribute"/> </xsl:when>
            <xsl:when test="$verb='Email Address for Users'"> <xsl:value-of select="$VMMMailAttribute"/> </xsl:when>
            <xsl:when test="$verb='Email Address for Group Members'"> <xsl:value-of select="$VMMMailAttribute"/> </xsl:when>
            <xsl:when test="$verb='Email Address for Group Members without Filtered Users'"> <xsl:value-of select="$VMMMailAttribute"/> </xsl:when>
            <xsl:when test="$verb='Email Address for Department Members'"> <xsl:value-of select="$VMMMailAttribute"/> </xsl:when>
            <xsl:when test="$verb='Email Address for Role Members'"> <xsl:value-of select="$VMMMailAttribute"/> </xsl:when>
            <xsl:when test="$verb='Email Address for Group Search'"> <xsl:value-of select="$VMMMailAttribute"/> </xsl:when>
                    
            <xsl:otherwise> <xsl:value-of select="$VMMUserIdAttribute"/> </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>    

    <!-- Begin global dispatching -->
    <xsl:template match="/staff:verb">            
            <xsl:choose>    
                        
            <xsl:when test="$verb='Users'">
                <xsl:call-template name="Users"/>
            </xsl:when>
            
            <xsl:when test="$verb='Users by user ID'">
                <xsl:call-template name="UsersByUserID"/>
            </xsl:when>
            <xsl:when test="$verb='Users by user ID without Named Users'">
                <xsl:call-template name="UsersByUserIDWithoutNamedUsers"/>
            </xsl:when>
                    
            <xsl:when test="$verb='User Records by user ID'">
                <xsl:call-template name="UserRecordsByUserID"/>
            </xsl:when>

            <xsl:when test="$verb='User Records by user ID without Named Users'">
                <xsl:call-template name="UserRecordsByUserIDWithoutNamedUsers"/>
            </xsl:when>
            
            <xsl:when test="$verb='Group Members'">
                <xsl:call-template name="GroupMembers"/>
            </xsl:when>
            <xsl:when test="$verb='Group Members without Named Users'">
                <xsl:call-template name="GroupMembersWithoutNamedUsers"/>
            </xsl:when>            
            <xsl:when test="$verb='Group Members without Filtered Users'">
                <xsl:call-template name="GroupMembersWithoutFilteredUsers"/>
            </xsl:when>                
                        
            <xsl:when test="$verb='Role Members'">
                <xsl:call-template name="RoleMembers"/>
            </xsl:when>
            <xsl:when test="$verb='Department Members'">
                <xsl:call-template name="DepartmentMembers"/>
            </xsl:when>
            
            <xsl:when test="$verb='Manager of Employee'">
                <xsl:call-template name="ManagerOfEmployee"/>
            </xsl:when>
            <xsl:when test="$verb='Manager of Employee by user ID'">
                <xsl:call-template name="ManagerOfEmployeeByUserID"/>
            </xsl:when>
            
            <xsl:when test="$verb='Person Search'">
                <xsl:call-template name="PersonSearch"/>
            </xsl:when>
            <xsl:when test="$verb='Group Search'">
                <xsl:call-template name="GroupSearch"/>
            </xsl:when>
            <xsl:when test="$verb='Native Query'">
                <xsl:call-template name="NativeQuery"/>
            </xsl:when>
            
            <xsl:when test="$verb='Everybody'">
                <xsl:call-template name="Everybody"/>
            </xsl:when>
            <xsl:when test="$verb='Nobody'">
                <xsl:call-template name="Nobody"/>
            </xsl:when>
            
            <xsl:when test="$verb='Group'">
                <xsl:call-template name="Group"/>
            </xsl:when>
            <xsl:when test="$verb='Groups'">
                <xsl:call-template name="Groups"/>
            </xsl:when>
            <xsl:when test="$verb='Users by user ID and groups'">
                <xsl:call-template name="UsersByUserIDAndGroups"/>
            </xsl:when>
            <xsl:when test="$verb='Intersection of Group Members'">
                <xsl:call-template name="IntersectionOfGroupMembers"/>
            </xsl:when>

            <!-- email verbs -->
            <!-- specific verb for this case -->
            <xsl:when test="$verb='Email Address for Users by user ID'">
              <xsl:call-template name="EmailForUsersByUserID"/>
            </xsl:when>
            <!-- these email verbs map onto regular verbs, as 'returnAttribute' is set to point to an email attribute -->
            <xsl:when test="$verb='Email Address for Users'">
              <xsl:call-template name="Users"/>
            </xsl:when>
            <xsl:when test="$verb='Email Address for Group Members'">
              <xsl:call-template name="GroupMembers"/>
            </xsl:when>
            <xsl:when test="$verb='Email Address for Group Members without Filtered Users'">
              <xsl:call-template name="GroupMembersWithoutFilteredUsers"/>
            </xsl:when>     
            <xsl:when test="$verb='Email Address for Department Members'">
              <xsl:call-template name="DepartmentMembers"/>
            </xsl:when>
            <xsl:when test="$verb='Email Address for Role Members'">
              <xsl:call-template name="RoleMembers"/>
            </xsl:when>
            <xsl:when test="$verb='Email Address for Group Search'">
              <xsl:call-template name="GroupSearch"/>
            </xsl:when>   
                    
            <xsl:otherwise>
                <xsl:message terminate="no">ERROR: Unsupported verb: '<xsl:value-of select="$verb"/>'.</xsl:message>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- End global dispatching -->

    <!-- Begin helper template for default result entity specifying user data to retrieve -->
    <xsl:template name="ResultEntitySpecForUserData">
        <svmm:resultEntity>
            <xsl:attribute name="type"> <xsl:value-of select="$VMMUserEntityType"/>  </xsl:attribute>                 
            <svmm:attribute> 
                <xsl:attribute name="name"> <xsl:value-of select="$returnAttribute"/> </xsl:attribute>                
                <xsl:attribute name="destination">userID</xsl:attribute>
            </svmm:attribute>                     
            <svmm:attribute> 
                <xsl:attribute name="name"> <xsl:value-of select="$VMMMailAttribute"/> </xsl:attribute>
                <xsl:attribute name="destination">eMailAddress</xsl:attribute>                
            </svmm:attribute>
            <svmm:attribute> 
                <xsl:attribute name="name"> <xsl:value-of select="$VMMLocaleAttribute"/> </xsl:attribute>                
                <xsl:attribute name="destination">preferredLocale</xsl:attribute>
            </svmm:attribute>
        </svmm:resultEntity>          
    </xsl:template>
    <!-- End helper template for specifying default result entity for user data -->


    <!-- Begin template Everybody -->
    <xsl:template name="Everybody">
        <svmm:staffQueries>
            <svmm:everybody/>
        </svmm:staffQueries>
    </xsl:template>
    <!-- End template Everybody -->
        
    <!-- Begin template Nobody -->
    <xsl:template name="Nobody">
        <svmm:staffQueries>
            <svmm:nobody/>
        </svmm:staffQueries>
    </xsl:template>
    <!-- End template Nobody -->


     <!-- Begin template Group -->
    <xsl:template name="Group">
        <xsl:variable name="GroupID">
            <xsl:value-of select="staff:parameter[@id='GroupID']"/>
        </xsl:variable>

        <svmm:staffQueries>
            <xsl:call-template name="GetGroup">
                <xsl:with-param name="groupname">
                    <xsl:value-of select="$GroupID"/>
                </xsl:with-param>
            </xsl:call-template>
        </svmm:staffQueries>
    </xsl:template>

    <xsl:template name="GetGroup">
        <xsl:param name="groupname">default</xsl:param>
        <svmm:groupID>
            <xsl:attribute name="name">
                <xsl:value-of select="$groupname"/>
            </xsl:attribute>
        </svmm:groupID>
    </xsl:template>
    <!-- End template Group -->



    <!-- Begin template Groups -->
    <xsl:template name="Groups">
        <xsl:variable name="GroupID0">
            <xsl:value-of select="staff:parameter[@id='GroupID']"/>
        </xsl:variable>
        <xsl:variable name="GroupID1">
            <xsl:value-of select="staff:parameter[@id='AlternativeGroupID1']"/>
        </xsl:variable>
        <xsl:variable name="GroupID2">
            <xsl:value-of select="staff:parameter[@id='AlternativeGroupID2']"/>
        </xsl:variable>
        <xsl:variable name="GroupID3">
            <xsl:value-of select="staff:parameter[@id='AlternativeGroupID3']"/>
        </xsl:variable>
        <xsl:variable name="GroupID4">
            <xsl:value-of select="staff:parameter[@id='AlternativeGroupID4']"/>
        </xsl:variable>
        <xsl:variable name="GroupID5">
            <xsl:value-of select="staff:parameter[@id='AlternativeGroupID5']"/>
        </xsl:variable>

        <svmm:staffQueries>
            <xsl:call-template name="GetGroup">
                <xsl:with-param name="groupname"> <xsl:value-of select="$GroupID0"/> </xsl:with-param>
            </xsl:call-template>
            <xsl:if test="$GroupID1!=''">
                <xsl:call-template name="GetGroup">
                    <xsl:with-param name="groupname"> <xsl:value-of select="$GroupID1"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$GroupID2!=''">
                <xsl:call-template name="GetGroup">
                    <xsl:with-param name="groupname"> <xsl:value-of select="$GroupID2"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$GroupID3!=''">
                <xsl:call-template name="GetGroup">
                    <xsl:with-param name="groupname"> <xsl:value-of select="$GroupID3"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$GroupID4!=''">
                <xsl:call-template name="GetGroup">
                    <xsl:with-param name="groupname"> <xsl:value-of select="$GroupID4"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$GroupID5!=''">
                <xsl:call-template name="GetGroup">
                    <xsl:with-param name="groupname"> <xsl:value-of select="$GroupID5"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
        </svmm:staffQueries>
    </xsl:template>
    <!-- End template Groups -->


    <!-- Begin template UsersByUserIDAndGroups -->
    <xsl:template name="UsersByUserIDAndGroups">
        <xsl:variable name="Name0">
            <xsl:value-of select="staff:parameter[@id='UserID']"/>
        </xsl:variable>
        <xsl:variable name="Name1">
            <xsl:value-of select="staff:parameter[@id='AlternativeUserID1']"/>
        </xsl:variable>
        <xsl:variable name="Name2">
            <xsl:value-of select="staff:parameter[@id='AlternativeUserID2']"/>
        </xsl:variable>
        <xsl:variable name="Name3">
            <xsl:value-of select="staff:parameter[@id='AlternativeUserID3']"/>
        </xsl:variable>
        <xsl:variable name="Name4">
            <xsl:value-of select="staff:parameter[@id='AlternativeUserID4']"/>
        </xsl:variable>
        <xsl:variable name="Name5">
            <xsl:value-of select="staff:parameter[@id='AlternativeUserID5']"/>
        </xsl:variable>
        <xsl:variable name="GroupID0">
            <xsl:value-of select="staff:parameter[@id='GroupID']"/>
        </xsl:variable>
        <xsl:variable name="GroupID1">
            <xsl:value-of select="staff:parameter[@id='AlternativeGroupID1']"/>
        </xsl:variable>
        <xsl:variable name="GroupID2">
            <xsl:value-of select="staff:parameter[@id='AlternativeGroupID2']"/>
        </xsl:variable>
        <xsl:variable name="GroupID3">
            <xsl:value-of select="staff:parameter[@id='AlternativeGroupID3']"/>
        </xsl:variable>
        <xsl:variable name="GroupID4">
            <xsl:value-of select="staff:parameter[@id='AlternativeGroupID4']"/>
        </xsl:variable>
        <xsl:variable name="GroupID5">
            <xsl:value-of select="staff:parameter[@id='AlternativeGroupID5']"/>
        </xsl:variable>

        <svmm:staffQueries>
            <xsl:attribute name="threshold">
                <xsl:value-of select="$Threshold"/>
            </xsl:attribute>
            <xsl:call-template name="GetUserByID">
                <xsl:with-param name="username"> <xsl:value-of select="$Name0"/> </xsl:with-param>
            </xsl:call-template>
            <xsl:if test="$Name1!=''">
                <xsl:call-template name="GetUserByID">
                    <xsl:with-param name="username"> <xsl:value-of select="$Name1"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Name2!=''">
                <xsl:call-template name="GetUserByID">
                    <xsl:with-param name="username"> <xsl:value-of select="$Name2"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Name3!=''">
                <xsl:call-template name="GetUserByID">
                    <xsl:with-param name="username"> <xsl:value-of select="$Name3"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Name4!=''">
                <xsl:call-template name="GetUserByID">
                    <xsl:with-param name="username"> <xsl:value-of select="$Name4"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Name5!=''">
                <xsl:call-template name="GetUserByID">
                    <xsl:with-param name="username"> <xsl:value-of select="$Name5"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:call-template name="GetGroup">
                <xsl:with-param name="groupname"> <xsl:value-of select="$GroupID0"/> </xsl:with-param>
            </xsl:call-template>
            <xsl:if test="$GroupID1!=''">
                <xsl:call-template name="GetGroup">
                    <xsl:with-param name="groupname"> <xsl:value-of select="$GroupID1"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$GroupID2!=''">
                <xsl:call-template name="GetGroup">
                    <xsl:with-param name="groupname"> <xsl:value-of select="$GroupID2"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$GroupID3!=''">
                <xsl:call-template name="GetGroup">
                    <xsl:with-param name="groupname"> <xsl:value-of select="$GroupID3"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$GroupID4!=''">
                <xsl:call-template name="GetGroup">
                    <xsl:with-param name="groupname"> <xsl:value-of select="$GroupID4"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$GroupID5!=''">
                <xsl:call-template name="GetGroup">
                    <xsl:with-param name="groupname"> <xsl:value-of select="$GroupID5"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
        </svmm:staffQueries>
    </xsl:template>
    <!-- End template UsersByUserIDAndGroups -->


    <!-- Begin template IntersectionOfGroupMembers -->
    <xsl:template name="IntersectionOfGroupMembers">
        <xsl:variable name="Group0">
            <xsl:value-of select="staff:parameter[@id='GroupName']"/>
        </xsl:variable>
        <xsl:variable name="Group1">
            <xsl:value-of select="staff:parameter[@id='OtherGroupName']"/>
        </xsl:variable>
        <xsl:variable name="includeSubgroups">
            <xsl:value-of select="staff:parameter[@id='IncludeSubgroups']"/>
        </xsl:variable>        
        <svmm:staffQueries>
            <xsl:attribute name="threshold"><xsl:value-of select="$Threshold"/></xsl:attribute>
            <xsl:call-template name="GetGroupMembers">
                <xsl:with-param name="setname"> <xsl:value-of select="$Group0"/> </xsl:with-param>
                <xsl:with-param name="includesubsets"> <xsl:value-of select="$includeSubgroups"/> </xsl:with-param>
            </xsl:call-template>
            <svmm:intermediateResult>
                <xsl:attribute name="name">otherGroupMembers</xsl:attribute>
                <svmm:usersOfGroup>
                    <xsl:attribute name="id"> <xsl:value-of select="$Group1"/> </xsl:attribute>
                    <xsl:attribute name="idType"> <xsl:value-of select="$VMMGroupIdType"/> </xsl:attribute>
                    <xsl:attribute name="entityType"> <xsl:value-of select="$VMMGroupEntityType"/> </xsl:attribute>            
                    <xsl:choose>
                        <xsl:when test="$includeSubgroups='false'">
                            <xsl:attribute name="recursive">no</xsl:attribute>
                        </xsl:when>
                        <xsl:when test="$includeSubgroups='true'">
                            <xsl:attribute name="recursive">yes</xsl:attribute>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:message terminate="no">WARNING: Unexpected value: '<xsl:value-of select="$includeSubgroups"/>' for IncludeSubgroups. Continue using the default value 'true'.</xsl:message>
                        </xsl:otherwise>
                    </xsl:choose>
                    <svmm:resultEntity>
                      <xsl:attribute name="type"> <xsl:value-of select="$VMMUserEntityType"/>  </xsl:attribute>                 
                      <svmm:attribute> 
                          <xsl:attribute name="name"> <xsl:value-of select="$returnAttribute"/> </xsl:attribute>                
                          <xsl:attribute name="destination">intermediate</xsl:attribute>
                      </svmm:attribute>
                    </svmm:resultEntity>                                                
                </svmm:usersOfGroup>
            </svmm:intermediateResult>
            <svmm:intersect>
                <xsl:attribute name="value">%otherGroupMembers%</xsl:attribute>
            </svmm:intersect>
        </svmm:staffQueries>
    </xsl:template>
    <!-- End template IntersectionOfGroupMembers -->


    <!-- Begin template UsersByUserID and children -->
    <xsl:template name="UsersByUserID">
        <xsl:variable name="Name0">
            <xsl:value-of select="staff:parameter[@id='UserID']"/>
        </xsl:variable>
        <xsl:variable name="Name1">
            <xsl:value-of select="staff:parameter[@id='AlternativeID1']"/>
        </xsl:variable>
        <xsl:variable name="Name2">
            <xsl:value-of select="staff:parameter[@id='AlternativeID2']"/>
        </xsl:variable>
        <xsl:variable name="Name3">
            <xsl:value-of select="staff:parameter[@id='AlternativeID3']"/>
        </xsl:variable>
        <xsl:variable name="Name4">
            <xsl:value-of select="staff:parameter[@id='AlternativeID4']"/>
        </xsl:variable>
        <xsl:variable name="Name5">
            <xsl:value-of select="staff:parameter[@id='AlternativeID5']"/>
        </xsl:variable>
        
        <svmm:staffQueries>
            <xsl:call-template name="GetUserByID">
                <xsl:with-param name="username">
                    <xsl:value-of select="$Name0"/>
                </xsl:with-param>                
            </xsl:call-template>
            <xsl:if test="$Name1!=''">
                <xsl:call-template name="GetUserByID">
                    <xsl:with-param name="username">
                        <xsl:value-of select="$Name1"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Name2!=''">
                <xsl:call-template name="GetUserByID">
                    <xsl:with-param name="username">
                        <xsl:value-of select="$Name2"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Name3!=''">
                <xsl:call-template name="GetUserByID">
                    <xsl:with-param name="username">
                        <xsl:value-of select="$Name3"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Name4!=''">
                <xsl:call-template name="GetUserByID">
                    <xsl:with-param name="username">
                        <xsl:value-of select="$Name4"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Name5!=''">
                <xsl:call-template name="GetUserByID">
                    <xsl:with-param name="username">
                        <xsl:value-of select="$Name5"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
        </svmm:staffQueries>
    </xsl:template>
    
    <xsl:template name="GetUserByID">
        <xsl:param name="username">default</xsl:param>
        <svmm:userID>
                  <xsl:attribute name="name">
                    <xsl:value-of select="$username"/>
                  </xsl:attribute>                                                              
        </svmm:userID>
    </xsl:template>
    <!-- End template UsersByUserID and children -->


    <!-- Begin template UsersByUserIDWithtoutNamedUsers -->
    <xsl:template name="UsersByUserIDWithoutNamedUsers">
        <xsl:variable name="Name0">
            <xsl:value-of select="staff:parameter[@id='UserID']"/>
        </xsl:variable>
        <xsl:variable name="Name1">
            <xsl:value-of select="staff:parameter[@id='AlternativeID1']"/>
        </xsl:variable>
        <xsl:variable name="Name2">
            <xsl:value-of select="staff:parameter[@id='AlternativeID2']"/>
        </xsl:variable>
        <xsl:variable name="Name3">
            <xsl:value-of select="staff:parameter[@id='AlternativeID3']"/>
        </xsl:variable>
        <xsl:variable name="Name4">
            <xsl:value-of select="staff:parameter[@id='AlternativeID4']"/>
        </xsl:variable>
        <xsl:variable name="Name5">
            <xsl:value-of select="staff:parameter[@id='AlternativeID5']"/>
        </xsl:variable>
        <svmm:staffQueries>
            <xsl:call-template name="GetUserByID">
                <xsl:with-param name="username">
                    <xsl:value-of select="$Name0"/>
                </xsl:with-param>
            </xsl:call-template>
            <xsl:if test="$Name1!=''">
                <xsl:call-template name="GetUserByID">
                    <xsl:with-param name="username">
                        <xsl:value-of select="$Name1"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Name2!=''">
                <xsl:call-template name="GetUserByID">
                    <xsl:with-param name="username">
                        <xsl:value-of select="$Name2"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Name3!=''">
                <xsl:call-template name="GetUserByID">
                    <xsl:with-param name="username">
                        <xsl:value-of select="$Name3"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Name4!=''">
                <xsl:call-template name="GetUserByID">
                    <xsl:with-param name="username">
                        <xsl:value-of select="$Name4"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Name5!=''">
                <xsl:call-template name="GetUserByID">
                    <xsl:with-param name="username">
                        <xsl:value-of select="$Name5"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:if>

            <svmm:remove>
                <xsl:attribute name="value"><xsl:value-of select="staff:parameter[@id='NamedUsers']"/></xsl:attribute>
            </svmm:remove>            
            
        </svmm:staffQueries>
    </xsl:template>
    <!-- End template UsersByUserIDWithoutNamedUsers -->


    <!-- Begin template UserRecordsByUserID and children -->
    <xsl:template name="UserRecordsByUserID">
        <xsl:variable name="Name0">
            <xsl:value-of select="staff:parameter[@id='UserID']"/>
        </xsl:variable>
        <xsl:variable name="Name1">
            <xsl:value-of select="staff:parameter[@id='AlternativeID1']"/>
        </xsl:variable>
        <xsl:variable name="Name2">
            <xsl:value-of select="staff:parameter[@id='AlternativeID2']"/>
        </xsl:variable>
        <xsl:variable name="Name3">
            <xsl:value-of select="staff:parameter[@id='AlternativeID3']"/>
        </xsl:variable>
        <xsl:variable name="Name4">
            <xsl:value-of select="staff:parameter[@id='AlternativeID4']"/>
        </xsl:variable>
        <xsl:variable name="Name5">
            <xsl:value-of select="staff:parameter[@id='AlternativeID5']"/>
        </xsl:variable>
        
        <svmm:staffQueries>
            <xsl:call-template name="GetUserRecordByID">
                <xsl:with-param name="username">
                    <xsl:value-of select="$Name0"/>
                </xsl:with-param>                
            </xsl:call-template>
            <xsl:if test="$Name1!=''">
                <xsl:call-template name="GetUserRecordByID">
                    <xsl:with-param name="username">
                        <xsl:value-of select="$Name1"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Name2!=''">
                <xsl:call-template name="GetUserRecordByID">
                    <xsl:with-param name="username">
                        <xsl:value-of select="$Name2"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Name3!=''">
                <xsl:call-template name="GetUserRecordByID">
                    <xsl:with-param name="username">
                        <xsl:value-of select="$Name3"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Name4!=''">
                <xsl:call-template name="GetUserRecordByID">
                    <xsl:with-param name="username">
                        <xsl:value-of select="$Name4"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Name5!=''">
                <xsl:call-template name="GetUserRecordByID">
                    <xsl:with-param name="username">
                        <xsl:value-of select="$Name5"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
        </svmm:staffQueries>
    </xsl:template>
    
    <xsl:template name="GetUserRecordByID">
        <xsl:param name="username">default</xsl:param>                
        <svmm:search>
            <xsl:attribute name="searchExpression">//entities[@xsi:type='<xsl:value-of select="$VMMUserEntityType"/>' and <xsl:value-of select="$VMMUserIdAttribute"/>='<xsl:value-of select="$username"/>']</xsl:attribute>              
              <xsl:call-template name="ResultEntitySpecForUserData" />                                
        </svmm:search>
    </xsl:template>
    <!-- End template UserRecordsUserID and children -->

    <!-- Begin template UserRecordsByUserIDWithoutNamedUsers and children -->
    <xsl:template name="UserRecordsByUserIDWithoutNamedUsers">
        <xsl:variable name="Name0">
            <xsl:value-of select="staff:parameter[@id='UserID']"/>
        </xsl:variable>
        <xsl:variable name="Name1">
            <xsl:value-of select="staff:parameter[@id='AlternativeID1']"/>
        </xsl:variable>
        <xsl:variable name="Name2">
            <xsl:value-of select="staff:parameter[@id='AlternativeID2']"/>
        </xsl:variable>
        <xsl:variable name="Name3">
            <xsl:value-of select="staff:parameter[@id='AlternativeID3']"/>
        </xsl:variable>
        <xsl:variable name="Name4">
            <xsl:value-of select="staff:parameter[@id='AlternativeID4']"/>
        </xsl:variable>
        <xsl:variable name="Name5">
            <xsl:value-of select="staff:parameter[@id='AlternativeID5']"/>
        </xsl:variable>
        
        <svmm:staffQueries>
            <xsl:call-template name="GetUserRecordByID">
                <xsl:with-param name="username">
                    <xsl:value-of select="$Name0"/>
                </xsl:with-param>                
            </xsl:call-template>
            <xsl:if test="$Name1!=''">
                <xsl:call-template name="GetUserRecordByID">
                    <xsl:with-param name="username">
                        <xsl:value-of select="$Name1"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Name2!=''">
                <xsl:call-template name="GetUserRecordByID">
                    <xsl:with-param name="username">
                        <xsl:value-of select="$Name2"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Name3!=''">
                <xsl:call-template name="GetUserRecordByID">
                    <xsl:with-param name="username">
                        <xsl:value-of select="$Name3"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Name4!=''">
                <xsl:call-template name="GetUserRecordByID">
                    <xsl:with-param name="username">
                        <xsl:value-of select="$Name4"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Name5!=''">
                <xsl:call-template name="GetUserRecordByID">
                    <xsl:with-param name="username">
                        <xsl:value-of select="$Name5"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            
            <svmm:remove>
                <xsl:attribute name="value"><xsl:value-of select="staff:parameter[@id='NamedUsers']"/></xsl:attribute>
            </svmm:remove>    
            
        </svmm:staffQueries>
    </xsl:template>
    <!-- End template UserRecordsByUserIDWithoutNamedUsers and children -->


    <!-- Begin template Users and children -->
    <xsl:template name="Users">
        <xsl:variable name="Name0">
            <xsl:value-of select="staff:parameter[@id='Name']"/>
        </xsl:variable>
        <xsl:variable name="Name1">
            <xsl:value-of select="staff:parameter[@id='AlternativeName1']"/>
        </xsl:variable>
        <xsl:variable name="Name2">
            <xsl:value-of select="staff:parameter[@id='AlternativeName2']"/>
        </xsl:variable>
        <xsl:variable name="Name3">
            <xsl:value-of select="staff:parameter[@id='AlternativeName3']"/>
        </xsl:variable>
        <xsl:variable name="Name4">
            <xsl:value-of select="staff:parameter[@id='AlternativeName4']"/>
        </xsl:variable>
        <xsl:variable name="Name5">
            <xsl:value-of select="staff:parameter[@id='AlternativeName5']"/>
        </xsl:variable>

        <svmm:staffQueries>
            <xsl:attribute name="threshold"><xsl:value-of select="$Threshold"/></xsl:attribute>
            <xsl:call-template name="GetUser">
                <xsl:with-param name="username">
                    <xsl:value-of select="$Name0"/>
                </xsl:with-param>
            </xsl:call-template>
            <xsl:if test="$Name1!=''">
                <xsl:call-template name="GetUser">
                    <xsl:with-param name="username">
                        <xsl:value-of select="$Name1"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Name2!=''">
                <xsl:call-template name="GetUser">
                    <xsl:with-param name="username">
                        <xsl:value-of select="$Name2"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Name3!=''">
                <xsl:call-template name="GetUser">
                    <xsl:with-param name="username">
                        <xsl:value-of select="$Name3"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Name4!=''">
                <xsl:call-template name="GetUser">
                    <xsl:with-param name="username">
                        <xsl:value-of select="$Name4"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Name5!=''">
                <xsl:call-template name="GetUser">
                    <xsl:with-param name="username">
                        <xsl:value-of select="$Name5"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
        </svmm:staffQueries>
    </xsl:template>
    
    <xsl:template name="GetUser">
        <xsl:param name="username">default</xsl:param>
        <svmm:user>
            <xsl:attribute name="id"><xsl:value-of select="$username"/></xsl:attribute>
            <xsl:attribute name="idType"><xsl:value-of select="$VMMUserIdType"/></xsl:attribute>            
            <xsl:call-template name="ResultEntitySpecForUserData" />
        </svmm:user>
    </xsl:template>
    <!-- End template Users and children -->


    <!-- Begin template GroupMembers and children -->
    <xsl:template name="GroupMembers">
        <xsl:variable name="Group0">
            <xsl:value-of select="staff:parameter[@id='GroupName']"/>
        </xsl:variable>
        <xsl:variable name="Group1">
            <xsl:value-of select="staff:parameter[@id='AlternativeGroupName1']"/>
        </xsl:variable>
        <xsl:variable name="Group2">
            <xsl:value-of select="staff:parameter[@id='AlternativeGroupName2']"/>
        </xsl:variable>
        <xsl:variable name="Group3">
            <xsl:value-of select="staff:parameter[@id='AlternativeGroupName3']"/>
        </xsl:variable>
        <xsl:variable name="Group4">
            <xsl:value-of select="staff:parameter[@id='AlternativeGroupName4']"/>
        </xsl:variable>
        <xsl:variable name="Group5">
            <xsl:value-of select="staff:parameter[@id='AlternativeGroupName5']"/>
        </xsl:variable>
        <xsl:variable name="includeSubgroups">
            <xsl:value-of select="staff:parameter[@id='IncludeSubgroups']"/>
        </xsl:variable>        
        <svmm:staffQueries>
            <xsl:attribute name="threshold"><xsl:value-of select="$Threshold"/></xsl:attribute>
            <xsl:call-template name="GetGroupMembers">
                <xsl:with-param name="setname"> <xsl:value-of select="$Group0"/> </xsl:with-param>
                <xsl:with-param name="includesubsets"> <xsl:value-of select="$includeSubgroups"/> </xsl:with-param>
            </xsl:call-template>
            <xsl:if test="$Group1!=''">
                <xsl:call-template name="GetGroupMembers">
                    <xsl:with-param name="setname"> <xsl:value-of select="$Group1"/> </xsl:with-param>
                    <xsl:with-param name="includesubsets"> <xsl:value-of select="$includeSubgroups"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Group2!=''">
                <xsl:call-template name="GetGroupMembers">
                    <xsl:with-param name="setname"> <xsl:value-of select="$Group2"/> </xsl:with-param>
                    <xsl:with-param name="includesubsets"> <xsl:value-of select="$includeSubgroups"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Group3!=''">
                <xsl:call-template name="GetGroupMembers">
                    <xsl:with-param name="setname"> <xsl:value-of select="$Group3"/> </xsl:with-param>
                    <xsl:with-param name="includesubsets"> <xsl:value-of select="$includeSubgroups"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Group4!=''">
                <xsl:call-template name="GetGroupMembers">
                    <xsl:with-param name="setname"> <xsl:value-of select="$Group4"/> </xsl:with-param>
                    <xsl:with-param name="includesubsets"> <xsl:value-of select="$includeSubgroups"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Group5!=''">
                <xsl:call-template name="GetGroupMembers">
                    <xsl:with-param name="setname"> <xsl:value-of select="$Group5"/> </xsl:with-param>
                    <xsl:with-param name="includesubsets"> <xsl:value-of select="$includeSubgroups"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
        </svmm:staffQueries>
    </xsl:template>
    
    <xsl:template name="GetGroupMembers">
        <xsl:param name="setname">default</xsl:param>
        <xsl:param name="includesubsets">yes</xsl:param>        
        <svmm:usersOfGroup>
            <xsl:attribute name="id"> <xsl:value-of select="$setname"/> </xsl:attribute>
            <xsl:attribute name="idType"> <xsl:value-of select="$VMMGroupIdType"/> </xsl:attribute>
            <xsl:attribute name="entityType"> <xsl:value-of select="$VMMGroupEntityType"/> </xsl:attribute>            
            <xsl:choose>
                <xsl:when test="$includesubsets='false'">
                    <xsl:attribute name="recursive">no</xsl:attribute>
                </xsl:when>
                <xsl:when test="$includesubsets='true'">
                    <xsl:attribute name="recursive">yes</xsl:attribute>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:message terminate="no">WARNING: Unexpected value: '<xsl:value-of select="$includesubsets"/>' for IncludeSubgroups. Continue using the default value 'true'.</xsl:message>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:call-template name="ResultEntitySpecForUserData" />
        </svmm:usersOfGroup>
    </xsl:template>
    <!-- End template GroupMembers and children -->


    <!-- Begin template group members without named users -->
    <xsl:template name="GroupMembersWithoutNamedUsers">    
        <svmm:staffQueries>                
            <svmm:usersOfGroup>
                <xsl:attribute name="id"> <xsl:value-of select="staff:parameter[@id='GroupName']"/> </xsl:attribute>
                <xsl:attribute name="idType"> <xsl:value-of select="$VMMGroupIdType"/> </xsl:attribute>
                <xsl:attribute name="entityType"> <xsl:value-of select="$VMMGroupEntityType"/> </xsl:attribute>
                <xsl:choose>
                    <xsl:when test="staff:parameter[@id='IncludeSubgroups']='false'">
                        <xsl:attribute name="recursive">no</xsl:attribute>
                    </xsl:when>
                    <xsl:when test="staff:parameter[@id='IncludeSubgroups']='true'">
                        <xsl:attribute name="recursive">yes</xsl:attribute>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:message terminate="no">WARNING: Unexpected value: '<xsl:value-of select="staff:parameter[@id='IncludeSubgroups']"/>' for IncludeSubgroups. Continue using the default value 'true'.</xsl:message>
                    </xsl:otherwise>            
                </xsl:choose>
                <xsl:call-template name="ResultEntitySpecForUserData" />                                            
            </svmm:usersOfGroup>    

            <svmm:remove>
                <xsl:attribute name="value"><xsl:value-of select="staff:parameter[@id='NamedUsers']"/></xsl:attribute>
            </svmm:remove>
        </svmm:staffQueries>
    </xsl:template>
    <!-- End template group members without named users -->


    <!-- Begin template group members without filtered users -->
    <xsl:template name="GroupMembersWithoutFilteredUsers">
        
        <svmm:staffQueries>
            <svmm:usersOfGroup>
                <xsl:attribute name="id"> <xsl:value-of select="staff:parameter[@id='GroupName']"/> </xsl:attribute>
                <xsl:attribute name="idType"> <xsl:value-of select="$VMMGroupIdType"/> </xsl:attribute>
                <xsl:attribute name="entityType"> <xsl:value-of select="$VMMGroupEntityType"/> </xsl:attribute>
                <xsl:choose>
                    <xsl:when test="staff:parameter[@id='IncludeSubgroups']='false'">
                        <xsl:attribute name="recursive">no</xsl:attribute>
                    </xsl:when>
                    <xsl:when test="staff:parameter[@id='IncludeSubgroups']='true'">
                        <xsl:attribute name="recursive">yes</xsl:attribute>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:message terminate="no">WARNING: Unexpected value: '<xsl:value-of select="staff:parameter[@id='IncludeSubgroups']"/>' for IncludeSubgroups. Continue using the default value 'true'.</xsl:message>
                    </xsl:otherwise>            
                </xsl:choose>
                <xsl:call-template name="ResultEntitySpecForUserData" />    
            </svmm:usersOfGroup>

            <svmm:intermediateResult>
                <xsl:attribute name="name">filteredusers</xsl:attribute>
                
                      <svmm:search>
                    <xsl:attribute name="searchExpression">//entities[@xsi:type='<xsl:value-of select="$VMMUserEntityType"/>' and <xsl:value-of select="staff:parameter[@id='FilterAttribute']"/>='<xsl:value-of select="staff:parameter[@id='FilterValue']"/>']</xsl:attribute>
                      
                      <svmm:resultEntity>
                        <xsl:attribute name="type"> <xsl:value-of select="$VMMUserEntityType"/>  </xsl:attribute>                 
                        <svmm:attribute> 
                            <xsl:attribute name="name"> <xsl:value-of select="$returnAttribute"/> </xsl:attribute>                
                            <xsl:attribute name="destination">intermediate</xsl:attribute>
                        </svmm:attribute>
                    </svmm:resultEntity>                                                
                </svmm:search>                    
            </svmm:intermediateResult>

            <svmm:remove>
                <xsl:attribute name="value">%filteredusers%</xsl:attribute>
            </svmm:remove>
        </svmm:staffQueries>

    </xsl:template>
    <!-- End template group members without filtered users -->


    <!-- Begin template RoleMembers -->
    <xsl:template name="RoleMembers">
        <xsl:variable name="Role0">
            <xsl:value-of select="staff:parameter[@id='RoleName']"/>
        </xsl:variable>
        <xsl:variable name="Role1">
            <xsl:value-of select="staff:parameter[@id='AlternativeRoleName1']"/>
        </xsl:variable>
        <xsl:variable name="Role2">
            <xsl:value-of select="staff:parameter[@id='AlternativeRoleName2']"/>
        </xsl:variable>
        <xsl:variable name="Role3">
            <xsl:value-of select="staff:parameter[@id='AlternativeRoleName3']"/>
        </xsl:variable>
        <xsl:variable name="Role4">
            <xsl:value-of select="staff:parameter[@id='AlternativeRoleName4']"/>
        </xsl:variable>
        <xsl:variable name="Role5">
            <xsl:value-of select="staff:parameter[@id='AlternativeRoleName5']"/>
        </xsl:variable>
        <xsl:variable name="includeNestedRoles">
            <xsl:value-of select="staff:parameter[@id='IncludeNestedRoles']"/>
        </xsl:variable>                
        <svmm:staffQueries>
            <xsl:attribute name="threshold"><xsl:value-of select="$Threshold"/></xsl:attribute>
            <xsl:call-template name="GetGroupMembers">
                <xsl:with-param name="setname"> <xsl:value-of select="$Role0"/> </xsl:with-param>
                <xsl:with-param name="includesubsets"> <xsl:value-of select="$includeNestedRoles"/> </xsl:with-param>
            </xsl:call-template>
            <xsl:if test="$Role1!=''">
                <xsl:call-template name="GetGroupMembers"> 
                    <xsl:with-param name="setname"> <xsl:value-of select="$Role1"/> </xsl:with-param>
                    <xsl:with-param name="includesubsets"> <xsl:value-of select="$includeNestedRoles"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Role2!=''">
                <xsl:call-template name="GetGroupMembers">
                    <xsl:with-param name="setname"> <xsl:value-of select="$Role2"/> </xsl:with-param>
                    <xsl:with-param name="includesubsets"> <xsl:value-of select="$includeNestedRoles"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Role3!=''">
                <xsl:call-template name="GetGroupMembers"> 
                    <xsl:with-param name="setname"> <xsl:value-of select="$Role3"/> </xsl:with-param>
                    <xsl:with-param name="includesubsets"> <xsl:value-of select="$includeNestedRoles"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Role4!=''">
                <xsl:call-template name="GetGroupMembers"> 
                    <xsl:with-param name="setname"> <xsl:value-of select="$Role4"/> </xsl:with-param>
                    <xsl:with-param name="includesubsets"> <xsl:value-of select="$includeNestedRoles"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Role5!=''">
                <xsl:call-template name="GetGroupMembers"> 
                    <xsl:with-param name="setname"> <xsl:value-of select="$Role5"/> </xsl:with-param>
                    <xsl:with-param name="includesubsets"> <xsl:value-of select="$includeNestedRoles"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
        </svmm:staffQueries>
    </xsl:template>
    <!-- End template RoleMembers -->


    <!-- Begin template DepartmentMembers -->
    <xsl:template name="DepartmentMembers">
        <xsl:variable name="Dept0">
            <xsl:value-of select="staff:parameter[@id='DepartmentName']"/>
        </xsl:variable>
        <xsl:variable name="Dept1">
            <xsl:value-of select="staff:parameter[@id='AlternativeDepartmentName1']"/>
        </xsl:variable>
        <xsl:variable name="Dept2">
            <xsl:value-of select="staff:parameter[@id='AlternativeDepartmentName2']"/>
        </xsl:variable>
        <xsl:variable name="Dept3">
            <xsl:value-of select="staff:parameter[@id='AlternativeDepartmentName3']"/>
        </xsl:variable>
        <xsl:variable name="Dept4">
            <xsl:value-of select="staff:parameter[@id='AlternativeDepartmentName4']"/>
        </xsl:variable>
        <xsl:variable name="Dept5">
            <xsl:value-of select="staff:parameter[@id='AlternativeDepartmentName5']"/>
        </xsl:variable>
        <xsl:variable name="includeNestedDepartments">
            <xsl:value-of select="staff:parameter[@id='IncludeNestedDepartments']"/>
        </xsl:variable>
        <svmm:staffQueries>
            <xsl:attribute name="threshold"><xsl:value-of select="$Threshold"/></xsl:attribute>
            <xsl:call-template name="GetGroupMembers">
                <xsl:with-param name="setname"> <xsl:value-of select="$Dept0"/> </xsl:with-param>
                <xsl:with-param name="includesubsets"> <xsl:value-of select="$includeNestedDepartments"/> </xsl:with-param>
            </xsl:call-template>
            <xsl:if test="$Dept1!=''">
                <xsl:call-template name="GetGroupMembers">
                    <xsl:with-param name="setname"> <xsl:value-of select="$Dept1"/> </xsl:with-param>
                    <xsl:with-param name="includesubsets"> <xsl:value-of select="$includeNestedDepartments"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Dept2!=''">
                <xsl:call-template name="GetGroupMembers">
                    <xsl:with-param name="setname"> <xsl:value-of select="$Dept2"/> </xsl:with-param>
                    <xsl:with-param name="includesubsets"> <xsl:value-of select="$includeNestedDepartments"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Dept3!=''">
                <xsl:call-template name="GetGroupMembers">
                    <xsl:with-param name="setname"> <xsl:value-of select="$Dept3"/> </xsl:with-param>
                    <xsl:with-param name="includesubsets"> <xsl:value-of select="$includeNestedDepartments"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Dept4!=''">
                <xsl:call-template name="GetGroupMembers">
                    <xsl:with-param name="setname"> <xsl:value-of select="$Dept4"/> </xsl:with-param>
                    <xsl:with-param name="includesubsets"> <xsl:value-of select="$includeNestedDepartments"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Dept5!=''">
                <xsl:call-template name="GetGroupMembers">
                    <xsl:with-param name="setname"> <xsl:value-of select="$Dept5"/> </xsl:with-param>
                    <xsl:with-param name="includesubsets"> <xsl:value-of select="$includeNestedDepartments"/> </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
        </svmm:staffQueries>
    </xsl:template>
    <!-- End template DepartmentMembers -->


    <!-- Begin template ManagerOfEmployee -->
    <xsl:template name="ManagerOfEmployee">
        <svmm:staffQueries>
            <xsl:attribute name="threshold"><xsl:value-of select="$Threshold"/></xsl:attribute>
            <svmm:intermediateResult>
                <xsl:attribute name="name">manager</xsl:attribute>
                <svmm:user>
                    <xsl:attribute name="id"><xsl:value-of select="staff:parameter[@id='EmployeeName']"/></xsl:attribute>
                    <xsl:attribute name="idType"><xsl:value-of select="$VMMUserIdType"/></xsl:attribute>
                    <svmm:resultEntity>
                         <xsl:attribute name="type"> <xsl:value-of select="$VMMUserEntityType"/>  </xsl:attribute>                 
                        <svmm:attribute> 
                            <xsl:attribute name="name"> <xsl:value-of select="$VMMUserManagerAttribute"/> </xsl:attribute>
                            <xsl:attribute name="destination">intermediate</xsl:attribute>            
                        </svmm:attribute>                     
                    </svmm:resultEntity>
                </svmm:user>
            </svmm:intermediateResult>
            <svmm:user>
                <xsl:attribute name="id">%manager%</xsl:attribute>
                <xsl:attribute name="idType">uniqueName</xsl:attribute>
                
                <xsl:call-template name="ResultEntitySpecForUserData"/>
            </svmm:user>
        </svmm:staffQueries>
    </xsl:template>
    <!-- End template ManagerOfEmployee -->


    <!-- Begin template ManagerOfEmployeeByUserID-->
    <xsl:template name="ManagerOfEmployeeByUserID">
        <svmm:staffQueries>
            <xsl:attribute name="threshold"><xsl:value-of select="$Threshold"/></xsl:attribute>
            <svmm:intermediateResult>
                <xsl:attribute name="name">manager</xsl:attribute>                
                <svmm:search>
                    <xsl:attribute name="searchExpression">//entities[@xsi:type='<xsl:value-of select="$VMMUserEntityType"/>' and <xsl:value-of select="$VMMUserIdAttribute"/>='<xsl:value-of select="staff:parameter[@id='EmployeeUserID']"/>']</xsl:attribute>
                      
                      <svmm:resultEntity>
                         <xsl:attribute name="type"> <xsl:value-of select="$VMMUserEntityType"/>  </xsl:attribute>                 
                        <svmm:attribute> 
                            <xsl:attribute name="name"> <xsl:value-of select="$VMMUserManagerAttribute"/> </xsl:attribute>
                            <xsl:attribute name="destination">intermediate</xsl:attribute>                
                        </svmm:attribute>                     
                    </svmm:resultEntity>                            
                </svmm:search>                                    
            </svmm:intermediateResult>
            <svmm:user>
                <xsl:attribute name="id">%manager%</xsl:attribute>
                <xsl:attribute name="idType"> <xsl:value-of select="$VMMUserIdType"/> </xsl:attribute>
                
                <xsl:call-template name="ResultEntitySpecForUserData"/>
            </svmm:user>
        </svmm:staffQueries>
    </xsl:template>
    <!-- End template ManagerOfEmployeeByUserID-->


    <!-- Begin template PersonSearch -->
    <xsl:template name="PersonSearch">
        <svmm:staffQueries>
            <xsl:attribute name="threshold"><xsl:value-of select="$Threshold"/></xsl:attribute>        
            <svmm:search>
                    <xsl:variable name="searchexpression">
                    //entities[@xsi:type='<xsl:value-of select="$VMMUserEntityType"/>'                     
                        
                        <xsl:if test="staff:parameter[@id='UserID']!=''">
                               and <xsl:value-of select="$PS_UserID"/>='<xsl:value-of select="staff:parameter[@id='UserID']"/>'
                        </xsl:if>
                        
                        <xsl:if test="staff:parameter[@id='Profile']!=''">
                               and <xsl:value-of select="$PS_Profile"/>='<xsl:value-of select="staff:parameter[@id='Profile']"/>'
                        </xsl:if>
                                                     
                        <xsl:if test="staff:parameter[@id='LastName']!=''">
                               and <xsl:value-of select="$PS_LastName"/>='<xsl:value-of select="staff:parameter[@id='LastName']"/>'
                        </xsl:if>
                        
                              <xsl:if test="staff:parameter[@id='FirstName']!=''">
                                     and <xsl:value-of select="$PS_FirstName"/>='<xsl:value-of select="staff:parameter[@id='FirstName']"/>'
                              </xsl:if>
                              
                              <xsl:if test="staff:parameter[@id='MiddleName']!=''">
                                     and <xsl:value-of select="$PS_MiddleName"/>='<xsl:value-of select="staff:parameter[@id='MiddleName']"/>'
                              </xsl:if>
                              
                              <xsl:if test="staff:parameter[@id='Email']!=''">
                                     and <xsl:value-of select="$PS_Email"/>='<xsl:value-of select="staff:parameter[@id='Email']"/>'
                              </xsl:if>          
                              
                              <xsl:if test="staff:parameter[@id='Company']!=''">
                                     and <xsl:value-of select="$PS_Company"/>='<xsl:value-of select="staff:parameter[@id='Company']"/>'
                              </xsl:if>
                              
                              <xsl:if test="staff:parameter[@id='DisplayName']!=''">
                                  and <xsl:value-of select="$PS_DisplayName"/>='<xsl:value-of select="staff:parameter[@id='DisplayName']"/>' 
                              </xsl:if>
                              
                          <xsl:if test="staff:parameter[@id='Assistant']!=''">
                              and <xsl:value-of select="$PS_Assistant"/>='<xsl:value-of select="staff:parameter[@id='Assistant']"/>' 
                          </xsl:if>
                          
                          <xsl:if test="staff:parameter[@id='Secretary']!=''">
                              and <xsl:value-of select="$PS_Secretary"/>='<xsl:value-of select="staff:parameter[@id='Secretary']"/>)' 
                          </xsl:if>
                          
                          <xsl:if test="staff:parameter[@id='Manager']!=''">
                              and <xsl:value-of select="$PS_Manager"/>='<xsl:value-of select="staff:parameter[@id='Manager']"/>'
                          </xsl:if>
                          
                          <xsl:if test="staff:parameter[@id='Department']!=''">
                              and <xsl:value-of select="$PS_Department"/>='<xsl:value-of select="staff:parameter[@id='Department']"/>'
                          </xsl:if>
                          
                          <xsl:if test="staff:parameter[@id='EmployeeID']!=''">
                              and <xsl:value-of select="$PS_EmployeeID"/>='<xsl:value-of select="staff:parameter[@id='EmployeeID']"/>'
                          </xsl:if>
                          
                          <xsl:if test="staff:parameter[@id='TaxPayerID']!=''">
                              and <xsl:value-of select="$PS_TaxPayerID"/>='<xsl:value-of select="staff:parameter[@id='TaxPayerID']"/>'
                          </xsl:if>
          
                          <xsl:if test="staff:parameter[@id='Phone']!=''">
                              and <xsl:value-of select="$PS_Phone"/>='<xsl:value-of select="staff:parameter[@id='Phone']"/>'
                          </xsl:if>

                          <xsl:if test="staff:parameter[@id='Fax']!=''">
                              and <xsl:value-of select="$PS_Fax"/>='<xsl:value-of select="staff:parameter[@id='Fax']"/>'
                          </xsl:if>

                          <xsl:if test="staff:parameter[@id='Gender']!=''">
                              and <xsl:value-of select="$PS_Gender"/>='<xsl:value-of select="staff:parameter[@id='Gender']"/>'
                          </xsl:if>

                          <xsl:if test="staff:parameter[@id='Timezone']!=''">
                              and <xsl:value-of select="$PS_Timezone"/>='<xsl:value-of select="staff:parameter[@id='Timezone']"/>'
                          </xsl:if>

                          <xsl:if test="staff:parameter[@id='PreferredLanguage']!=''">
                              and <xsl:value-of select="$PS_PreferredLanguage"/>='<xsl:value-of select="staff:parameter[@id='PreferredLanguage']"/>'
                          </xsl:if>                          
                        ]    
                    </xsl:variable>      
                    <xsl:attribute name="searchExpression"><xsl:value-of select="normalize-space($searchexpression)"/></xsl:attribute>

                <xsl:call-template name="ResultEntitySpecForUserData"/>        

            </svmm:search>
        </svmm:staffQueries>
    </xsl:template>
    <!-- End template PersonSearch -->


    <!-- Begin template GroupSearch -->
    <xsl:template name="GroupSearch">
        <svmm:staffQueries>
            <xsl:attribute name="threshold"><xsl:value-of select="$Threshold"/></xsl:attribute>
            <svmm:intermediateResult>
                <xsl:attribute name="name">groupname</xsl:attribute>            
                <svmm:search>
                    <xsl:variable name="searchexpression">
                        //entities[@xsi:type='<xsl:value-of select="$VMMGroupEntityType"/>'
                        <xsl:if test="staff:parameter[@id='GroupID']!=''">
                            and <xsl:value-of select="$GS_GroupID"/>='<xsl:value-of select="staff:parameter[@id='GroupID']"/>'
                        </xsl:if>
    
                              <xsl:if test="staff:parameter[@id='Type']!=''">
                                  and <xsl:value-of select="$GS_Type"/>='<xsl:value-of select="staff:parameter[@id='Type']"/>'
                              </xsl:if>
              
                              <xsl:if test="staff:parameter[@id='IndustryType']!=''">
                                  and <xsl:value-of select="$GS_IndustryType"/>='<xsl:value-of select="staff:parameter[@id='IndustryType']"/>'
                              </xsl:if>
              
                              <xsl:if test="staff:parameter[@id='BusinessType']!=''">
                                  and <xsl:value-of select="$GS_BusinessType"/>='<xsl:value-of select="staff:parameter[@id='BusinessType']"/>'
                              </xsl:if>
              
                              <xsl:if test="staff:parameter[@id='GeographicLocation']!=''">
                                  and <xsl:value-of select="$GS_GeographicLocation"/>='<xsl:value-of select="staff:parameter[@id='GeographicLocation']"/>'
                              </xsl:if>
              
                              <xsl:if test="staff:parameter[@id='Affiliates']!=''">
                                  and <xsl:value-of select="$GS_Affiliates"/>='<xsl:value-of select="staff:parameter[@id='Affiliates']"/>'
                              </xsl:if>
              
                              <xsl:if test="staff:parameter[@id='DisplayName']!=''">
                                  and <xsl:value-of select="$GS_DisplayName"/>='<xsl:value-of select="staff:parameter[@id='DisplayName']"/>'
                              </xsl:if>
              
                              <xsl:if test="staff:parameter[@id='Secretary']!=''">
                                  and <xsl:value-of select="$GS_Secretary"/>='<xsl:value-of select="staff:parameter[@id='Secretary']"/>'
                              </xsl:if>
              
                              <xsl:if test="staff:parameter[@id='Assistant']!=''">
                                  and <xsl:value-of select="$GS_Assistant"/>='<xsl:value-of select="staff:parameter[@id='Assistant']"/>'
                              </xsl:if>
              
                              <xsl:if test="staff:parameter[@id='Manager']!=''">
                                  and <xsl:value-of select="$GS_Manager"/>='<xsl:value-of select="staff:parameter[@id='Manager']"/>'
                              </xsl:if>
              
                              <xsl:if test="staff:parameter[@id='BusinessCategory']!=''">
                                  and <xsl:value-of select="$GS_BusinessCategory"/>='<xsl:value-of select="staff:parameter[@id='BusinessCategory']"/>'
                              </xsl:if>
              
                              <xsl:if test="staff:parameter[@id='ParentCompany']!=''">
                                  and <xsl:value-of select="$GS_ParentCompany"/>='<xsl:value-of select="staff:parameter[@id='ParentCompany']"/>'
                              </xsl:if>
                            ]    
                        </xsl:variable>      
                        <xsl:attribute name="searchExpression"><xsl:value-of select="normalize-space($searchexpression)"/></xsl:attribute>
    
                    <svmm:resultEntity>
                        <xsl:attribute name="type"> <xsl:value-of select="$VMMGroupEntityType"/>  </xsl:attribute>                 
                        <svmm:attribute> 
                            <xsl:attribute name="name">identifier</xsl:attribute>
                            <xsl:attribute name="destination">intermediate</xsl:attribute>                
                        </svmm:attribute>                     
                    </svmm:resultEntity>                                
                </svmm:search>
            </svmm:intermediateResult>
            <svmm:usersOfGroup>
                <xsl:attribute name="id">%groupname%</xsl:attribute>
                <xsl:attribute name="idType"> <xsl:value-of select="$VMMGroupIdType"/> </xsl:attribute>
                <xsl:attribute name="entityType"> <xsl:value-of select="$VMMGroupEntityType"/> </xsl:attribute>            
                <xsl:attribute name="recursive">yes</xsl:attribute>
    
                <xsl:call-template name="ResultEntitySpecForUserData"/>        
            </svmm:usersOfGroup>
        </svmm:staffQueries>
    </xsl:template>
    <!-- End template GroupSearch -->
          
    <!-- Begin template NativeQuery -->
    <xsl:template name="NativeQuery">
        <svmm:staffQueries>

            <xsl:attribute name="threshold"><xsl:value-of select="$Threshold"/></xsl:attribute>
                  <!-- Allow multiple Native Query templates-->
                  <xsl:choose>            
                    <!-- Template 'search' -->
                    <xsl:when test="staff:parameter[@id='QueryTemplate']='search'">
                                                                    
                    <xsl:choose>
                        <xsl:when test="staff:parameter[@id='AdditionalParameter1']='person'">
                              <svmm:search>
                            <xsl:attribute name="searchExpression">//entities[@xsi:type='<xsl:value-of select="$VMMUserEntityType"/>' and <xsl:value-of select="staff:parameter[@id='Query']"/> ]</xsl:attribute>

                            <xsl:if test="staff:parameter[@id='AdditionalParameter2']!=''">
                                <xsl:attribute name="searchBase">
                                    <xsl:value-of select="staff:parameter[@id='AdditionalParameter2']"/>
                                </xsl:attribute>
                            </xsl:if>                                                

                            <xsl:call-template name="ResultEntitySpecForUserData"/>
                        </svmm:search>
                    </xsl:when>
                                
                        <xsl:when test="staff:parameter[@id='AdditionalParameter1']='group'">
                        <svmm:intermediateResult>
                            <xsl:attribute name="name">groupname</xsl:attribute>                                                        
                            <svmm:search>
                                <xsl:attribute name="searchExpression">//entities[@xsi:type='<xsl:value-of select="$VMMGroupEntityType"/>' and <xsl:value-of select="staff:parameter[@id='Query']"/> ]</xsl:attribute>                                

                                <xsl:if test="staff:parameter[@id='AdditionalParameter2']!=''">
                                    <xsl:attribute name="searchBase">
                                        <xsl:value-of select="staff:parameter[@id='AdditionalParameter2']"/>
                                    </xsl:attribute>
                                </xsl:if>
                                
                                <svmm:resultEntity>
                                    <xsl:attribute name="type"> <xsl:value-of select="$VMMGroupEntityType"/>  </xsl:attribute>                 
                                    <svmm:attribute> 
                                        <xsl:attribute name="name">identifier</xsl:attribute>
                                        <xsl:attribute name="destination">intermediate</xsl:attribute>                
                                    </svmm:attribute>                     
                                </svmm:resultEntity>    
                            </svmm:search>
                        </svmm:intermediateResult>
                        
                        <svmm:usersOfGroup>
                            <xsl:attribute name="id">%groupname%</xsl:attribute>
                            <xsl:attribute name="idType"> <xsl:value-of select="$VMMGroupIdType"/> </xsl:attribute>
                            <xsl:attribute name="entityType"> <xsl:value-of select="$VMMGroupEntityType"/> </xsl:attribute>            
                                                        
                            <xsl:if test="staff:parameter[@id='AdditionalParameter2']!=''">
                                <xsl:attribute name="searchBase">
                                    <xsl:value-of select="staff:parameter[@id='AdditionalParameter2']"/>
                                </xsl:attribute>
                            </xsl:if>                                
                            
                            <xsl:choose>
                                <xsl:when test="staff:parameter[@id='AdditionalParameter3']='false'">
                                    <xsl:attribute name="recursive">no</xsl:attribute>
                                </xsl:when>
                                <xsl:when test="staff:parameter[@id='AdditionalParameter3']='true'">
                                    <xsl:attribute name="recursive">yes</xsl:attribute>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:attribute name="recursive">yes</xsl:attribute>                                
                                </xsl:otherwise>
                            </xsl:choose>
            
                            <xsl:call-template name="ResultEntitySpecForUserData"/>
                        </svmm:usersOfGroup>
                    </xsl:when>                                    
                                
                    <xsl:otherwise>
                        <svmm:unsupportedNativeQueryAdditionalParameter1Value> <xsl:value-of select="staff:parameter[@id='AdditionalParameter1']"/> </svmm:unsupportedNativeQueryAdditionalParameter1Value>
                              <xsl:message terminate="no">ERROR: Native query template 'search' is not supported by the VMM XSL transformation with usage type: <xsl:value-of select="staff:parameter[@id='AdditionalParameter1']"/>. Valid values are: person, group. Set one of these as AdditionalParameter1.</xsl:message>
                        </xsl:otherwise>                                        
                </xsl:choose>                        
            </xsl:when>                    
                                

            <!-- Template 'user' -->
            <xsl:when test="staff:parameter[@id='QueryTemplate']='user'">
                      <svmm:search>
                    <xsl:attribute name="searchExpression">//entities[@xsi:type='<xsl:value-of select="$VMMUserEntityType"/>' and <xsl:value-of select="staff:parameter[@id='Query']"/> ]</xsl:attribute>

                    <xsl:if test="staff:parameter[@id='AdditionalParameter2']!=''">
                        <xsl:attribute name="searchBase">
                            <xsl:value-of select="staff:parameter[@id='AdditionalParameter2']"/>
                        </xsl:attribute>
                    </xsl:if>                            

                    <xsl:call-template name="ResultEntitySpecForUserData"/>
                </svmm:search>            
            </xsl:when>
                    
            <!-- Template 'usersOfGroup' -->            
                <xsl:when test="staff:parameter[@id='QueryTemplate']='usersOfGroup'">
                    <svmm:intermediateResult>
                        <xsl:attribute name="name">groupname</xsl:attribute>                                                        
                        <svmm:search>
                            <xsl:attribute name="searchExpression">//entities[@xsi:type='<xsl:value-of select="$VMMGroupEntityType"/>' and <xsl:value-of select="staff:parameter[@id='Query']"/> ]</xsl:attribute>                                

                            <xsl:if test="staff:parameter[@id='AdditionalParameter2']!=''">
                                <xsl:attribute name="searchBase">
                                    <xsl:value-of select="staff:parameter[@id='AdditionalParameter2']"/>
                                </xsl:attribute>
                            </xsl:if>
                                
                            <svmm:resultEntity>
                                <xsl:attribute name="type"> <xsl:value-of select="$VMMGroupEntityType"/>  </xsl:attribute>                 
                                <svmm:attribute> 
                                    <xsl:attribute name="name">identifier</xsl:attribute>
                                    <xsl:attribute name="destination">intermediate</xsl:attribute>                
                                </svmm:attribute>                     
                            </svmm:resultEntity>    
                        </svmm:search>
                    </svmm:intermediateResult>
                        
                    <svmm:usersOfGroup>
                        <xsl:attribute name="id">%groupname%</xsl:attribute>
                        <xsl:attribute name="idType"> <xsl:value-of select="$VMMGroupIdType"/> </xsl:attribute>
                        <xsl:attribute name="entityType"> <xsl:value-of select="$VMMGroupEntityType"/> </xsl:attribute>
                        
                        <xsl:choose>
                            <xsl:when test="staff:parameter[@id='AdditionalParameter3']='false'">
                                <xsl:attribute name="recursive">no</xsl:attribute>
                            </xsl:when>
                            <xsl:when test="staff:parameter[@id='AdditionalParameter3']='true'">
                                <xsl:attribute name="recursive">yes</xsl:attribute>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:attribute name="recursive">yes</xsl:attribute>                                
                            </xsl:otherwise>
                        </xsl:choose>
            
                        <xsl:call-template name="ResultEntitySpecForUserData"/>
                    </svmm:usersOfGroup>                
                        
                </xsl:when>                        

                <xsl:otherwise>
                    <svmm:unsupportedNativeQueryQueryTemplateValue> <xsl:value-of select="staff:parameter[@id='QueryTemplate']"/> </svmm:unsupportedNativeQueryQueryTemplateValue>
                          <xsl:message terminate="no">ERROR: Native query template '<xsl:value-of select="staff:parameter[@id='QueryTemplate']"/>' is not supported by the VMM XSL transformation. Supported values are: 'search', 'user', 'usersOfGroup'.</xsl:message>
                    </xsl:otherwise>                        
            </xsl:choose>        
        </svmm:staffQueries>
                                
    </xsl:template>
    <!-- End template NativeQuery -->

    <!-- Begin template EmailForUsersByUserID -->
      <xsl:template name="EmailForUsersByUserID">
          <svmm:staffQueries>
            <xsl:attribute name="threshold"><xsl:value-of select="$Threshold"/></xsl:attribute>    
            <xsl:variable name="Name0">
                <xsl:value-of select="staff:parameter[@id='UserID']"/>
            </xsl:variable>
            <xsl:variable name="Name1">
                <xsl:value-of select="staff:parameter[@id='AlternativeID1']"/>
            </xsl:variable>
            <xsl:variable name="Name2">
                <xsl:value-of select="staff:parameter[@id='AlternativeID2']"/>
            </xsl:variable>

            <xsl:call-template name="GetUserEmailByID">
                <xsl:with-param name="username">
                    <xsl:value-of select="$Name0"/>
                </xsl:with-param>
            </xsl:call-template>
            <xsl:if test="$Name1!=''">
                <xsl:call-template name="GetUserEmailByID">
                    <xsl:with-param name="username">
                        <xsl:value-of select="$Name1"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$Name2!=''">
                <xsl:call-template name="GetUserEmailByID">
                    <xsl:with-param name="username">
                        <xsl:value-of select="$Name2"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:if>
        </svmm:staffQueries>
    </xsl:template>

    <xsl:template name="GetUserEmailByID">
        <xsl:param name="username">default</xsl:param>
        <svmm:search>
            <xsl:attribute name="searchExpression">//entities[@xsi:type='<xsl:value-of select="$VMMUserEntityType"/>' and <xsl:value-of select="$VMMUserIdAttribute"/>='<xsl:value-of select="$username"/>']</xsl:attribute>                    
                     
            <svmm:resultEntity>
                <xsl:attribute name="type"> <xsl:value-of select="$VMMUserEntityType"/>  </xsl:attribute>                 
                <svmm:attribute> 
                    <xsl:attribute name="name"> <xsl:value-of select="$VMMMailAttribute"/> </xsl:attribute>
                    <xsl:attribute name="destination">userID</xsl:attribute>                
                </svmm:attribute>                     
            </svmm:resultEntity>
                        
        </svmm:search>
    </xsl:template>
    <!-- End template EmailForUsersByUserID -->

</xsl:transform>
