#BEGIN COPYRIGHT
#*************************************************************************
#
# Licensed Materials - Property of IBM
# 5725-C94, 5725-C95, 5725-C96
# (C) Copyright IBM Corporation 2011, 2013. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
#*************************************************************************
#END COPYRIGHT

import os.path, sys
import jarray
import re

from java.lang import System
from java.lang import String
from java.lang import Long
from javax.management import ObjectName
from com.ibm.bpe.api import UTCDate

execfile(os.path.join(System.getProperty("was.install.root"), "ProcessChoreographer/admin/bpclib.py"))
__file__ = "listTemplates.py"

#*******************************************************************************************************
# globals
#*******************************************************************************************************
localNode = System.getProperty("local.node")

#*******************************************************************************************************
# print usage and error message, if any
#*******************************************************************************************************
def usage(errmsg = None):
  if errmsg:
    print
    print "ERROR: " + errmsg
  #endif
  print
  print "Usage: wsadmin -f " + __file__
  print "       [ ([-node <nodeName>] -server <serverName>) | (-cluster <clusterName>) ]"
  print "       [ -templateName <templateName> ]"
  print "       [ -applicationName <applicationName> ]"
  print "       [ -all | -active | -stopped |-invalid | -superseded ]"
  print "       [ -countInstances ]"
  print "       [ -groupBy (application | template) ]"
  print " "
  print "List process and task templates with additional details."
  print " "
  print "The result can be either grouped by template name or application name. The result"
  print "can be further restricted by specifying a template name or application name or"
  print "specific states."
  print " "
  print "The '-node', '-server', and '-cluster' parameters denote the Business Process "
  print "Choreographer configuration to work with. Specify the deployment target where Business Process "
  print "Choreographer is configured. The server or at least one cluster member must be running."
  print " "
  print "With the optional '-templateName' parameters only templates with the specified name are returned."
  print "With the optional '-applicationName' parameters only templates that belong to the specified application"
  print "are returned. "
  print
  print "With the optional '-countInstances' parameter the number of instances in an end state (finished, "
  print "terminated, failed) and the number of active instancs (all other states) is displayed. "
  print " "
  print "The '-groupBy' parameter can be used to either group the result by template name or application name."
  print " "
  print "The server or at least one cluster member must be running If the '-countInstances' or '-invalid' "
  print "parameters are used  "
  print " "
  print "The default values for the optional parameters are:"
  print "  node:               <local node> (" + localNode + ")"
#enddef

def printDetails(orderedByTemplate, orderedByApplication):
  templateKeys = [templateKey for templateKey in orderedByTemplate.keys()]
  templateWidth = reduce(lambda maxlen, len: max(maxlen, len), map(lambda templateKey: len(templateKey), templateKeys), 0) # get length of longest key
  applicationKeys = [applicationKey for applicationKey in orderedByApplication.keys()]
  templates =[]
  for key in applicationKeys:
    templates.extend(orderedByApplication[key])
  #endfor
  rowEntries = [template["namespace"] for template in templates]
  rowEntries.extend(templateKeys)
  rowEntries.extend(applicationKeys)
  title1 = "Template (name, valid from (UTC),"
  rowEntries.append(title1)
  title2 = "namespace, application name)"
  rowEntries.append(title2)
  firstColumnWidth = reduce(lambda maxlen, len: max(maxlen, len), map(lambda entry: len(entry), rowEntries), 0) # get length of longest key    
  print
  if not "superseded" in states and props["groupBy"] == "application":
    for key in applicationKeys:                                                                
      print
      print "Application '" + key + "'" 
      print
      print "%s %*s | Template | Active    | Finished" % (title1, firstColumnWidth - len(title1),"")
      print "%s %*s | state    | instances | instances" % (title2,firstColumnWidth - len(title2),"")
      print "-" * (firstColumnWidth + 37)
      for template in orderedByApplication[key]:
        applicationName = template["applicationName"]
        templateName = template["templateName"]
        validFrom = template["validFrom"]
        namespace = template["namespace"]
        state = template["state"]
        print "%s %*s |%9s | %9s | %8s" % (templateName, firstColumnWidth - len(templateName), "", "", "", "")
        print "%s %*s |%9s | %9s | %8s" % (validFrom, firstColumnWidth - len(validFrom), "", "", "", "")
        print "%s %*s |%9s | %9s | %8s" % (namespace, firstColumnWidth - len(namespace), "", state, template["active"], template["finished"])
        print "%s %*s |%9s | %9s | %8s" % (applicationName, firstColumnWidth - len(applicationName), "", "", "", "")
        print "-" * (firstColumnWidth + 37)
      #endfor
      print
    #endfor
  else:
    for key in templateKeys:
      print
      print "Template '" + key + "'"
      print
      print "%s %*s | Template | Active    | Finished" % (title1, firstColumnWidth - len(title1),"")
      print "%s %*s | state    | instances | instances" % (title2,firstColumnWidth - len(title2),"")
      print "-" * (firstColumnWidth + 37)
      for template in orderedByTemplate[key]:
        applicationName = template["applicationName"]
        templateName = template["templateName"]
        validFrom = template["validFrom"]
        namespace = template["namespace"]
        state = template["state"]
        print "%s %*s |%9s | %9s | %8s" % (templateName, firstColumnWidth - len(templateName), "", "", "", "")
        print "%s %*s |%9s | %9s | %8s" % (validFrom, firstColumnWidth - len(validFrom), "", "", "", "")
        print "%s %*s |%9s | %9s | %8s" % (namespace, firstColumnWidth - len(namespace), "", state, template["active"], template["finished"])
        print "%s %*s |%9s | %9s | %8s" % (applicationName, firstColumnWidth - len(applicationName), "", "", "", "")
        print "-" * (firstColumnWidth + 37)
      #endfor
    #endfor 
  #endif   
#enddef

def processMBeanResult (mbeanResult):
  result = []
  for template in mbeanResult:
    namespace = template[3]
    if not namespace:
      namespace = "n/a"
    #endif
    state = template[4]
    if ("active" in states and "STATE_STARTED" != state) or ("stopped" in states and "STATE_STOPPED" != state):
      continue
    #endif
    if state == "STATE_STARTED":
      state = "STARTED"
    else:
      state = "STOPPED"
    #endif
    templateMap = {"applicationName":template[0],"templateName":template[1],"validFrom":template[2],"namespace":namespace,"state":state,"active":"?","finished":"?"}
    if len(template) > 5:
     templateMap.update({"active":template[5],"finished":template[6]})
    #endelse
    result.append(templateMap)
  #endfor
  return result
#enddef

def sortResult (result):
  sortedTemplates= {}
  sortedApplications = {}
  for template in result:
    appName = template["applicationName"]
    templateName = template["templateName"]
    #if order by template sort different here
    if sortedTemplates.has_key(templateName):
      sortedTemplates.get(templateName).append(template)
    else:
      sortedTemplates.update({templateName:[template]})
    #endelse
    if sortedApplications.has_key(appName):
      sortedApplications.get(appName).append(template)
    else:
      sortedApplications.update({appName:[template]})
  #endfor
  if "superseded" in states:
    for key in sortedTemplates.keys():
      template = sortedTemplates[key]
      if len(template) == 1:
        del sortedTemplates[key]
      #endif
    #endfor
  #endif
  printDetails(sortedTemplates,sortedApplications)
#enddef

def getTemplatesFromConfig(type, applicationName, templateName):
  templates = []
  #list all process/task compoments
  components = AdminConfig.list(type).splitlines()
  pattern = re.compile(".*/([^/|]*)|")
  for component in components:
      appName = pattern.match(component).group(1)
      templName = AdminConfig.showAttribute(component,"name")
      # filter only templates that belong to the specified application
      if (applicationName and appName != applicationName) or (templateName and templName != templateName):
        continue
      #endif
      validFrom = AdminConfig.showAttribute(component,"validFrom")
      namespace = "n/a"
      if type == "TaskComponent":
        namespace = AdminConfig.showAttribute(component,"namespace")
      #endif
      stateManagement = AdminConfig.showAttribute(component,"stateManagement")
      templateState = AdminConfig.showAttribute(stateManagement,"initialState")
      if ("active" in states and "START" != templateState) or ("stopped" in states and "STOP" != templateState):
        continue
      #endif
      if templateState == "START":
        templateState = "STARTED"
      else:
        templateState = "STOPPED"
      #endif
      template = {"applicationName":appName,"templateName":templName,"validFrom":UTCDate(Long(validFrom)).toXsdString(),"namespace":namespace,"state":templateState,"active":"?","finished":"?"}
      templates.append(template)
      #endif
  #endfor
  return templates
#enddef

def getNumberOfInstances(mbean, method, applicationName, templateName):
  result = None
  if not mbean:
    print str(scope) + " is not available -- make sure the server or at least one cluster member is running."
  else:
    signature = ['java.lang.String','java.lang.String']
    params = [applicationName, templateName]
    #"getNumberOfProcessInstances"
    result = AdminControl.invoke_jmx(ObjectName(mbean), method , params, signature)
  #endelse
  return result
#enddef

def getInvalidTemplates (mbean, method, templateName):
  result = None
  if not mbean:
    print str(scope) + " is not available -- make sure the server or at least one cluster member is running."
  else:
    signature = ['java.lang.String']
    params = [templateName]
    #getInvalidProcessTemplates
    result = AdminControl.invoke_jmx(ObjectName(mbean), method, params, signature)
  #endElse
  return result
#enddef


# ----------------------
# parse the command line
props = {}
props.update({ "node": localNode, "server": "", "cluster": "" })
props.update({ "templateName": "", "applicationName":""})
props.update({ "all": None, "active": None, "stopped": None, "invalid": None, "superseded": None })
props.update({ "countInstances":None})
props.update({ "groupBy": "application"})          
try:
  props = wsadmin.parse(sys.argv, props)
except ValueError, error:
  usage(str(error))
  sys.exit(1)
#endtry

states = [key for key in props.keys() if props[key] and key in ["all", "active", "stopped", "invalid", "superseded"]]

#
# validate parameters
#
# -----------------------------------------------
# check if the scope is a valid deployment target
scope = Scope(nodeName = props["node"], serverName = props["server"], clusterName = props["cluster"])
if scope.convertToCluster():
  print "Warning: '" + props["server"] + "' is a member of cluster '" + scope.clusterName + "', adjusting scope to cluster."
#endif

if not scope.isDeploymentTarget():
  usage(str(scope) + " is not a valid deployment target.")
  sys.exit(1)
#endif

if not scope.isBPCDeploymentTarget("RUNTIME"):
  usage("Process Choreographer is not configured on " + scope.displayName() +"." )
  sys.exit(1)
#endif

if not props["server"] and not props["cluster"]:
  usage("One of the '-server' and '-cluster' parameters must be specified.")
  sys.exit(1)
#endif

if props["server"] and props["cluster"]:
  usage("Only one of the '-server' and '-cluster' parameters can be specified.")
  sys.exit(1)
#endif

if props["server"] and not props["node"]:
  usage("The '-node' parameter must be specified if '-server' is specified.")
  sys.exit(1)
#endif

if (props["groupBy"] and props["groupBy"] != "application" and props["groupBy"] != "template"):
  usage("Invalid value for the '-groupBy' parameter '" + props["groupBy"] + "', value must be either 'application' or 'template'.")
  sys.exit(1)
#endif

if("invalid" in states and props["countInstances"]):
  usage("Only one of the '-invalid' and '-countInstances' parameters can be specified.")
  sys.exit(1)
#endif

if("invalid" in states or props["countInstances"]):
  if wsadmin.getConnectionStatus() != WsAdmin.CONNECTED:
    usage(__file__ + " must run in connected mode, cannot use the '-conntype NONE' option.")
    sys.exit(1)
  #endif
#endif


if props["countInstances"]:
  bfmMBean = scope.lookupMBean("InternalProcessContainer")
  htmMbean = scope.lookupMBean("InternalTaskManager")
  result = []
  templates = getNumberOfInstances(bfmMBean,"getNumberOfProcessInstances",props["applicationName"],props["templateName"])
  result.extend(processMBeanResult(templates)) 
  templates = getNumberOfInstances(htmMbean,"getNumberOfTaskInstances",props["applicationName"],props["templateName"])
  result.extend(processMBeanResult(templates)) 
  if result:
    print
    print "*************************************************************************"
    if "superseded" in states:
      print "Templates with multiple versions found."
      print "If you want to identify application templates that could be uninstalled," 
      print "look for application versions that have zero instances. By removing "
      print "applications that are no longer needed, you can speed up how fast your" 
      print "server starts."
    else:
      print "Templates found."
    #endif
    print "*************************************************************************"
    sortResult(result)
  else:
    print
    print "No templates found."
    print
  #endif
elif "invalid" in states:
  bfmMBean = scope.lookupMBean("InternalProcessContainer")
  htmMbean = scope.lookupMBean("InternalTaskManager")
  result = []
  templates = getInvalidTemplates(bfmMBean, "getInvalidProcessTemplates" ,props["templateName"])
  result.extend(processMBeanResult(templates))
  templates = getInvalidTemplates(htmMbean, "getInvalidTaskTemplates" ,props["templateName"])
  result.extend(processMBeanResult(templates))
  if result:
    print
    print "*************************************************************************"
    print "Templates without a corresponding enterprise application found. Use the"
    print "deleteInvalidProcessTemplates.py and the deleteInvalidTaskTemplates.py"
    print "scripts to delete the templates."
    print "*************************************************************************"
    sortResult(result)
  else:
    print
    print "No invalid templates found."
    print
  #endif
else:
  result = []
  templates = getTemplatesFromConfig("ProcessComponent",props["applicationName"],props["templateName"])
  result.extend(templates)
  templates = getTemplatesFromConfig("TaskComponent",props["applicationName"],props["templateName"])
  result.extend(templates)
  if result:
    print
    print "************************************************************************"
    if "superseded" in states:
      print "Templates with multiple versions found."
      print "If you want to identify application templates that could be uninstalled," 
      print "look for application versions that have zero instances. By removing "
      print "applications that are no longer needed, you can speed up how fast your" 
      print "server starts."
    else:
      print "Templates found."
    #endif
    print "Use the '-countInstances parameter to display the number of active and "
    print "finished instances for each template."
    print "*************************************************************************"
    sortResult(result)
  else:
    print
    print "No templates found."
    print
  #endif
#endif



