#BEGIN COPYRIGHT
#*************************************************************************
#
# Licensed Materials - Property of IBM
# 5725-C94, 5725-C95, 5725-C96
# (C) Copyright IBM Corporation 2006, 2013. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
#*************************************************************************
#END COPYRIGHT

import os.path, sys

from java.lang import System

execfile(os.path.join(System.getProperty("was.install.root"), "ProcessChoreographer/admin/bpclib.py"))
__file__ = "setStateObserver.py"

#*******************************************************************************************************
# print usage and error message, if any
#*******************************************************************************************************
def usage(errmsg = None):
  if errmsg:
    print
    print "ERROR: " + errmsg
  #endif
  print
  print "Usage: wsadmin -f setStateObserver.py"
  print "       ( [-node <nodeName>] -server <serverName>) | (-cluster <clusterName>)"
  print "       ( ( -enable | -disable ) <stateObserver(s)> )"
  print "       [ ( -bfm | -htm ) ]"
  print
  print "Enables or disables state observers for Business Process Choreographer where"
  print "<stateObserver(s)> denotes a semicolon-separated list of state observers."
  print
  print "The well-known state observers for audit logging are 'CEI' and 'AuditLog' for "
  print "Business Flow Manager and Human Task Manager and 'TaskHistory' for Human Task Manager."
  print
  print "The default values for the optional parameters are:"
  print "  node:               <local node> ("+localNode+")"
#enddef



def setStateObserver(component, scope, enable, disable):
  oldsops = AdminTask.listBPCStateObservers(scope,"-"+component+" true")
  if (oldsops == "[]"):
    oldsops = []
  else:
    sysEnv=java.lang.System.getProperties()
    lineSep=sysEnv["line.separator"]
    oldsops = oldsops.replace(lineSep,";")
    oldsops = oldsops.split(";")
  #endIf
  if (disable == ""):
    disable = []
  else:
    disable = disable.split(";")
  #endIf
  if (enable == ""):
    newsops = []
  else:
    newsops = enable.split(";")
  #endIf
  for todisable in disable:
      AdminTask.removeBPCStateObserver(scope,"-"+component+" true -stateObserver "+todisable)
  #endFor
  for toenable in newsops:
      AdminTask.addBPCStateObserver(scope,"-"+component+" true -stateObserver "+toenable)
  #endFor
  for oldsop in oldsops:
    if (oldsop not in newsops and oldsop not in disable):
      newsops.append(oldsop)
    #endIf
  #endFor
  if (enable == "" and disable == []):
    print component + " state observers for " + scope + " are '" + ";".join(oldsops) + "'."
  else:
    print "Changing " + component + " state observers for " + scope + " from '" + ";".join(oldsops) + "' to '" + ";".join(newsops) + "'."
  #endIf
#endDef


#*******************************************************************************************************
# Parse command line
#*******************************************************************************************************
localNode = java.lang.System.getProperty ( "local.node" )
localCell = java.lang.System.getProperty ( "local.cell" )
nodeName  = localNode

argerr = ""
clusterName = ""
serverName = ""
enable = ""
disable = ""
mode = "bfm_and_htm"

argc = len(sys.argv)

i = 0
while ( i < argc ):
  arg = sys.argv[i]
  if (arg == "-node"):
    i = i+1;
    if (i < argc):
      nodeName = sys.argv[i]
    else:
      argerr = "Missing argument for '-node' parameter"
    #endElse
  elif (arg == "-server"):
    i = i+1;
    if (i < argc):
      serverName = sys.argv[i]
    else:
      argerr = "Missing argument for '-server' parameter"
    #endElse
  elif (arg == "-cluster"):
    i = i+1;
    if (i < argc):
      clusterName = sys.argv[i]
    else:
      argerr = "Missing argument for '-cluster' parameter"
    #endElse
  elif (arg == "-enable"):
    i = i+1;
    if (i < argc):
      enable = sys.argv[i]
    else:
      argerr = "Missing argument for '-enable' parameter"
    #endElse
  elif (arg == "-disable"):
    i = i+1;
    if (i < argc):
      disable = sys.argv[i]
    else:
      argerr = "Missing argument for '-disable' parameter"
    #endElse
  elif (arg == "-bfm"):
    mode = "bfm_only"
  elif (arg == "-htm"):
    mode = "htm_only"
  else:
    argerr = "Invalid command line argument: "+arg
    break
  #endElse
  i += 1
#endWhile

if (argerr == ""):
  if ( (len(serverName)>0) + (len(clusterName)>0) != 1 ):
     argerr="Exactly one of the '-server' and '-cluster' command line option must be specified"
  #endIf
#endIf

if ( (argerr != "") or (argc==0)  ):
  usage(argerr)
  sys.exit(1)
#endIf

scope = Scope(nodeName = nodeName, serverName = serverName, clusterName = clusterName)
if scope.convertToCluster():
  print "Warning: '" + serverName + "' is a member of cluster '" + scope.clusterName + "', adjusting scope to cluster."
#endif

if not scope.isDeploymentTarget():
  usage(str(scope) + " is not a valid deployment target.")
  sys.exit(1)
#endif

if not scope.isBPCDeploymentTarget("RUNTIME"):
  usage("Process Choreographer is not configured on " + scope.displayName() +"." )
  sys.exit(1)
#endif


if ( serverName ):
  server = AdminConfig.getid("/Cell:"+localCell+"/Node:"+nodeName+"/Server:"+serverName+"/")
  if (mode != "htm_only"):
    setStateObserver("bfm", server, enable, disable)
  #endIf
  if (mode != "bfm_only"):
    setStateObserver("htm", server, enable, disable)
  #endIf
else:
  cluster = AdminConfig.getid("/Cell:"+localCell+"/ServerCluster:"+clusterName+"/" )
  if (mode != "htm_only"):
    setStateObserver("bfm", cluster, enable, disable)
  #endIf
  if (mode != "bfm_only"):
    setStateObserver("htm", cluster, enable, disable)
  #endIf
#endElse

if (enable != "" or disable != ""):
  AdminConfig.save()
