-- *****************************************************************
--
-- Licensed Materials - Property of IBM
-- 5725-C94, 5725-C95, 5725-C96
-- (C) Copyright IBM Corporation 2006, 2013. All Rights Reserved.
-- US Government Users Restricted Rights- Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
-- *****************************************************************
-- Scriptfile to create schema (tables) for DB2 z/OS
----------------------------------------------------------------------


-------------------
-- Create tables --
-------------------

CREATE TABLE @SCHEMA@.SCHEMA_VERSION
(
 SCHEMA_VERSION INTEGER NOT NULL ,
 DATA_MIGRATION SMALLINT NOT NULL ,
  PRIMARY KEY (SCHEMA_VERSION)
) IN @DB_NAME@.TEMPL01;

CREATE UNIQUE INDEX 
  @SCHEMA@.SCHEMA_P
  ON @SCHEMA@.SCHEMA_VERSION
(   
  SCHEMA_VERSION
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
(
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 NAME VARCHAR(220) NOT NULL ,
 DEFINITION_NAME VARCHAR(220) ,
 DISPLAY_NAME VARCHAR(64) ,
 APPLICATION_NAME VARCHAR(220) ,
 DISPLAY_ID INTEGER NOT NULL ,
 DISPLAY_ID_EXT VARCHAR(32) ,
 DESCRIPTION VARCHAR(254) ,
 DOCUMENTATION CLOB(4096) ,
 EXECUTION_MODE INTEGER NOT NULL ,
 IS_SHARED SMALLINT NOT NULL ,
 IS_AD_HOC SMALLINT NOT NULL ,
 STATE INTEGER NOT NULL ,
 VALID_FROM TIMESTAMP NOT NULL ,
 TARGET_NAMESPACE VARCHAR(250) ,
 CREATED TIMESTAMP NOT NULL ,
 AUTO_DELETE SMALLINT NOT NULL ,
 EXTENDED_AUTO_DELETE INTEGER NOT NULL ,
 VERSION VARCHAR(32) ,
 SCHEMA_VERSION INTEGER NOT NULL ,
 ABSTRACT_BASE_NAME VARCHAR(254) ,
 S_BEAN_LOOKUP_NAME VARCHAR(254) ,
 S_BEAN60_LOOKUP_NAME VARCHAR(254) ,
 E_BEAN_LOOKUP_NAME VARCHAR(254) ,
 PROCESS_BASE_NAME VARCHAR(254) ,
 S_BEAN_HOME_NAME VARCHAR(254) ,
 E_BEAN_HOME_NAME VARCHAR(254) ,
 BPEWS_UTID CHAR(16) FOR BIT DATA ,
 WPC_UTID CHAR(16) FOR BIT DATA ,
 BPMN_UTID CHAR(16) FOR BIT DATA ,
 BUSINESS_RELEVANCE SMALLINT NOT NULL ,
 ADMINISTRATOR_QTID CHAR(16) FOR BIT DATA ,
 READER_QTID CHAR(16) FOR BIT DATA ,
 A_TKTID CHAR(16) FOR BIT DATA ,
 A_TKTIDFOR_ACTS CHAR(16) FOR BIT DATA ,
 COMPENSATION_SPHERE INTEGER NOT NULL ,
 AUTONOMY INTEGER NOT NULL ,
 CAN_CALL SMALLINT NOT NULL ,
 CAN_INITIATE SMALLINT NOT NULL ,
 CONTINUE_ON_ERROR SMALLINT NOT NULL ,
 IGNORE_MISSING_DATA INTEGER NOT NULL ,
 EAR_VERSION INTEGER NOT NULL ,
 LANGUAGE_TYPE INTEGER NOT NULL ,
 DEPLOY_TYPE INTEGER NOT NULL ,
 MESSAGE_DIGEST VARCHAR(20) FOR BIT DATA ,
 CUSTOM_TEXT1 VARCHAR(64) ,
 CUSTOM_TEXT2 VARCHAR(64) ,
 CUSTOM_TEXT3 VARCHAR(64) ,
 CUSTOM_TEXT4 VARCHAR(64) ,
 CUSTOM_TEXT5 VARCHAR(64) ,
 CUSTOM_TEXT6 VARCHAR(64) ,
 CUSTOM_TEXT7 VARCHAR(64) ,
 CUSTOM_TEXT8 VARCHAR(64) ,
  PRIMARY KEY (PTID)
) IN @DB_NAME@.TEMP802;

CREATE UNIQUE INDEX 
  @SCHEMA@.PROCESS_TEMPLATE_B_P
  ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
  PTID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column DOCUMENTATION
CREATE AUX TABLE @SCHEMA@.AT213401
   IN @DB_NAME@.AS213401
   STORES @SCHEMA@.PROCESS_TEMPLATE_B_T COLUMN DOCUMENTATION;
-- auxiliary index for LOB column DOCUMENTATION
CREATE UNIQUE INDEX @SCHEMA@.AT213401I
  ON @SCHEMA@.AT213401
   USING STOGROUP @STOGRP@;


CREATE UNIQUE INDEX 
  @SCHEMA@.PTB_NAME_VALID
  ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
  NAME, 
  VALID_FROM
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.PTB_NAME_VF_STATE
  ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
  NAME, 
  VALID_FROM, 
  STATE, 
  PTID
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.PTB_TOP_APP
  ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
  APPLICATION_NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.PTB_STATE_PTID
  ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
  STATE, 
  PTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.PTB_NAME
  ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
  PTID, 
  NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.PTB_SBLKN
  ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
  S_BEAN60_LOOKUP_NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.PC_VERSION_TEMPLATE_T
(
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 SNAPSHOT_ID VARCHAR(254) NOT NULL ,
 SNAPSHOT_NAME VARCHAR(254) ,
 TOP_LEVEL_TOOLKIT_ACRONYM VARCHAR(7) ,
 TOP_LEVEL_TOOLKIT_NAME VARCHAR(254) ,
 TRACK_NAME VARCHAR(254) ,
 PROCESS_APP_NAME VARCHAR(254) ,
 PROCESS_APP_ACRONYM VARCHAR(7) ,
 TOOLKIT_SNAPSHOT_ID VARCHAR(254) ,
 TOOLKIT_SNAPSHOT_NAME VARCHAR(254) ,
 TOOLKIT_NAME VARCHAR(254) ,
 TOOLKIT_ACRONYM VARCHAR(7) ,
 IS_TIP SMALLINT NOT NULL ,
  PRIMARY KEY (CONTAINMENT_CONTEXT_ID)
) IN @DB_NAME@.TEMPL64;

CREATE UNIQUE INDEX 
  @SCHEMA@.PC_VERSION_TEMPLATE_P
  ON @SCHEMA@.PC_VERSION_TEMPLATE_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.PCV_SPID
  ON @SCHEMA@.PC_VERSION_TEMPLATE_T
(   
  SNAPSHOT_ID
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.PCV_PAN
  ON @SCHEMA@.PC_VERSION_TEMPLATE_T
(   
  PROCESS_APP_NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.PCV_PAA
  ON @SCHEMA@.PC_VERSION_TEMPLATE_T
(   
  PROCESS_APP_ACRONYM
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.PCV_TLTA
  ON @SCHEMA@.PC_VERSION_TEMPLATE_T
(   
  TOP_LEVEL_TOOLKIT_ACRONYM
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T
(
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 ATTR_KEY VARCHAR(220) NOT NULL ,
 VALUE VARCHAR(254) ,
 DISPLAY_ID_EXT VARCHAR(32) ,
  PRIMARY KEY (PTID, ATTR_KEY)
) IN @DB_NAME@.TEMPL42;

CREATE UNIQUE INDEX 
  @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_P
  ON @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T
(   
  PTID, 
  ATTR_KEY
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.PTAB_PTID
  ON @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.SCOPE_TEMPLATE_B_T
(
 STID CHAR(16) FOR BIT DATA NOT NULL ,
 PARENT_STID CHAR(16) FOR BIT DATA ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 COMP_HANDLER_ATID CHAR(16) FOR BIT DATA ,
 IMPLEMENTS_EHTID CHAR(16) FOR BIT DATA ,
 FOR_EACH_ATID CHAR(16) FOR BIT DATA ,
 DISPLAY_ID INTEGER NOT NULL ,
 DISPLAY_ID_EXT VARCHAR(32) ,
 ISOLATED SMALLINT NOT NULL ,
 IS_COMPENSABLE SMALLINT NOT NULL ,
 BUSINESS_RELEVANCE SMALLINT NOT NULL ,
 A_TKTID CHAR(16) FOR BIT DATA ,
 IS_IMPLICIT SMALLINT NOT NULL ,
 HAS_COMPENSATION_HANDLER SMALLINT NOT NULL ,
  PRIMARY KEY (STID)
) IN @DB_NAME@.TEMPL03;

CREATE UNIQUE INDEX 
  @SCHEMA@.SCOPE_TEMPLATE_B_P
  ON @SCHEMA@.SCOPE_TEMPLATE_B_T
(   
  STID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.ST_PTID
  ON @SCHEMA@.SCOPE_TEMPLATE_B_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.SERVICE_TEMPLATE_B_T
(
 VTID CHAR(16) FOR BIT DATA NOT NULL ,
 PORT_TYPE_NAME VARCHAR(254) NOT NULL ,
 PORT_TYPE_UTID CHAR(16) FOR BIT DATA NOT NULL ,
 OPERATION_NAME VARCHAR(254) NOT NULL ,
 NAME VARCHAR(254) ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 TRANSACTION_BEHAVIOR INTEGER NOT NULL ,
 IS_TWO_WAY SMALLINT NOT NULL ,
 NUMBER_OF_RECEIVE_ACTS INTEGER NOT NULL ,
  PRIMARY KEY (VTID)
) IN @DB_NAME@.TEMPL04;

CREATE UNIQUE INDEX 
  @SCHEMA@.SERVICE_TEMPLATE_B_P
  ON @SCHEMA@.SERVICE_TEMPLATE_B_T
(   
  VTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.VT_VTID_PTUTID
  ON @SCHEMA@.SERVICE_TEMPLATE_B_T
(   
  VTID, 
  PORT_TYPE_UTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.VT_PTID
  ON @SCHEMA@.SERVICE_TEMPLATE_B_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ACTIVITY_SERVICE_TEMPLATE_B_T
(
 ATID CHAR(16) FOR BIT DATA NOT NULL ,
 VTID CHAR(16) FOR BIT DATA NOT NULL ,
 KIND INTEGER NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 PARTNER_LINK_NAME VARCHAR(220) ,
 INPUT_CTID CHAR(16) FOR BIT DATA ,
 OUTPUT_CTID CHAR(16) FOR BIT DATA ,
 LINK_ORDER_NUMBER INTEGER ,
 POTENTIAL_OWNER_QTID CHAR(16) FOR BIT DATA ,
 READER_QTID CHAR(16) FOR BIT DATA ,
 EDITOR_QTID CHAR(16) FOR BIT DATA ,
 TKTID CHAR(16) FOR BIT DATA ,
 UNDO_MSG_TEMPLATE BLOB(1073741823) ,
 DISPLAY_ID_EXT VARCHAR(32) ,
  PRIMARY KEY (ATID, VTID, KIND)
) IN @DB_NAME@.TEMPL05;

CREATE UNIQUE INDEX 
  @SCHEMA@.ACTIVITY_SERVICE_TEMPLATE_B_P
  ON @SCHEMA@.ACTIVITY_SERVICE_TEMPLATE_B_T
(   
  ATID, 
  VTID, 
  KIND
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column UNDO_MSG_TEMPLATE
CREATE AUX TABLE @SCHEMA@.AT213402
   IN @DB_NAME@.AS213402
 STORES @SCHEMA@.ACTIVITY_SERVICE_TEMPLATE_B_T COLUMN
 UNDO_MSG_TEMPLATE;
-- auxiliary index for LOB column UNDO_MSG_TEMPLATE
CREATE UNIQUE INDEX @SCHEMA@.AT213402I
  ON @SCHEMA@.AT213402
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.AST_PTID
  ON @SCHEMA@.ACTIVITY_SERVICE_TEMPLATE_B_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.SERVICE_LOCATION_TEMPLATE_B_T
(
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 VTID CHAR(16) FOR BIT DATA NOT NULL ,
 MODULE_NAME VARCHAR(220) NOT NULL ,
 EXPORT_NAME CLOB(4096) ,
 COMPONENT_NAME CLOB(4096) NOT NULL ,
  PRIMARY KEY (PTID, VTID)
) IN @DB_NAME@.TEMPL06;

CREATE UNIQUE INDEX 
  @SCHEMA@.SERVICE_LOCATION_TEMPLATE_B_P
  ON @SCHEMA@.SERVICE_LOCATION_TEMPLATE_B_T
(   
  PTID, 
  VTID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column EXPORT_NAME
CREATE AUX TABLE @SCHEMA@.AT213403
   IN @DB_NAME@.AS213403
   STORES @SCHEMA@.SERVICE_LOCATION_TEMPLATE_B_T COLUMN EXPORT_NAME;
-- auxiliary index for LOB column EXPORT_NAME
CREATE UNIQUE INDEX @SCHEMA@.AT213403I
  ON @SCHEMA@.AT213403
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column COMPONENT_NAME
CREATE AUX TABLE @SCHEMA@.AT213404
   IN @DB_NAME@.AS213404
 STORES @SCHEMA@.SERVICE_LOCATION_TEMPLATE_B_T COLUMN COMPONENT_NAME;
-- auxiliary index for LOB column COMPONENT_NAME
CREATE UNIQUE INDEX @SCHEMA@.AT213404I
  ON @SCHEMA@.AT213404
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.SLT_PTID
  ON @SCHEMA@.SERVICE_LOCATION_TEMPLATE_B_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.SERVICE_FAULT_TEMPLATE_B_T
(
 VTID CHAR(16) FOR BIT DATA NOT NULL ,
 FAULT_NAME VARCHAR(220) NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 MESSAGE_DEFINITION BLOB(3900K) NOT NULL ,
  PRIMARY KEY (VTID, FAULT_NAME)
) IN @DB_NAME@.TEMPL07;

CREATE UNIQUE INDEX 
  @SCHEMA@.SERVICE_FAULT_TEMPLATE_B_P
  ON @SCHEMA@.SERVICE_FAULT_TEMPLATE_B_T
(   
  VTID, 
  FAULT_NAME
) NOT PADDED
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column MESSAGE_DEFINITION
CREATE AUX TABLE @SCHEMA@.AT213405
   IN @DB_NAME@.AS213405
 STORES @SCHEMA@.SERVICE_FAULT_TEMPLATE_B_T COLUMN
 MESSAGE_DEFINITION;
-- auxiliary index for LOB column MESSAGE_DEFINITION
CREATE UNIQUE INDEX @SCHEMA@.AT213405I
  ON @SCHEMA@.AT213405
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.SFT_PTID
  ON @SCHEMA@.SERVICE_FAULT_TEMPLATE_B_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
(
 ATID CHAR(16) FOR BIT DATA NOT NULL ,
 PARENT_STID CHAR(16) FOR BIT DATA ,
 IMPLEMENTS_STID CHAR(16) FOR BIT DATA ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 IMPLEMENTS_EHTID CHAR(16) FOR BIT DATA ,
 ENCLOSING_FOR_EACH_ATID CHAR(16) FOR BIT DATA ,
 IS_EVENT_HANDLER_END_ACTIVITY SMALLINT NOT NULL ,
 KIND INTEGER NOT NULL ,
 NAME VARCHAR(220) ,
 DISPLAY_NAME VARCHAR(64) ,
 JOIN_CONDITION INTEGER NOT NULL ,
 JOIN_CONDITION_NAME VARCHAR(254) ,
 EXIT_CONDITION INTEGER NOT NULL ,
 EXIT_CONDITION_NAME VARCHAR(254) ,
 EXIT_CONDITION_EXECUTE_AT INTEGER NOT NULL ,
 NUMBER_OF_LINKS INTEGER NOT NULL ,
 SUPPRESS_JOIN_FAILURE SMALLINT NOT NULL ,
 SOURCES_TYPE INTEGER NOT NULL ,
 TARGETS_TYPE INTEGER NOT NULL ,
 CREATE_INSTANCE SMALLINT ,
 IS_END_ACTIVITY SMALLINT NOT NULL ,
 FAULT_NAME VARCHAR(254) ,
 HAS_OWN_FAULT_HANDLER SMALLINT NOT NULL ,
 COMPLEX_BEGIN_ATID CHAR(16) FOR BIT DATA ,
 CORRESPONDING_END_ATID CHAR(16) FOR BIT DATA ,
 PARENT_ATID CHAR(16) FOR BIT DATA ,
 HAS_CROSSING_LINK SMALLINT ,
 SCRIPT_NAME VARCHAR(254) ,
 AFFILIATION INTEGER NOT NULL ,
 TRANSACTION_BEHAVIOR INTEGER NOT NULL ,
 DESCRIPTION VARCHAR(254) ,
 DOCUMENTATION CLOB(4096) ,
 BUSINESS_RELEVANCE SMALLINT NOT NULL ,
 FAULT_NAME_UTID CHAR(16) FOR BIT DATA ,
 FAULT_VARIABLE_CTID CHAR(16) FOR BIT DATA ,
 DISPLAY_ID INTEGER NOT NULL ,
 DISPLAY_ID_EXT VARCHAR(32) ,
 IS_TRANSACTIONAL SMALLINT NOT NULL ,
 CONTINUE_ON_ERROR SMALLINT NOT NULL ,
 ENCLOSED_FTID CHAR(16) FOR BIT DATA ,
 EXPRESSION CLOB(3900K) ,
 EXIT_EXPRESSION CLOB(3900K) ,
 HAS_INBOUND_LINK SMALLINT NOT NULL ,
 COMPENSATION_STID CHAR(16) FOR BIT DATA ,
 COMPENSATION_ATID CHAR(16) FOR BIT DATA ,
 A_TKTID CHAR(16) FOR BIT DATA ,
 IS_IN_GFLOW SMALLINT NOT NULL ,
 IS_REGION_BEGIN SMALLINT NOT NULL ,
 CORRESPONDING_IORATID CHAR(16) FOR BIT DATA ,
 IS_GFLOW SMALLINT NOT NULL ,
 CUSTOM_IMPLEMENTATION BLOB(3900K) ,
 EXPRESSION_MAP BLOB(3900K) ,
 EXIT_EXPRESSION_MAP BLOB(3900K) ,
 GENERATED_BY VARCHAR(220) ,
 GATEWAY_DIRECTION INTEGER NOT NULL ,
 IS_INTERRUPTING SMALLINT NOT NULL ,
 ORDER_NUMBER INTEGER NOT NULL ,
  PRIMARY KEY (ATID)
) IN @DB_NAME@.TEMP808;

CREATE UNIQUE INDEX 
  @SCHEMA@.ACTIVITY_TEMPLATE_B_P
  ON @SCHEMA@.ACTIVITY_TEMPLATE_B_T
(   
  ATID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column DOCUMENTATION
CREATE AUX TABLE @SCHEMA@.AT213406
   IN @DB_NAME@.AS213406
   STORES @SCHEMA@.ACTIVITY_TEMPLATE_B_T COLUMN DOCUMENTATION;
-- auxiliary index for LOB column DOCUMENTATION
CREATE UNIQUE INDEX @SCHEMA@.AT213406I
  ON @SCHEMA@.AT213406
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column EXPRESSION
CREATE AUX TABLE @SCHEMA@.AT213407
   IN @DB_NAME@.AS213407
   STORES @SCHEMA@.ACTIVITY_TEMPLATE_B_T COLUMN EXPRESSION;
-- auxiliary index for LOB column EXPRESSION
CREATE UNIQUE INDEX @SCHEMA@.AT213407I
  ON @SCHEMA@.AT213407
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column EXIT_EXPRESSION
CREATE AUX TABLE @SCHEMA@.AT213408
   IN @DB_NAME@.AS213408
   STORES @SCHEMA@.ACTIVITY_TEMPLATE_B_T COLUMN EXIT_EXPRESSION;
-- auxiliary index for LOB column EXIT_EXPRESSION
CREATE UNIQUE INDEX @SCHEMA@.AT213408I
  ON @SCHEMA@.AT213408
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column CUSTOM_IMPLEMENTATION
CREATE AUX TABLE @SCHEMA@.AT213409
   IN @DB_NAME@.AS213409
   STORES @SCHEMA@.ACTIVITY_TEMPLATE_B_T COLUMN CUSTOM_IMPLEMENTATION;
-- auxiliary index for LOB column CUSTOM_IMPLEMENTATION
CREATE UNIQUE INDEX @SCHEMA@.AT213409I
  ON @SCHEMA@.AT213409
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column EXPRESSION_MAP
CREATE AUX TABLE @SCHEMA@.AT21340A
   IN @DB_NAME@.AS21340A
   STORES @SCHEMA@.ACTIVITY_TEMPLATE_B_T COLUMN EXPRESSION_MAP;
-- auxiliary index for LOB column EXPRESSION_MAP
CREATE UNIQUE INDEX @SCHEMA@.AT21340AI
  ON @SCHEMA@.AT21340A
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column EXIT_EXPRESSION_MAP
CREATE AUX TABLE @SCHEMA@.AT21340B
   IN @DB_NAME@.AS21340B
   STORES @SCHEMA@.ACTIVITY_TEMPLATE_B_T COLUMN EXIT_EXPRESSION_MAP;
-- auxiliary index for LOB column EXIT_EXPRESSION_MAP
CREATE UNIQUE INDEX @SCHEMA@.AT21340BI
  ON @SCHEMA@.AT21340B
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.ATB_PTID
  ON @SCHEMA@.ACTIVITY_TEMPLATE_B_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.ATB_NAME
  ON @SCHEMA@.ACTIVITY_TEMPLATE_B_T
(   
  NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.ATB_KIND_BR_NAME
  ON @SCHEMA@.ACTIVITY_TEMPLATE_B_T
(   
  KIND, 
  BUSINESS_RELEVANCE, 
  NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ALARM_TEMPLATE_B_T
(
 XTID CHAR(16) FOR BIT DATA NOT NULL ,
 ATID CHAR(16) FOR BIT DATA NOT NULL ,
 KIND INTEGER NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 EXPRESSION BLOB(3900K) ,
 EXPRESSION_NAME VARCHAR(254) ,
 DURATION VARCHAR(254) ,
 CALENDAR VARCHAR(254) ,
 CALENDAR_JNDI_NAME VARCHAR(254) ,
 REPEAT_KIND INTEGER NOT NULL ,
 REPEAT_EXPRESSION BLOB(3900K) ,
 REPEAT_EXP_NAME VARCHAR(254) ,
 ON_ALARM_ORDER_NUMBER INTEGER ,
 EXPRESSION_MAP BLOB(3900K) ,
 REPEAT_EXPRESSION_MAP BLOB(3900K) ,
 DISPLAY_ID_EXT VARCHAR(32) ,
  PRIMARY KEY (XTID)
) IN @DB_NAME@.TEMPL09;

CREATE UNIQUE INDEX 
  @SCHEMA@.ALARM_TEMPLATE_B_P
  ON @SCHEMA@.ALARM_TEMPLATE_B_T
(   
  XTID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column EXPRESSION
CREATE AUX TABLE @SCHEMA@.AT21340C
   IN @DB_NAME@.AS21340C
   STORES @SCHEMA@.ALARM_TEMPLATE_B_T COLUMN EXPRESSION;
-- auxiliary index for LOB column EXPRESSION
CREATE UNIQUE INDEX @SCHEMA@.AT21340CI
  ON @SCHEMA@.AT21340C
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column REPEAT_EXPRESSION
CREATE AUX TABLE @SCHEMA@.AT21340D
   IN @DB_NAME@.AS21340D
   STORES @SCHEMA@.ALARM_TEMPLATE_B_T COLUMN REPEAT_EXPRESSION;
-- auxiliary index for LOB column REPEAT_EXPRESSION
CREATE UNIQUE INDEX @SCHEMA@.AT21340DI
  ON @SCHEMA@.AT21340D
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column EXPRESSION_MAP
CREATE AUX TABLE @SCHEMA@.AT21340E
   IN @DB_NAME@.AS21340E
   STORES @SCHEMA@.ALARM_TEMPLATE_B_T COLUMN EXPRESSION_MAP;
-- auxiliary index for LOB column EXPRESSION_MAP
CREATE UNIQUE INDEX @SCHEMA@.AT21340EI
  ON @SCHEMA@.AT21340E
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column REPEAT_EXPRESSION_MAP
CREATE AUX TABLE @SCHEMA@.AT21340F
   IN @DB_NAME@.AS21340F
   STORES @SCHEMA@.ALARM_TEMPLATE_B_T COLUMN REPEAT_EXPRESSION_MAP;
-- auxiliary index for LOB column REPEAT_EXPRESSION_MAP
CREATE UNIQUE INDEX @SCHEMA@.AT21340FI
  ON @SCHEMA@.AT21340F
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.XT_PTID
  ON @SCHEMA@.ALARM_TEMPLATE_B_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.FAULT_HANDLER_TEMPLATE_B_T
(
 FTID CHAR(16) FOR BIT DATA NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 FAULT_NAME VARCHAR(254) ,
 CTID CHAR(16) FOR BIT DATA ,
 STID CHAR(16) FOR BIT DATA ,
 ATID CHAR(16) FOR BIT DATA ,
 FAULT_LINK_SOURCE_ATID CHAR(16) FOR BIT DATA ,
 FAULT_LINK_TARGET_ATID CHAR(16) FOR BIT DATA ,
 IMPLEMENTATION_ATID CHAR(16) FOR BIT DATA NOT NULL ,
 FAULT_NAME_UTID CHAR(16) FOR BIT DATA ,
 ORDER_NUMBER INTEGER NOT NULL ,
 DISPLAY_ID_EXT VARCHAR(32) ,
  PRIMARY KEY (FTID)
) IN @DB_NAME@.TEMPL10;

CREATE UNIQUE INDEX 
  @SCHEMA@.FAULT_HANDLER_TEMPLATE_B_P
  ON @SCHEMA@.FAULT_HANDLER_TEMPLATE_B_T
(   
  FTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.FT_PTID
  ON @SCHEMA@.FAULT_HANDLER_TEMPLATE_B_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.LINK_TEMPLATE_B_T
(
 SOURCE_ATID CHAR(16) FOR BIT DATA NOT NULL ,
 TARGET_ATID CHAR(16) FOR BIT DATA NOT NULL ,
 FLOW_BEGIN_ATID CHAR(16) FOR BIT DATA ,
 ENCLOSING_FOR_EACH_ATID CHAR(16) FOR BIT DATA ,
 DISPLAY_ID INTEGER NOT NULL ,
 DISPLAY_ID_EXT VARCHAR(32) ,
 NAME VARCHAR(254) ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 KIND INTEGER NOT NULL ,
 LIFETIME INTEGER NOT NULL ,
 TRANSITION_CONDITION INTEGER NOT NULL ,
 TRANSITION_CONDITION_NAME VARCHAR(254) ,
 ORDER_NUMBER INTEGER NOT NULL ,
 SEQUENCE_NUMBER INTEGER NOT NULL ,
 BUSINESS_RELEVANCE SMALLINT NOT NULL ,
 DESCRIPTION VARCHAR(254) ,
 DOCUMENTATION CLOB(4096) ,
 EXPRESSION CLOB(3900K) ,
 IS_INBOUND_LINK SMALLINT NOT NULL ,
 OUTBOUND_ATID CHAR(16) FOR BIT DATA ,
 EXPRESSION_MAP BLOB(3900K) ,
 GENERATED_BY VARCHAR(220) ,
 RTID CHAR(16) FOR BIT DATA ,
  PRIMARY KEY (SOURCE_ATID, TARGET_ATID)
) IN @DB_NAME@.TEMPL11;

CREATE UNIQUE INDEX 
  @SCHEMA@.LINK_TEMPLATE_B_P
  ON @SCHEMA@.LINK_TEMPLATE_B_T
(   
  SOURCE_ATID, 
  TARGET_ATID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column DOCUMENTATION
CREATE AUX TABLE @SCHEMA@.AT213410
   IN @DB_NAME@.AS213410
   STORES @SCHEMA@.LINK_TEMPLATE_B_T COLUMN DOCUMENTATION;
-- auxiliary index for LOB column DOCUMENTATION
CREATE UNIQUE INDEX @SCHEMA@.AT213410I
  ON @SCHEMA@.AT213410
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column EXPRESSION
CREATE AUX TABLE @SCHEMA@.AT213411
   IN @DB_NAME@.AS213411
   STORES @SCHEMA@.LINK_TEMPLATE_B_T COLUMN EXPRESSION;
-- auxiliary index for LOB column EXPRESSION
CREATE UNIQUE INDEX @SCHEMA@.AT213411I
  ON @SCHEMA@.AT213411
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column EXPRESSION_MAP
CREATE AUX TABLE @SCHEMA@.AT213412
   IN @DB_NAME@.AS213412
   STORES @SCHEMA@.LINK_TEMPLATE_B_T COLUMN EXPRESSION_MAP;
-- auxiliary index for LOB column EXPRESSION_MAP
CREATE UNIQUE INDEX @SCHEMA@.AT213412I
  ON @SCHEMA@.AT213412
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.LNK_PTID
  ON @SCHEMA@.LINK_TEMPLATE_B_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.LINK_BOUNDARY_TEMPLATE_B_T
(
 SOURCE_ATID CHAR(16) FOR BIT DATA NOT NULL ,
 TARGET_ATID CHAR(16) FOR BIT DATA NOT NULL ,
 BOUNDARY_STID CHAR(16) FOR BIT DATA NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 IS_OUTMOST_BOUNDARY SMALLINT NOT NULL ,
  PRIMARY KEY (SOURCE_ATID, TARGET_ATID, BOUNDARY_STID)
) IN @DB_NAME@.TEMPL12;

CREATE UNIQUE INDEX 
  @SCHEMA@.LINK_BOUNDARY_TEMPLATE_B_P
  ON @SCHEMA@.LINK_BOUNDARY_TEMPLATE_B_T
(   
  SOURCE_ATID, 
  TARGET_ATID, 
  BOUNDARY_STID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.BND_PTID
  ON @SCHEMA@.LINK_BOUNDARY_TEMPLATE_B_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.RESET_TEMPLATE_B_T
(
 LOOP_ENTRY_ATID CHAR(16) FOR BIT DATA NOT NULL ,
 LOOP_BODY_ATID CHAR(16) FOR BIT DATA NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 KIND INTEGER NOT NULL ,
  PRIMARY KEY (LOOP_ENTRY_ATID, LOOP_BODY_ATID)
) IN @DB_NAME@.TEMPL13;

CREATE UNIQUE INDEX 
  @SCHEMA@.RESET_TEMPLATE_B_P
  ON @SCHEMA@.RESET_TEMPLATE_B_T
(   
  LOOP_ENTRY_ATID, 
  LOOP_BODY_ATID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.RST_PTID
  ON @SCHEMA@.RESET_TEMPLATE_B_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.VARIABLE_MAPPING_TEMPLATE_B_T
(
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 ATID CHAR(16) FOR BIT DATA NOT NULL ,
 VTID CHAR(16) FOR BIT DATA NOT NULL ,
 SOURCE_CTID CHAR(16) FOR BIT DATA NOT NULL ,
 TARGET_CTID CHAR(16) FOR BIT DATA NOT NULL ,
 PARAMETER VARCHAR(254) NOT NULL ,
  PRIMARY KEY (PTID, ATID, VTID, SOURCE_CTID, TARGET_CTID)
) IN @DB_NAME@.TEMPL14;

CREATE UNIQUE INDEX 
  @SCHEMA@.VARIABLE_MAPPING_TEMPLATE_B_P
  ON @SCHEMA@.VARIABLE_MAPPING_TEMPLATE_B_T
(   
  PTID, 
  ATID, 
  VTID, 
  SOURCE_CTID, 
  TARGET_CTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.VMT_TCTID
  ON @SCHEMA@.VARIABLE_MAPPING_TEMPLATE_B_T
(   
  PTID, 
  ATID, 
  VTID, 
  TARGET_CTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
(
 CTID CHAR(16) FOR BIT DATA NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 EHTID CHAR(16) FOR BIT DATA ,
 STID CHAR(16) FOR BIT DATA ,
 FTID CHAR(16) FOR BIT DATA ,
 DERIVED SMALLINT NOT NULL ,
 DISPLAY_ID INTEGER NOT NULL ,
 DISPLAY_ID_EXT VARCHAR(32) ,
 FROM_SPEC INTEGER NOT NULL ,
 NAME VARCHAR(254) NOT NULL ,
 MESSAGE_TEMPLATE BLOB(3900K) ,
 IS_QUERYABLE SMALLINT NOT NULL ,
 BUSINESS_RELEVANCE SMALLINT NOT NULL ,
 GENERATED_BY VARCHAR(220) ,
 SEQUENCE_NUMBER INTEGER NOT NULL ,
 FROM_VARIABLE_CTID CHAR(16) FOR BIT DATA ,
 FROM_PARAMETER2 VARCHAR(254) ,
 FROM_PARAMETER3 BLOB(3900K) ,
 FROM_PARAMETER3_LANGUAGE INTEGER NOT NULL ,
 FROM_EXPRESSION_MAP BLOB(3900K) ,
 ATID CHAR(16) FOR BIT DATA ,
  PRIMARY KEY (CTID)
) IN @DB_NAME@.TEMPL15;

CREATE UNIQUE INDEX 
  @SCHEMA@.VARIABLE_TEMPLATE_B_P
  ON @SCHEMA@.VARIABLE_TEMPLATE_B_T
(   
  CTID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column MESSAGE_TEMPLATE
CREATE AUX TABLE @SCHEMA@.AT213413
   IN @DB_NAME@.AS213413
   STORES @SCHEMA@.VARIABLE_TEMPLATE_B_T COLUMN MESSAGE_TEMPLATE;
-- auxiliary index for LOB column MESSAGE_TEMPLATE
CREATE UNIQUE INDEX @SCHEMA@.AT213413I
  ON @SCHEMA@.AT213413
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column FROM_PARAMETER3
CREATE AUX TABLE @SCHEMA@.AT213414
   IN @DB_NAME@.AS213414
   STORES @SCHEMA@.VARIABLE_TEMPLATE_B_T COLUMN FROM_PARAMETER3;
-- auxiliary index for LOB column FROM_PARAMETER3
CREATE UNIQUE INDEX @SCHEMA@.AT213414I
  ON @SCHEMA@.AT213414
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column FROM_EXPRESSION_MAP
CREATE AUX TABLE @SCHEMA@.AT213415
   IN @DB_NAME@.AS213415
   STORES @SCHEMA@.VARIABLE_TEMPLATE_B_T COLUMN FROM_EXPRESSION_MAP;
-- auxiliary index for LOB column FROM_EXPRESSION_MAP
CREATE UNIQUE INDEX @SCHEMA@.AT213415I
  ON @SCHEMA@.AT213415
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.CT_PTID
  ON @SCHEMA@.VARIABLE_TEMPLATE_B_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.VARIABLE_STACK_TEMPLATE_B_T
(
 VSID CHAR(16) FOR BIT DATA NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 CTID CHAR(16) FOR BIT DATA NOT NULL ,
 STID CHAR(16) FOR BIT DATA NOT NULL ,
 FTID CHAR(16) FOR BIT DATA ,
 EHTID CHAR(16) FOR BIT DATA ,
 NAME VARCHAR(255) NOT NULL ,
  PRIMARY KEY (VSID)
) IN @DB_NAME@.TEMPL16;

CREATE UNIQUE INDEX 
  @SCHEMA@.VARIABLE_STACK_TEMPLATE_B_P
  ON @SCHEMA@.VARIABLE_STACK_TEMPLATE_B_T
(   
  VSID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.VS_PTID
  ON @SCHEMA@.VARIABLE_STACK_TEMPLATE_B_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ACTIVITY_FAULT_TEMPLATE_B_T
(
 AFID CHAR(16) FOR BIT DATA NOT NULL ,
 ATID CHAR(16) FOR BIT DATA NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 FAULT_NAME VARCHAR(254) NOT NULL ,
 FAULT_UTID CHAR(16) FOR BIT DATA ,
 MESSAGE BLOB(3900K) NOT NULL ,
  PRIMARY KEY (AFID)
) IN @DB_NAME@.TEMPL17;

CREATE UNIQUE INDEX 
  @SCHEMA@.ACTIVITY_FAULT_TEMPLATE_B_P
  ON @SCHEMA@.ACTIVITY_FAULT_TEMPLATE_B_T
(   
  AFID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column MESSAGE
CREATE AUX TABLE @SCHEMA@.AT213416
   IN @DB_NAME@.AS213416
   STORES @SCHEMA@.ACTIVITY_FAULT_TEMPLATE_B_T COLUMN MESSAGE;
-- auxiliary index for LOB column MESSAGE
CREATE UNIQUE INDEX @SCHEMA@.AT213416I
  ON @SCHEMA@.AT213416
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.AF_PTID
  ON @SCHEMA@.ACTIVITY_FAULT_TEMPLATE_B_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.PARTNER_LINK_TEMPLATE_B_T
(
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 PARTNER_LINK_NAME VARCHAR(220) NOT NULL ,
 PROCESS_NAME VARCHAR(220) ,
 TARGET_NAMESPACE VARCHAR(250) ,
 RESOLUTION_SCOPE INTEGER NOT NULL ,
 MY_ROLE SMALLINT NOT NULL ,
 MY_ROLE_IMPL BLOB(3900K) ,
 MY_ROLE_LOCALNAME VARCHAR(220) ,
 MY_ROLE_NAMESPACE VARCHAR(220) ,
 THEIR_ROLE SMALLINT NOT NULL ,
 THEIR_ROLE_IMPL BLOB(3900K) ,
 THEIR_ROLE_LOCALNAME VARCHAR(220) ,
 THEIR_ROLE_NAMESPACE VARCHAR(220) ,
 DISPLAY_ID_EXT VARCHAR(32) ,
  PRIMARY KEY (PTID, PARTNER_LINK_NAME)
) IN @DB_NAME@.TEMPL18;

CREATE UNIQUE INDEX 
  @SCHEMA@.PARTNER_LINK_TEMPLATE_B_P
  ON @SCHEMA@.PARTNER_LINK_TEMPLATE_B_T
(   
  PTID, 
  PARTNER_LINK_NAME
) NOT PADDED
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column MY_ROLE_IMPL
CREATE AUX TABLE @SCHEMA@.AT213417
   IN @DB_NAME@.AS213417
   STORES @SCHEMA@.PARTNER_LINK_TEMPLATE_B_T COLUMN MY_ROLE_IMPL;
-- auxiliary index for LOB column MY_ROLE_IMPL
CREATE UNIQUE INDEX @SCHEMA@.AT213417I
  ON @SCHEMA@.AT213417
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column THEIR_ROLE_IMPL
CREATE AUX TABLE @SCHEMA@.AT213418
   IN @DB_NAME@.AS213418
   STORES @SCHEMA@.PARTNER_LINK_TEMPLATE_B_T COLUMN THEIR_ROLE_IMPL;
-- auxiliary index for LOB column THEIR_ROLE_IMPL
CREATE UNIQUE INDEX @SCHEMA@.AT213418I
  ON @SCHEMA@.AT213418
   USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.URI_TEMPLATE_B_T
(
 UTID CHAR(16) FOR BIT DATA NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 URI VARCHAR(220) NOT NULL ,
  PRIMARY KEY (UTID)
) IN @DB_NAME@.TEMPL19;

CREATE UNIQUE INDEX 
  @SCHEMA@.URI_TEMPLATE_B_P
  ON @SCHEMA@.URI_TEMPLATE_B_T
(   
  UTID
)
USING STOGROUP @STOGRP@;

CREATE UNIQUE INDEX 
  @SCHEMA@.UT_PTID_URI
  ON @SCHEMA@.URI_TEMPLATE_B_T
(   
  PTID, 
  URI
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.UT_UTID_URI
  ON @SCHEMA@.URI_TEMPLATE_B_T
(   
  UTID, 
  URI
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.CLIENT_SETTING_TEMPLATE_B_T
(
 CSID CHAR(16) FOR BIT DATA NOT NULL ,
 ATID CHAR(16) FOR BIT DATA ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 VTID CHAR(16) FOR BIT DATA ,
 SETTINGS BLOB(3900K) ,
  PRIMARY KEY (CSID)
) IN @DB_NAME@.TEMPL20;

CREATE UNIQUE INDEX 
  @SCHEMA@.CLIENT_SETTING_TEMPLATE_B_P
  ON @SCHEMA@.CLIENT_SETTING_TEMPLATE_B_T
(   
  CSID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column SETTINGS
CREATE AUX TABLE @SCHEMA@.AT213419
   IN @DB_NAME@.AS213419
   STORES @SCHEMA@.CLIENT_SETTING_TEMPLATE_B_T COLUMN SETTINGS;
-- auxiliary index for LOB column SETTINGS
CREATE UNIQUE INDEX @SCHEMA@.AT213419I
  ON @SCHEMA@.AT213419
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.CS_PTID
  ON @SCHEMA@.CLIENT_SETTING_TEMPLATE_B_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ASSIGN_TEMPLATE_B_T
(
 ATID CHAR(16) FOR BIT DATA NOT NULL ,
 ORDER_NUMBER INTEGER NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 FROM_SPEC INTEGER NOT NULL ,
 FROM_VARIABLE_CTID CHAR(16) FOR BIT DATA ,
 FROM_PARAMETER2 VARCHAR(254) ,
 FROM_PARAMETER3 BLOB(1073741823) ,
 FROM_PARAMETER3_LANGUAGE INTEGER NOT NULL ,
 TO_SPEC INTEGER NOT NULL ,
 TO_VARIABLE_CTID CHAR(16) FOR BIT DATA ,
 TO_PARAMETER2 VARCHAR(254) ,
 TO_PARAMETER3 BLOB(3900K) ,
 TO_PARAMETER3_LANGUAGE INTEGER NOT NULL ,
 FROM_EXPRESSION_MAP BLOB(3900K) ,
 TO_EXPRESSION_MAP BLOB(3900K) ,
  PRIMARY KEY (ATID, ORDER_NUMBER)
) IN @DB_NAME@.TEMPL21;

CREATE UNIQUE INDEX 
  @SCHEMA@.ASSIGN_TEMPLATE_B_P
  ON @SCHEMA@.ASSIGN_TEMPLATE_B_T
(   
  ATID, 
  ORDER_NUMBER
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column FROM_PARAMETER3
CREATE AUX TABLE @SCHEMA@.AT21341A
   IN @DB_NAME@.AS21341A
   STORES @SCHEMA@.ASSIGN_TEMPLATE_B_T COLUMN FROM_PARAMETER3;
-- auxiliary index for LOB column FROM_PARAMETER3
CREATE UNIQUE INDEX @SCHEMA@.AT21341AI
  ON @SCHEMA@.AT21341A
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column TO_PARAMETER3
CREATE AUX TABLE @SCHEMA@.AT21341B
   IN @DB_NAME@.AS21341B
   STORES @SCHEMA@.ASSIGN_TEMPLATE_B_T COLUMN TO_PARAMETER3;
-- auxiliary index for LOB column TO_PARAMETER3
CREATE UNIQUE INDEX @SCHEMA@.AT21341BI
  ON @SCHEMA@.AT21341B
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column FROM_EXPRESSION_MAP
CREATE AUX TABLE @SCHEMA@.AT21341C
   IN @DB_NAME@.AS21341C
   STORES @SCHEMA@.ASSIGN_TEMPLATE_B_T COLUMN FROM_EXPRESSION_MAP;
-- auxiliary index for LOB column FROM_EXPRESSION_MAP
CREATE UNIQUE INDEX @SCHEMA@.AT21341CI
  ON @SCHEMA@.AT21341C
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column TO_EXPRESSION_MAP
CREATE AUX TABLE @SCHEMA@.AT21341D
   IN @DB_NAME@.AS21341D
   STORES @SCHEMA@.ASSIGN_TEMPLATE_B_T COLUMN TO_EXPRESSION_MAP;
-- auxiliary index for LOB column TO_EXPRESSION_MAP
CREATE UNIQUE INDEX @SCHEMA@.AT21341DI
  ON @SCHEMA@.AT21341D
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.ASTB_PTID
  ON @SCHEMA@.ASSIGN_TEMPLATE_B_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.CORRELATION_SET_TEMPLATE_B_T
(
 COID CHAR(16) FOR BIT DATA NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 STID CHAR(16) FOR BIT DATA NOT NULL ,
 NAME VARCHAR(255) NOT NULL ,
 DISPLAY_ID_EXT VARCHAR(32) ,
  PRIMARY KEY (COID)
) IN @DB_NAME@.TEMPL22;

CREATE UNIQUE INDEX 
  @SCHEMA@.CORRELATION_SET_TEMPLATE_B_P
  ON @SCHEMA@.CORRELATION_SET_TEMPLATE_B_T
(   
  COID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.CSTB_PTID
  ON @SCHEMA@.CORRELATION_SET_TEMPLATE_B_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.CORRELATION_TEMPLATE_B_T
(
 ATID CHAR(16) FOR BIT DATA NOT NULL ,
 VTID CHAR(16) FOR BIT DATA NOT NULL ,
 COID CHAR(16) FOR BIT DATA NOT NULL ,
 IS_FOR_EVENT_HANDLER SMALLINT NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 INITIATE INTEGER NOT NULL ,
 PATTERN INTEGER NOT NULL ,
  PRIMARY KEY (ATID, VTID, COID, IS_FOR_EVENT_HANDLER)
) IN @DB_NAME@.TEMPL23;

CREATE UNIQUE INDEX 
  @SCHEMA@.CORRELATION_TEMPLATE_B_P
  ON @SCHEMA@.CORRELATION_TEMPLATE_B_T
(   
  ATID, 
  VTID, 
  COID, 
  IS_FOR_EVENT_HANDLER
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.COID_PTID
  ON @SCHEMA@.CORRELATION_TEMPLATE_B_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T
(
 PAID CHAR(16) FOR BIT DATA NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 COID CHAR(16) FOR BIT DATA NOT NULL ,
 SEQUENCE_NUMBER INTEGER NOT NULL ,
 PROPERTY_UTID CHAR(16) FOR BIT DATA NOT NULL ,
 PROPERTY_NAME VARCHAR(255) NOT NULL ,
 JAVA_TYPE VARCHAR(255) NOT NULL ,
 MSG_TYPE_UTID CHAR(16) FOR BIT DATA NOT NULL ,
 MSG_TYPE_NAME VARCHAR(255) NOT NULL ,
 MSG_TYPE_KIND INTEGER NOT NULL ,
 PROPERTY_TYPE_UTID CHAR(16) FOR BIT DATA ,
 PROPERTY_TYPE_NAME VARCHAR(255) ,
 PART VARCHAR(255) ,
 QUERY VARCHAR(255) ,
 QUERY_LANGUAGE INTEGER NOT NULL ,
 IS_DEFINED_INLINE SMALLINT NOT NULL ,
  PRIMARY KEY (PAID)
) IN @DB_NAME@.TEMPL24;

CREATE UNIQUE INDEX 
  @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_P
  ON @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T
(   
  PAID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.PATB_COID_UTID
  ON @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T
(   
  COID, 
  MSG_TYPE_UTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.PATB_PTID_UTIDS
  ON @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T
(   
  PTID, 
  MSG_TYPE_UTID, 
  PROPERTY_UTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.EVENT_HANDLER_TEMPLATE_B_T
(
 EHTID CHAR(16) FOR BIT DATA NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 STID CHAR(16) FOR BIT DATA NOT NULL ,
 IMPL_ATID CHAR(16) FOR BIT DATA NOT NULL ,
 VTID CHAR(16) FOR BIT DATA ,
 INPUT_CTID CHAR(16) FOR BIT DATA ,
 TKTID CHAR(16) FOR BIT DATA ,
 KIND INTEGER NOT NULL ,
 DISPLAY_ID_EXT VARCHAR(32) ,
  PRIMARY KEY (EHTID)
) IN @DB_NAME@.TEMPL25;

CREATE UNIQUE INDEX 
  @SCHEMA@.EVENT_HANDLER_TEMPLATE_B_P
  ON @SCHEMA@.EVENT_HANDLER_TEMPLATE_B_T
(   
  EHTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.EHT_PTID
  ON @SCHEMA@.EVENT_HANDLER_TEMPLATE_B_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.EHALARM_TEMPLATE_B_T
(
 EHTID CHAR(16) FOR BIT DATA NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 KIND INTEGER NOT NULL ,
 EXPRESSION BLOB(3900K) ,
 EXPRESSION_NAME VARCHAR(254) ,
 DURATION VARCHAR(254) ,
 CALENDAR VARCHAR(254) ,
 CALENDAR_JNDI_NAME VARCHAR(254) ,
 REPEAT_KIND INTEGER NOT NULL ,
 REPEAT_EXPRESSION BLOB(3900K) ,
 REPEAT_EXP_NAME VARCHAR(254) ,
 REPEAT_DURATION VARCHAR(254) ,
 REPEAT_CALENDAR VARCHAR(254) ,
 REPEAT_CALENDAR_JNDI_NAME VARCHAR(254) ,
 EXPRESSION_MAP BLOB(3900K) ,
 REPEAT_EXPRESSION_MAP BLOB(3900K) ,
  PRIMARY KEY (EHTID)
) IN @DB_NAME@.TEMPL26;

CREATE UNIQUE INDEX 
  @SCHEMA@.EHALARM_TEMPLATE_B_P
  ON @SCHEMA@.EHALARM_TEMPLATE_B_T
(   
  EHTID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column EXPRESSION
CREATE AUX TABLE @SCHEMA@.AT21341E
   IN @DB_NAME@.AS21341E
   STORES @SCHEMA@.EHALARM_TEMPLATE_B_T COLUMN EXPRESSION;
-- auxiliary index for LOB column EXPRESSION
CREATE UNIQUE INDEX @SCHEMA@.AT21341EI
  ON @SCHEMA@.AT21341E
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column REPEAT_EXPRESSION
CREATE AUX TABLE @SCHEMA@.AT21341F
   IN @DB_NAME@.AS21341F
   STORES @SCHEMA@.EHALARM_TEMPLATE_B_T COLUMN REPEAT_EXPRESSION;
-- auxiliary index for LOB column REPEAT_EXPRESSION
CREATE UNIQUE INDEX @SCHEMA@.AT21341FI
  ON @SCHEMA@.AT21341F
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column EXPRESSION_MAP
CREATE AUX TABLE @SCHEMA@.AT213420
   IN @DB_NAME@.AS213420
   STORES @SCHEMA@.EHALARM_TEMPLATE_B_T COLUMN EXPRESSION_MAP;
-- auxiliary index for LOB column EXPRESSION_MAP
CREATE UNIQUE INDEX @SCHEMA@.AT213420I
  ON @SCHEMA@.AT213420
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column REPEAT_EXPRESSION_MAP
CREATE AUX TABLE @SCHEMA@.AT213421
   IN @DB_NAME@.AS213421
   STORES @SCHEMA@.EHALARM_TEMPLATE_B_T COLUMN REPEAT_EXPRESSION_MAP;
-- auxiliary index for LOB column REPEAT_EXPRESSION_MAP
CREATE UNIQUE INDEX @SCHEMA@.AT213421I
  ON @SCHEMA@.AT213421
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.EXT_PTID
  ON @SCHEMA@.EHALARM_TEMPLATE_B_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.CUSTOM_EXT_TEMPLATE_B_T
(
 PKID CHAR(16) FOR BIT DATA NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 NAMESPACE VARCHAR(220) NOT NULL ,
 LOCALNAME VARCHAR(220) NOT NULL ,
 TEMPLATE_INFO BLOB(3900K) ,
 INSTANCE_INFO BLOB(3900K) ,
  PRIMARY KEY (PKID)
) IN @DB_NAME@.TEMPL27;

CREATE UNIQUE INDEX 
  @SCHEMA@.CUSTOM_EXT_TEMPLATE_B_P
  ON @SCHEMA@.CUSTOM_EXT_TEMPLATE_B_T
(   
  PKID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column TEMPLATE_INFO
CREATE AUX TABLE @SCHEMA@.AT213422
   IN @DB_NAME@.AS213422
   STORES @SCHEMA@.CUSTOM_EXT_TEMPLATE_B_T COLUMN TEMPLATE_INFO;
-- auxiliary index for LOB column TEMPLATE_INFO
CREATE UNIQUE INDEX @SCHEMA@.AT213422I
  ON @SCHEMA@.AT213422
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column INSTANCE_INFO
CREATE AUX TABLE @SCHEMA@.AT213423
   IN @DB_NAME@.AS213423
   STORES @SCHEMA@.CUSTOM_EXT_TEMPLATE_B_T COLUMN INSTANCE_INFO;
-- auxiliary index for LOB column INSTANCE_INFO
CREATE UNIQUE INDEX @SCHEMA@.AT213423I
  ON @SCHEMA@.AT213423
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.CETB_PTID
  ON @SCHEMA@.CUSTOM_EXT_TEMPLATE_B_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.CUSTOM_STMT_TEMPLATE_B_T
(
 PKID CHAR(16) FOR BIT DATA NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 NAMESPACE VARCHAR(220) NOT NULL ,
 LOCALNAME VARCHAR(220) NOT NULL ,
 PURPOSE VARCHAR(220) NOT NULL ,
 STATEMENT BLOB(3900K) ,
  PRIMARY KEY (PKID)
) IN @DB_NAME@.TEMPL28;

CREATE UNIQUE INDEX 
  @SCHEMA@.CUSTOM_STMT_TEMPLATE_B_P
  ON @SCHEMA@.CUSTOM_STMT_TEMPLATE_B_T
(   
  PKID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column STATEMENT
CREATE AUX TABLE @SCHEMA@.AT213424
   IN @DB_NAME@.AS213424
   STORES @SCHEMA@.CUSTOM_STMT_TEMPLATE_B_T COLUMN STATEMENT;
-- auxiliary index for LOB column STATEMENT
CREATE UNIQUE INDEX @SCHEMA@.AT213424I
  ON @SCHEMA@.AT213424
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.CST_PTID_NS_LN_P
  ON @SCHEMA@.CUSTOM_STMT_TEMPLATE_B_T
(   
  PTID, 
  NAMESPACE, 
  LOCALNAME, 
  PURPOSE
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.PROCESS_CELL_MAP_T
(
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 CELL VARCHAR(220) NOT NULL ,
  PRIMARY KEY (PTID, CELL)
) IN @DB_NAME@.TEMPL29;

CREATE UNIQUE INDEX 
  @SCHEMA@.PROCESS_CELL_MAP_P
  ON @SCHEMA@.PROCESS_CELL_MAP_T
(   
  PTID, 
  CELL
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ACTIVITY_TEMPLATE_ATTR_B_T
(
 ATID CHAR(16) FOR BIT DATA NOT NULL ,
 ATTR_KEY VARCHAR(192) NOT NULL ,
 ATTR_VALUE VARCHAR(254) ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 DISPLAY_ID_EXT VARCHAR(32) ,
  PRIMARY KEY (ATID, ATTR_KEY)
) IN @DB_NAME@.TEMPL41;

CREATE UNIQUE INDEX 
  @SCHEMA@.ACTIVITY_TEMPLATE_ATTR_B_P
  ON @SCHEMA@.ACTIVITY_TEMPLATE_ATTR_B_T
(   
  ATID, 
  ATTR_KEY
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.ATAB_PTID
  ON @SCHEMA@.ACTIVITY_TEMPLATE_ATTR_B_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.ATAB_VALUE
  ON @SCHEMA@.ACTIVITY_TEMPLATE_ATTR_B_T
(   
  ATTR_VALUE
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.FOR_EACH_TEMPLATE_B_T
(
 ATID CHAR(16) FOR BIT DATA NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 COUNTER_CTID CHAR(16) FOR BIT DATA NOT NULL ,
 SUCCESSFUL_BRANCHES_ONLY SMALLINT NOT NULL ,
 START_COUNTER_LANGUAGE INTEGER NOT NULL ,
 FINAL_COUNTER_LANGUAGE INTEGER NOT NULL ,
 COMPLETION_CONDITION_LANGUAGE INTEGER NOT NULL ,
 START_COUNTER_EXPRESSION BLOB(3900K) ,
 FINAL_COUNTER_EXPRESSION BLOB(3900K) ,
 COMPLETION_COND_EXPRESSION BLOB(3900K) ,
 FOR_EACH_METHOD VARCHAR(254) ,
 START_COUNTER_EXPRESSION_MAP BLOB(3900K) ,
 FINAL_COUNTER_EXPRESSION_MAP BLOB(3900K) ,
 COMPLETION_COND_EXPRESSION_MAP BLOB(3900K) ,
  PRIMARY KEY (ATID)
) IN @DB_NAME@.TEMPL44;

CREATE UNIQUE INDEX 
  @SCHEMA@.FOR_EACH_TEMPLATE_B_P
  ON @SCHEMA@.FOR_EACH_TEMPLATE_B_T
(   
  ATID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column START_COUNTER_EXPRESSION
CREATE AUX TABLE @SCHEMA@.AT213425
   IN @DB_NAME@.AS213425
 STORES @SCHEMA@.FOR_EACH_TEMPLATE_B_T COLUMN
 START_COUNTER_EXPRESSION;
-- auxiliary index for LOB column START_COUNTER_EXPRESSION
CREATE UNIQUE INDEX @SCHEMA@.AT213425I
  ON @SCHEMA@.AT213425
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column FINAL_COUNTER_EXPRESSION
CREATE AUX TABLE @SCHEMA@.AT213426
   IN @DB_NAME@.AS213426
 STORES @SCHEMA@.FOR_EACH_TEMPLATE_B_T COLUMN
 FINAL_COUNTER_EXPRESSION;
-- auxiliary index for LOB column FINAL_COUNTER_EXPRESSION
CREATE UNIQUE INDEX @SCHEMA@.AT213426I
  ON @SCHEMA@.AT213426
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column COMPLETION_COND_EXPRESSION
CREATE AUX TABLE @SCHEMA@.AT213427
   IN @DB_NAME@.AS213427
 STORES @SCHEMA@.FOR_EACH_TEMPLATE_B_T COLUMN
 COMPLETION_COND_EXPRESSION;
-- auxiliary index for LOB column COMPLETION_COND_EXPRESSION
CREATE UNIQUE INDEX @SCHEMA@.AT213427I
  ON @SCHEMA@.AT213427
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column START_COUNTER_EXPRESSION_MAP
CREATE AUX TABLE @SCHEMA@.AT213428
   IN @DB_NAME@.AS213428
 STORES @SCHEMA@.FOR_EACH_TEMPLATE_B_T COLUMN
 START_COUNTER_EXPRESSION_MAP;
-- auxiliary index for LOB column START_COUNTER_EXPRESSION_MAP
CREATE UNIQUE INDEX @SCHEMA@.AT213428I
  ON @SCHEMA@.AT213428
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column FINAL_COUNTER_EXPRESSION_MAP
CREATE AUX TABLE @SCHEMA@.AT213429
   IN @DB_NAME@.AS213429
 STORES @SCHEMA@.FOR_EACH_TEMPLATE_B_T COLUMN
 FINAL_COUNTER_EXPRESSION_MAP;
-- auxiliary index for LOB column FINAL_COUNTER_EXPRESSION_MAP
CREATE UNIQUE INDEX @SCHEMA@.AT213429I
  ON @SCHEMA@.AT213429
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column COMPLETION_COND_EXPRESSION_MAP
CREATE AUX TABLE @SCHEMA@.AT21342A
   IN @DB_NAME@.AS21342A
 STORES @SCHEMA@.FOR_EACH_TEMPLATE_B_T COLUMN
 COMPLETION_COND_EXPRESSION_MAP;
-- auxiliary index for LOB column COMPLETION_COND_EXPRESSION_MAP
CREATE UNIQUE INDEX @SCHEMA@.AT21342AI
  ON @SCHEMA@.AT21342A
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.FET_PTID
  ON @SCHEMA@.FOR_EACH_TEMPLATE_B_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.GRAPHICAL_PROCESS_MODEL_T
(
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 SOURCE VARCHAR(100) NOT NULL ,
 KIND VARCHAR(100) NOT NULL ,
 GRAPHICAL_DATA BLOB(10000K) ,
 ID_MAPPING BLOB(10000K) ,
  PRIMARY KEY (PTID, SOURCE, KIND)
) IN @DB_NAME@.TEMPL45;

CREATE UNIQUE INDEX 
  @SCHEMA@.GRAPHICAL_PROCESS_MODEL_P
  ON @SCHEMA@.GRAPHICAL_PROCESS_MODEL_T
(   
  PTID, 
  SOURCE, 
  KIND
) NOT PADDED
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column GRAPHICAL_DATA
CREATE AUX TABLE @SCHEMA@.AT21342B
   IN @DB_NAME@.AS21342B
   STORES @SCHEMA@.GRAPHICAL_PROCESS_MODEL_T COLUMN GRAPHICAL_DATA;
-- auxiliary index for LOB column GRAPHICAL_DATA
CREATE UNIQUE INDEX @SCHEMA@.AT21342BI
  ON @SCHEMA@.AT21342B
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column ID_MAPPING
CREATE AUX TABLE @SCHEMA@.AT21342C
   IN @DB_NAME@.AS21342C
   STORES @SCHEMA@.GRAPHICAL_PROCESS_MODEL_T COLUMN ID_MAPPING;
-- auxiliary index for LOB column ID_MAPPING
CREATE UNIQUE INDEX @SCHEMA@.AT21342CI
  ON @SCHEMA@.AT21342C
   USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T
(
 PKID CHAR(16) FOR BIT DATA NOT NULL ,
 CTID CHAR(16) FOR BIT DATA NOT NULL ,
 PAID CHAR(16) FOR BIT DATA NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 QUERY_TYPE INTEGER NOT NULL ,
  PRIMARY KEY (PKID)
) IN @DB_NAME@.TEMPL46;

CREATE UNIQUE INDEX 
  @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_P
  ON @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T
(   
  PKID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.QVT_PTID
  ON @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
(
 MPTID CHAR(16) FOR BIT DATA NOT NULL ,
 SOURCE_PTID CHAR(16) FOR BIT DATA NOT NULL ,
 TARGET_PTID CHAR(16) FOR BIT DATA NOT NULL ,
 TYPE INTEGER NOT NULL ,
  PRIMARY KEY (MPTID)
) IN @DB_NAME@.TEMPL47;

CREATE UNIQUE INDEX 
  @SCHEMA@.MIGRATION_PLAN_TEMPLATE_P
  ON @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
(   
  MPTID
)
USING STOGROUP @STOGRP@;

CREATE UNIQUE INDEX 
  @SCHEMA@.MPT_PTIDS
  ON @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
(   
  SOURCE_PTID, 
  TARGET_PTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.MPT_TPTID
  ON @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
(   
  TARGET_PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.IDMAPPING_TEMPLATE_T
(
 MPTID CHAR(16) FOR BIT DATA NOT NULL ,
 SOURCE_OID CHAR(16) FOR BIT DATA NOT NULL ,
 TARGET_OID CHAR(16) FOR BIT DATA NOT NULL ,
 SOURCE_PTID CHAR(16) FOR BIT DATA NOT NULL ,
  PRIMARY KEY (MPTID, SOURCE_OID)
) IN @DB_NAME@.TEMPL48;

CREATE UNIQUE INDEX 
  @SCHEMA@.IDMAPPING_TEMPLATE_P
  ON @SCHEMA@.IDMAPPING_TEMPLATE_T
(   
  MPTID, 
  SOURCE_OID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.IDMT_PTID
  ON @SCHEMA@.IDMAPPING_TEMPLATE_T
(   
  SOURCE_PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.CHANGE_GROUP_TEMPLATE_T
(
 CGTID CHAR(16) FOR BIT DATA NOT NULL ,
 MPTID CHAR(16) FOR BIT DATA NOT NULL ,
 SOURCE_PTID CHAR(16) FOR BIT DATA NOT NULL ,
 MANDATORY SMALLINT NOT NULL ,
 CHANGES CLOB(3900K) NOT NULL ,
  PRIMARY KEY (CGTID)
) IN @DB_NAME@.TEMPL51;

CREATE UNIQUE INDEX 
  @SCHEMA@.CHANGE_GROUP_TEMPLATE_P
  ON @SCHEMA@.CHANGE_GROUP_TEMPLATE_T
(   
  CGTID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column CHANGES
CREATE AUX TABLE @SCHEMA@.AT21342D
   IN @DB_NAME@.AS21342D
   STORES @SCHEMA@.CHANGE_GROUP_TEMPLATE_T COLUMN CHANGES;
-- auxiliary index for LOB column CHANGES
CREATE UNIQUE INDEX @SCHEMA@.AT21342DI
  ON @SCHEMA@.AT21342D
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.CGT_MT
  ON @SCHEMA@.CHANGE_GROUP_TEMPLATE_T
(   
  MPTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.CGT_PT
  ON @SCHEMA@.CHANGE_GROUP_TEMPLATE_T
(   
  SOURCE_PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T
(
 CGTID CHAR(16) FOR BIT DATA NOT NULL ,
 SOURCE_ATID CHAR(16) FOR BIT DATA NOT NULL ,
 MPTID CHAR(16) FOR BIT DATA NOT NULL ,
 SOURCE_PTID CHAR(16) FOR BIT DATA NOT NULL ,
 RELATIONSHIP INTEGER NOT NULL ,
  PRIMARY KEY (CGTID, SOURCE_ATID)
) IN @DB_NAME@.TEMPL52;

CREATE UNIQUE INDEX 
  @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_P
  ON @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T
(   
  CGTID, 
  SOURCE_ATID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.CGIT_MT
  ON @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T
(   
  MPTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.CGIT_PT
  ON @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T
(   
  SOURCE_PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.MIGRATION_PLAN_VAR_TEMPLATE_T
(
 MPTID CHAR(16) FOR BIT DATA NOT NULL ,
 TARGET_CTID CHAR(16) FOR BIT DATA NOT NULL ,
 TARGET_STID CHAR(16) FOR BIT DATA NOT NULL ,
 SOURCE_PTID CHAR(16) FOR BIT DATA NOT NULL ,
  PRIMARY KEY (MPTID, TARGET_CTID)
) IN @DB_NAME@.TEMPL53;

CREATE UNIQUE INDEX 
  @SCHEMA@.MIGRATION_PLAN_VAR_TEMPLATE_P
  ON @SCHEMA@.MIGRATION_PLAN_VAR_TEMPLATE_T
(   
  MPTID, 
  TARGET_CTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.MPVT_PT
  ON @SCHEMA@.MIGRATION_PLAN_VAR_TEMPLATE_T
(   
  SOURCE_PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.REGION_TEMPLATE_T
(
 RTID CHAR(16) FOR BIT DATA NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 BEGIN_ATID CHAR(16) FOR BIT DATA ,
 END_ATID CHAR(16) FOR BIT DATA ,
 REGION_TYPE INTEGER NOT NULL ,
 BEGIN_ORDER_NUMBER INTEGER NOT NULL ,
 PARENT_RTID CHAR(16) FOR BIT DATA ,
  PRIMARY KEY (RTID)
) IN @DB_NAME@.TEMPL54;

CREATE UNIQUE INDEX 
  @SCHEMA@.REGION_TEMPLATE_P
  ON @SCHEMA@.REGION_TEMPLATE_T
(   
  RTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.RGT_PTID
  ON @SCHEMA@.REGION_TEMPLATE_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.REGION_CONTENT_TEMPLATE_T
(
 RTID CHAR(16) FOR BIT DATA NOT NULL ,
 CONTAINED_ATID CHAR(16) FOR BIT DATA NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
  PRIMARY KEY (RTID, CONTAINED_ATID)
) IN @DB_NAME@.TEMPL55;

CREATE UNIQUE INDEX 
  @SCHEMA@.REGION_CONTENT_TEMPLATE_P
  ON @SCHEMA@.REGION_CONTENT_TEMPLATE_T
(   
  RTID, 
  CONTAINED_ATID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.RCT_PTID
  ON @SCHEMA@.REGION_CONTENT_TEMPLATE_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.CHANGE_TEMPLATE_T
(
 PKID CHAR(16) FOR BIT DATA NOT NULL ,
 MPTID CHAR(16) FOR BIT DATA NOT NULL ,
 PROPERTY INTEGER NOT NULL ,
 DISPLAY_ID_EXT VARCHAR(32) NOT NULL ,
 CHANGE_TYPE INTEGER NOT NULL ,
 SOURCE_PTID CHAR(16) FOR BIT DATA NOT NULL ,
  PRIMARY KEY (PKID)
) IN @DB_NAME@.TEMPL56;

CREATE UNIQUE INDEX 
  @SCHEMA@.CHANGE_TEMPLATE_P
  ON @SCHEMA@.CHANGE_TEMPLATE_T
(   
  PKID
)
USING STOGROUP @STOGRP@;

CREATE UNIQUE INDEX 
  @SCHEMA@.CT_MTPDIS
  ON @SCHEMA@.CHANGE_TEMPLATE_T
(   
  MPTID, 
  PROPERTY, 
  DISPLAY_ID_EXT
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.CGT_PTID
  ON @SCHEMA@.CHANGE_TEMPLATE_T
(   
  SOURCE_PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.DATA_ASSIGNMENT_TEMPLATE_T
(
 PKID CHAR(16) FOR BIT DATA NOT NULL ,
 ATID CHAR(16) FOR BIT DATA NOT NULL ,
 ORDER_NUMBER INTEGER NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 DATA_ASSOCIATION_TYPE INTEGER NOT NULL ,
 SOURCE_REF_CTID CHAR(16) FOR BIT DATA ,
 TARGET_REF_CTID CHAR(16) FOR BIT DATA ,
 FROM_EXPRESSION BLOB(1073741823) ,
 FROM_EXPRESSION_MAP BLOB(1073741823) ,
 TO_EXPRESSION BLOB(1073741823) ,
 TO_EXPRESSION_MAP BLOB(1073741823) ,
  PRIMARY KEY (PKID)
) IN @DB_NAME@.TEMPL58;

CREATE UNIQUE INDEX 
  @SCHEMA@.DATA_ASSIGNMENT_TEMPLATE_P
  ON @SCHEMA@.DATA_ASSIGNMENT_TEMPLATE_T
(   
  PKID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column FROM_EXPRESSION
CREATE AUX TABLE @SCHEMA@.AT21342E
   IN @DB_NAME@.AS21342E
   STORES @SCHEMA@.DATA_ASSIGNMENT_TEMPLATE_T COLUMN FROM_EXPRESSION;
-- auxiliary index for LOB column FROM_EXPRESSION
CREATE UNIQUE INDEX @SCHEMA@.AT21342EI
  ON @SCHEMA@.AT21342E
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column FROM_EXPRESSION_MAP
CREATE AUX TABLE @SCHEMA@.AT21342F
   IN @DB_NAME@.AS21342F
 STORES @SCHEMA@.DATA_ASSIGNMENT_TEMPLATE_T COLUMN
 FROM_EXPRESSION_MAP;
-- auxiliary index for LOB column FROM_EXPRESSION_MAP
CREATE UNIQUE INDEX @SCHEMA@.AT21342FI
  ON @SCHEMA@.AT21342F
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column TO_EXPRESSION
CREATE AUX TABLE @SCHEMA@.AT213430
   IN @DB_NAME@.AS213430
   STORES @SCHEMA@.DATA_ASSIGNMENT_TEMPLATE_T COLUMN TO_EXPRESSION;
-- auxiliary index for LOB column TO_EXPRESSION
CREATE UNIQUE INDEX @SCHEMA@.AT213430I
  ON @SCHEMA@.AT213430
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column TO_EXPRESSION_MAP
CREATE AUX TABLE @SCHEMA@.AT213431
   IN @DB_NAME@.AS213431
 STORES @SCHEMA@.DATA_ASSIGNMENT_TEMPLATE_T COLUMN TO_EXPRESSION_MAP;
-- auxiliary index for LOB column TO_EXPRESSION_MAP
CREATE UNIQUE INDEX @SCHEMA@.AT213431I
  ON @SCHEMA@.AT213431
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.DATB_PTID
  ON @SCHEMA@.DATA_ASSIGNMENT_TEMPLATE_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.DATB_ATID_DATA
  ON @SCHEMA@.DATA_ASSIGNMENT_TEMPLATE_T
(   
  ATID, 
  DATA_ASSOCIATION_TYPE
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.DATA_VISIBILITY_TEMPLATE_T
(
 VSID CHAR(16) FOR BIT DATA NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 CTID CHAR(16) FOR BIT DATA NOT NULL ,
 ATID CHAR(16) FOR BIT DATA NOT NULL ,
 NAME VARCHAR(255) NOT NULL ,
  PRIMARY KEY (VSID)
) IN @DB_NAME@.TEMPL59;

CREATE UNIQUE INDEX 
  @SCHEMA@.DATA_VISIBILITY_TEMPLATE_P
  ON @SCHEMA@.DATA_VISIBILITY_TEMPLATE_T
(   
  VSID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.DVT_PTID
  ON @SCHEMA@.DATA_VISIBILITY_TEMPLATE_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.LOOP_CHAR_TEMPLATE_T
(
 ATID CHAR(16) FOR BIT DATA NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 LOOP_TYPE INTEGER NOT NULL ,
 CONDITION BLOB(1073741823) ,
 CONDITION_PREFIX_MAP BLOB(1073741823) ,
 LOOP_MAXIMUM INTEGER ,
  PRIMARY KEY (ATID)
) IN @DB_NAME@.TEMPL60;

CREATE UNIQUE INDEX 
  @SCHEMA@.LOOP_CHAR_TEMPLATE_P
  ON @SCHEMA@.LOOP_CHAR_TEMPLATE_T
(   
  ATID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column CONDITION
CREATE AUX TABLE @SCHEMA@.AT213432
   IN @DB_NAME@.AS213432
   STORES @SCHEMA@.LOOP_CHAR_TEMPLATE_T COLUMN CONDITION;
-- auxiliary index for LOB column CONDITION
CREATE UNIQUE INDEX @SCHEMA@.AT213432I
  ON @SCHEMA@.AT213432
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column CONDITION_PREFIX_MAP
CREATE AUX TABLE @SCHEMA@.AT213433
   IN @DB_NAME@.AS213433
   STORES @SCHEMA@.LOOP_CHAR_TEMPLATE_T COLUMN CONDITION_PREFIX_MAP;
-- auxiliary index for LOB column CONDITION_PREFIX_MAP
CREATE UNIQUE INDEX @SCHEMA@.AT213433I
  ON @SCHEMA@.AT213433
   USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.IORCOUNTER_TEMPLATE_T
(
 PKID CHAR(16) FOR BIT DATA NOT NULL ,
 SOURCE_ATID CHAR(16) FOR BIT DATA NOT NULL ,
 TARGET_ATID CHAR(16) FOR BIT DATA NOT NULL ,
 GATEWAY_ATID CHAR(16) FOR BIT DATA NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 COUNTER_ID CLOB(3900K) NOT NULL ,
  PRIMARY KEY (PKID)
) IN @DB_NAME@.TEMPL61;

CREATE UNIQUE INDEX 
  @SCHEMA@.IORCOUNTER_TEMPLATE_P
  ON @SCHEMA@.IORCOUNTER_TEMPLATE_T
(   
  PKID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column COUNTER_ID
CREATE AUX TABLE @SCHEMA@.AT213434
   IN @DB_NAME@.AS213434
   STORES @SCHEMA@.IORCOUNTER_TEMPLATE_T COLUMN COUNTER_ID;
-- auxiliary index for LOB column COUNTER_ID
CREATE UNIQUE INDEX @SCHEMA@.AT213434I
  ON @SCHEMA@.AT213434
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.IOR_CNT_SRC_TRGT
  ON @SCHEMA@.IORCOUNTER_TEMPLATE_T
(   
  SOURCE_ATID, 
  TARGET_ATID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.IOR_CNT_PTID
  ON @SCHEMA@.IORCOUNTER_TEMPLATE_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ERROR_EVENT_TEMPLATE_T
(
 PKID CHAR(16) FOR BIT DATA NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 ATID CHAR(16) FOR BIT DATA NOT NULL ,
 ERROR_NAME VARCHAR(254) ,
 ERROR_NAME_UTID CHAR(16) FOR BIT DATA ,
 ERROR_MESSAGE_DEFINITION BLOB(3900K) ,
 CTID CHAR(16) FOR BIT DATA ,
 ORDER_NUMBER INTEGER NOT NULL ,
  PRIMARY KEY (PKID)
) IN @DB_NAME@.TEMPL62;

CREATE UNIQUE INDEX 
  @SCHEMA@.ERROR_EVENT_TEMPLATE_P
  ON @SCHEMA@.ERROR_EVENT_TEMPLATE_T
(   
  PKID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column ERROR_MESSAGE_DEFINITION
CREATE AUX TABLE @SCHEMA@.AT213435
   IN @DB_NAME@.AS213435
 STORES @SCHEMA@.ERROR_EVENT_TEMPLATE_T COLUMN
 ERROR_MESSAGE_DEFINITION;
-- auxiliary index for LOB column ERROR_MESSAGE_DEFINITION
CREATE UNIQUE INDEX @SCHEMA@.AT213435I
  ON @SCHEMA@.AT213435
   USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.STAFF_QUERY_TEMPLATE_T
(
 QTID CHAR(16) FOR BIT DATA NOT NULL ,
 ASSOCIATED_OBJECT_TYPE INTEGER NOT NULL ,
 ASSOCIATED_OID CHAR(16) FOR BIT DATA NOT NULL ,
 T_QUERY VARCHAR(32) NOT NULL ,
 QUERY BLOB(3900K) NOT NULL ,
 HASH_CODE INTEGER NOT NULL ,
 SUBSTITUTION_POLICY INTEGER NOT NULL ,
 STAFF_VERB BLOB(3900K) ,
  PRIMARY KEY (QTID)
) IN @DB_NAME@.TEMPL30;

CREATE UNIQUE INDEX 
  @SCHEMA@.STAFF_QUERY_TEMPLATE_P
  ON @SCHEMA@.STAFF_QUERY_TEMPLATE_T
(   
  QTID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column QUERY
CREATE AUX TABLE @SCHEMA@.AT213436
   IN @DB_NAME@.AS213436
   STORES @SCHEMA@.STAFF_QUERY_TEMPLATE_T COLUMN QUERY;
-- auxiliary index for LOB column QUERY
CREATE UNIQUE INDEX @SCHEMA@.AT213436I
  ON @SCHEMA@.AT213436
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column STAFF_VERB
CREATE AUX TABLE @SCHEMA@.AT213437
   IN @DB_NAME@.AS213437
   STORES @SCHEMA@.STAFF_QUERY_TEMPLATE_T COLUMN STAFF_VERB;
-- auxiliary index for LOB column STAFF_VERB
CREATE UNIQUE INDEX @SCHEMA@.AT213437I
  ON @SCHEMA@.AT213437
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.SQT_HASH
  ON @SCHEMA@.STAFF_QUERY_TEMPLATE_T
(   
  ASSOCIATED_OID, 
  HASH_CODE, 
  T_QUERY, 
  ASSOCIATED_OBJECT_TYPE
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
(
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 SHARED_PC_ID CHAR(16) FOR BIT DATA ,
 STATE INTEGER NOT NULL ,
 PENDING_REQUEST INTEGER NOT NULL ,
 CREATED TIMESTAMP ,
 STARTED TIMESTAMP ,
 COMPLETED TIMESTAMP ,
 LAST_STATE_CHANGE TIMESTAMP ,
 LAST_MODIFIED TIMESTAMP ,
 NAME VARCHAR(220) NOT NULL ,
 PARENT_NAME VARCHAR(220) ,
 TOP_LEVEL_NAME VARCHAR(220) NOT NULL ,
 COMPENSATION_SPHERE_NAME VARCHAR(100) ,
 STARTER VARCHAR(128) ,
 DESCRIPTION VARCHAR(254) ,
 INPUT_SNID CHAR(16) FOR BIT DATA ,
 INPUT_ATID CHAR(16) FOR BIT DATA ,
 INPUT_VTID CHAR(16) FOR BIT DATA ,
 OUTPUT_SNID CHAR(16) FOR BIT DATA ,
 OUTPUT_ATID CHAR(16) FOR BIT DATA ,
 OUTPUT_VTID CHAR(16) FOR BIT DATA ,
 FAULT_NAME VARCHAR(254) ,
 TOP_LEVEL_PIID CHAR(16) FOR BIT DATA NOT NULL ,
 PARENT_PIID CHAR(16) FOR BIT DATA ,
 PARENT_AIID CHAR(16) FOR BIT DATA ,
 TKIID CHAR(16) FOR BIT DATA ,
 TERMIN_ON_REC SMALLINT NOT NULL ,
 AWAITED_SUB_PROC SMALLINT NOT NULL ,
 IS_CREATING SMALLINT NOT NULL ,
 PREVIOUS_STATE INTEGER ,
 EXECUTING_ISOLATED_SCOPE SMALLINT NOT NULL ,
 SCHEDULER_TASK_ID VARCHAR(254) ,
 RESUMES TIMESTAMP ,
 PENDING_SKIP_REQUEST SMALLINT NOT NULL ,
 IS_MIGRATED SMALLINT NOT NULL ,
 UNHANDLED_EXCEPTION BLOB(1073741823) ,
 ERROR_EVENT_ATID CHAR(16) FOR BIT DATA ,
 CREATED_WITH_VERSION INTEGER NOT NULL ,
 WSID_1 CHAR(16) FOR BIT DATA ,
 WSID_1_HC INTEGER ,
 WSID_2 CHAR(16) FOR BIT DATA ,
 WSID_2_HC INTEGER ,
 CUSTOM_TEXT1 VARCHAR(64) ,
 CUSTOM_TEXT2 VARCHAR(64) ,
 CUSTOM_TEXT3 VARCHAR(64) ,
 CUSTOM_TEXT4 VARCHAR(64) ,
 CUSTOM_TEXT5 VARCHAR(64) ,
 CUSTOM_TEXT6 VARCHAR(64) ,
 CUSTOM_TEXT7 VARCHAR(64) ,
 CUSTOM_TEXT8 VARCHAR(64) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (PIID)
) IN @DB_NAME@.INSTA01;

CREATE UNIQUE INDEX 
  @SCHEMA@.PROCESS_INSTANCE_B_P
  ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  PIID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column UNHANDLED_EXCEPTION
CREATE AUX TABLE @SCHEMA@.AT213438
   IN @DB_NAME@.AS213438
   STORES @SCHEMA@.PROCESS_INSTANCE_B_T COLUMN UNHANDLED_EXCEPTION;
-- auxiliary index for LOB column UNHANDLED_EXCEPTION
CREATE UNIQUE INDEX @SCHEMA@.AT213438I
  ON @SCHEMA@.AT213438
   USING STOGROUP @STOGRP@;


CREATE UNIQUE INDEX 
  @SCHEMA@.PIB_NAME
  ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.PIB_TOP
  ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  TOP_LEVEL_PIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.PIB_PAP
  ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  PARENT_PIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.PIB_PAR
  ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  PARENT_AIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.PIB_PTID
  ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.PIB_WSID1
  ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  WSID_1, 
  STATE
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.PIB_WSID2
  ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  WSID_2, 
  STATE
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.PIB_STA_PT_ST2_PI
  ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  STATE, 
  PTID, 
  STARTER, 
  STARTED, 
  PIID
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.SCOPE_INSTANCE_B_T
(
 SIID CHAR(16) FOR BIT DATA NOT NULL ,
 PARENT_SIID CHAR(16) FOR BIT DATA ,
 STID CHAR(16) FOR BIT DATA NOT NULL ,
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 EHIID CHAR(16) FOR BIT DATA ,
 ENCLOSING_FEIID CHAR(16) FOR BIT DATA ,
 ENCLOSING_FOR_EACH_END_AIID CHAR(16) FOR BIT DATA ,
 COMPENSATE_AIID CHAR(16) FOR BIT DATA ,
 PARENT_COMP_SIID CHAR(16) FOR BIT DATA ,
 LAST_COMP_SIID CHAR(16) FOR BIT DATA ,
 RUNNING_EVENT_HANDLERS INTEGER NOT NULL ,
 STATE INTEGER NOT NULL ,
 NOTIFY_PARENT SMALLINT NOT NULL ,
 AWAITED_SCOPES INTEGER NOT NULL ,
 AWAITED_SUB_PROCESSES INTEGER NOT NULL ,
 BPEL_EXCEPTION BLOB(1073741823) ,
 IS_ACTIVE SMALLINT NOT NULL ,
 INITIATED_COMP SMALLINT NOT NULL ,
 IS_TERMINATION_FROM_FOR_EACH SMALLINT NOT NULL ,
 TOTAL_COMPL_NUMBER NUMERIC(20) NOT NULL ,
 SCOPE_COMPL_NUMBER NUMERIC(20) NOT NULL ,
 A_TKIID CHAR(16) FOR BIT DATA ,
 HAS_COMPENSATION_WORK SMALLINT NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (SIID)
) IN @DB_NAME@.INSTA02;

CREATE UNIQUE INDEX 
  @SCHEMA@.SCOPE_INSTANCE_B_P
  ON @SCHEMA@.SCOPE_INSTANCE_B_T
(   
  SIID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column BPEL_EXCEPTION
CREATE AUX TABLE @SCHEMA@.AT213439
   IN @DB_NAME@.AS213439
   STORES @SCHEMA@.SCOPE_INSTANCE_B_T COLUMN BPEL_EXCEPTION;
-- auxiliary index for LOB column BPEL_EXCEPTION
CREATE UNIQUE INDEX @SCHEMA@.AT213439I
  ON @SCHEMA@.AT213439
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.SI_PI_ST_EH_ACT_FE
  ON @SCHEMA@.SCOPE_INSTANCE_B_T
(   
  PIID, 
  STID, 
  IS_ACTIVE, 
  EHIID, 
  ENCLOSING_FEIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.SI_PIID_PARSI
  ON @SCHEMA@.SCOPE_INSTANCE_B_T
(   
  PIID, 
  PARENT_SIID, 
  IS_ACTIVE
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.SI_PARCOMP_STA_ST
  ON @SCHEMA@.SCOPE_INSTANCE_B_T
(   
  PARENT_COMP_SIID, 
  STATE, 
  STID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.SI_PIID_STATE
  ON @SCHEMA@.SCOPE_INSTANCE_B_T
(   
  PIID, 
  STATE
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.SI_LAST_COMPSIID
  ON @SCHEMA@.SCOPE_INSTANCE_B_T
(   
  LAST_COMP_SIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.SI_PI_ST_EH_FE_STA
  ON @SCHEMA@.SCOPE_INSTANCE_B_T
(   
  PIID, 
  STID, 
  EHIID, 
  ENCLOSING_FEIID, 
  STATE
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.SI_PARCOMP_STA_SCN
  ON @SCHEMA@.SCOPE_INSTANCE_B_T
(   
  PARENT_COMP_SIID, 
  STATE, 
  SCOPE_COMPL_NUMBER
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
(
 AIID CHAR(16) FOR BIT DATA NOT NULL ,
 ATID CHAR(16) FOR BIT DATA NOT NULL ,
 SIID CHAR(16) FOR BIT DATA ,
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 EHIID CHAR(16) FOR BIT DATA ,
 ENCLOSING_FEIID CHAR(16) FOR BIT DATA ,
 ICIID CHAR(16) FOR BIT DATA ,
 PARENT_AIID CHAR(16) FOR BIT DATA ,
 ERROR_EVENT_ATID CHAR(16) FOR BIT DATA ,
 P_TKIID CHAR(16) FOR BIT DATA ,
 A_TKIID CHAR(16) FOR BIT DATA ,
 INVOKED_INSTANCE_ID CHAR(16) FOR BIT DATA ,
 INVOKED_INSTANCE_TYPE INTEGER NOT NULL ,
 STATE INTEGER NOT NULL ,
 BPMN_STATE INTEGER NOT NULL ,
 TRANS_COND_VALUES VARCHAR(66) FOR BIT DATA NOT NULL ,
 NUMBER_LINKS_EVALUATED INTEGER NOT NULL ,
 FINISHED TIMESTAMP ,
 ACTIVATED TIMESTAMP ,
 FIRST_ACTIVATED TIMESTAMP ,
 STARTED TIMESTAMP ,
 LAST_MODIFIED TIMESTAMP ,
 LAST_STATE_CHANGE TIMESTAMP ,
 OWNER VARCHAR(128) ,
 DESCRIPTION VARCHAR(254) ,
 LINK_ORDER_NUMBER INTEGER ,
 SCHEDULER_TASK_ID VARCHAR(254) ,
 EXPIRES TIMESTAMP ,
 CONTINUE_ON_ERROR SMALLINT NOT NULL ,
 UNHANDLED_EXCEPTION BLOB(1073741823) ,
 STOP_REASON INTEGER NOT NULL ,
 PREVIOUS_STATE INTEGER ,
 INVOCATION_COUNTER INTEGER NOT NULL ,
 FOR_EACH_START_COUNTER_VALUE NUMERIC(20) ,
 FOR_EACH_FINAL_COUNTER_VALUE NUMERIC(20) ,
 FOR_EACH_CURRENT_COUNTER_VALUE NUMERIC(20) ,
 FOR_EACH_COMPLETED_BRANCHES NUMERIC(20) ,
 FOR_EACH_FAILED_BRANCHES NUMERIC(20) ,
 FOR_EACH_MAX_COMPL_BRANCHES NUMERIC(20) ,
 FOR_EACH_AWAITED_BRANCHES NUMERIC(20) ,
 IS51_ACTIVITY SMALLINT NOT NULL ,
 MAY_HAVE_SUBPROCESS SMALLINT ,
 SKIP_REQUESTED SMALLINT NOT NULL ,
 JUMP_TARGET_ATID CHAR(16) FOR BIT DATA ,
 SUB_STATE INTEGER NOT NULL ,
 PENDING_REQUEST_DATA BLOB(1073741823) ,
 XTID CHAR(16) FOR BIT DATA ,
 EXPIRATION_COUNTER INTEGER ,
 PREVIOUS_EXPIRATION_DATE TIMESTAMP ,
 TARGET_IORAIID CHAR(16) FOR BIT DATA ,
 DISPLAY_ID_EXT VARCHAR(32) ,
 MAX_COMPENSATION_NUMBER NUMERIC(20) ,
 HAS_WORK_ITEM SMALLINT ,
 WSID_1 CHAR(16) FOR BIT DATA ,
 WSID_1_HC INTEGER ,
 WSID_2 CHAR(16) FOR BIT DATA ,
 WSID_2_HC INTEGER ,
 LOOP_COUNTER INTEGER ,
 AWAITED_ACTIVITIES INTEGER NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (AIID)
) IN @DB_NAME@.INSTA03;

CREATE UNIQUE INDEX 
  @SCHEMA@.ACTIVITY_INSTANCE_B_P
  ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  AIID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column UNHANDLED_EXCEPTION
CREATE AUX TABLE @SCHEMA@.AT21343A
   IN @DB_NAME@.AS21343A
   STORES @SCHEMA@.ACTIVITY_INSTANCE_B_T COLUMN UNHANDLED_EXCEPTION;
-- auxiliary index for LOB column UNHANDLED_EXCEPTION
CREATE UNIQUE INDEX @SCHEMA@.AT21343AI
  ON @SCHEMA@.AT21343A
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column PENDING_REQUEST_DATA
CREATE AUX TABLE @SCHEMA@.AT21343B
   IN @DB_NAME@.AS21343B
   STORES @SCHEMA@.ACTIVITY_INSTANCE_B_T COLUMN PENDING_REQUEST_DATA;
-- auxiliary index for LOB column PENDING_REQUEST_DATA
CREATE UNIQUE INDEX @SCHEMA@.AT21343BI
  ON @SCHEMA@.AT21343B
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.AIB_PI_EH_FE_AT
  ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  PIID, 
  EHIID, 
  ENCLOSING_FEIID, 
  ATID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.AIB_PI_EH_EF_DIS
  ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  PIID, 
  EHIID, 
  ENCLOSING_FEIID, 
  DISPLAY_ID_EXT
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.AIB_IC_PI_AT
  ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  ICIID, 
  PIID, 
  ATID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.AIB_PTID
  ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.AIB_PI_STA_AI
  ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  PIID, 
  STATE, 
  AIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.AIB_SIID
  ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  SIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.AIB_ATID_STAT
  ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  ATID, 
  STATE
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.AIB_PI_AT
  ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  PIID, 
  ATID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.AIB_WSID1
  ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  WSID_1, 
  STATE
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.AIB_WSID2
  ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  WSID_2, 
  STATE
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.VARIABLE_INSTANCE_B_T
(
 CTID CHAR(16) FOR BIT DATA NOT NULL ,
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 DATA BLOB(1073741823) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (CTID, PIID)
) IN @DB_NAME@.INSTA04;

CREATE UNIQUE INDEX 
  @SCHEMA@.VARIABLE_INSTANCE_B_P
  ON @SCHEMA@.VARIABLE_INSTANCE_B_T
(   
  CTID, 
  PIID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column DATA
CREATE AUX TABLE @SCHEMA@.AT21343C
   IN @DB_NAME@.AS21343C
   STORES @SCHEMA@.VARIABLE_INSTANCE_B_T COLUMN DATA;
-- auxiliary index for LOB column DATA
CREATE UNIQUE INDEX @SCHEMA@.AT21343CI
  ON @SCHEMA@.AT21343C
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.CI_PIID
  ON @SCHEMA@.VARIABLE_INSTANCE_B_T
(   
  PIID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.SCOPED_VARIABLE_INSTANCE_B_T
(
 SVIID CHAR(16) FOR BIT DATA NOT NULL ,
 CTID CHAR(16) FOR BIT DATA NOT NULL ,
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 SIID CHAR(16) FOR BIT DATA NOT NULL ,
 EHIID CHAR(16) FOR BIT DATA ,
 FEIID CHAR(16) FOR BIT DATA ,
 DATA BLOB(1073741823) ,
 DATA_IL VARCHAR(3000) FOR BIT DATA ,
 IS_ACTIVE SMALLINT NOT NULL ,
 IS_INITIALIZED SMALLINT NOT NULL ,
 IS_QUERYABLE SMALLINT NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (SVIID)
) IN @DB_NAME@.INST805;

CREATE UNIQUE INDEX 
  @SCHEMA@.SCOPED_VARIABLE_INSTANCE_B_P
  ON @SCHEMA@.SCOPED_VARIABLE_INSTANCE_B_T
(   
  SVIID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column DATA
CREATE AUX TABLE @SCHEMA@.AT21343D
   IN @DB_NAME@.AS21343D
   STORES @SCHEMA@.SCOPED_VARIABLE_INSTANCE_B_T COLUMN DATA;
-- auxiliary index for LOB column DATA
CREATE UNIQUE INDEX @SCHEMA@.AT21343DI
  ON @SCHEMA@.AT21343D
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.SVI_PI_CT_EH_FE
  ON @SCHEMA@.SCOPED_VARIABLE_INSTANCE_B_T
(   
  PIID, 
  CTID, 
  IS_ACTIVE, 
  EHIID, 
  FEIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.SVI_CT_SI_EH_AC
  ON @SCHEMA@.SCOPED_VARIABLE_INSTANCE_B_T
(   
  SIID, 
  CTID, 
  IS_ACTIVE, 
  EHIID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.STAFF_MESSAGE_INSTANCE_B_T
(
 AIID CHAR(16) FOR BIT DATA NOT NULL ,
 KIND INTEGER NOT NULL ,
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 DATA BLOB(1073741823) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (AIID, KIND)
) IN @DB_NAME@.INSTA06;

CREATE UNIQUE INDEX 
  @SCHEMA@.STAFF_MESSAGE_INSTANCE_B_P
  ON @SCHEMA@.STAFF_MESSAGE_INSTANCE_B_T
(   
  AIID, 
  KIND
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column DATA
CREATE AUX TABLE @SCHEMA@.AT21343E
   IN @DB_NAME@.AS21343E
   STORES @SCHEMA@.STAFF_MESSAGE_INSTANCE_B_T COLUMN DATA;
-- auxiliary index for LOB column DATA
CREATE UNIQUE INDEX @SCHEMA@.AT21343EI
  ON @SCHEMA@.AT21343E
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.SMI_PIID
  ON @SCHEMA@.STAFF_MESSAGE_INSTANCE_B_T
(   
  PIID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.EVENT_INSTANCE_B_T
(
 EIID CHAR(16) FOR BIT DATA NOT NULL ,
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 VTID CHAR(16) FOR BIT DATA NOT NULL ,
 IS_TWO_WAY SMALLINT NOT NULL ,
 IS_PRIMARY_EVENT_INSTANCE SMALLINT NOT NULL ,
 STATE INTEGER NOT NULL ,
 AIID CHAR(16) FOR BIT DATA ,
 EHTID CHAR(16) FOR BIT DATA ,
 SIID CHAR(16) FOR BIT DATA ,
 TKIID CHAR(16) FOR BIT DATA ,
 NEXT_POSTED_EVENT CHAR(16) FOR BIT DATA ,
 LAST_POSTED_EVENT CHAR(16) FOR BIT DATA ,
 POST_COUNT INTEGER NOT NULL ,
 WSID_1 CHAR(16) FOR BIT DATA ,
 WSID_1_HC INTEGER ,
 WSID_2 CHAR(16) FOR BIT DATA ,
 WSID_2_HC INTEGER ,
 MESSAGE BLOB(1073741823) ,
 REPLY_CONTEXT BLOB(3900k) ,
 POST_TIME TIMESTAMP ,
 MAX_NUMBER_OF_POSTS INTEGER NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (EIID)
) IN @DB_NAME@.INSTA07;

CREATE UNIQUE INDEX 
  @SCHEMA@.EVENT_INSTANCE_B_P
  ON @SCHEMA@.EVENT_INSTANCE_B_T
(   
  EIID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column MESSAGE
CREATE AUX TABLE @SCHEMA@.AT21343F
   IN @DB_NAME@.AS21343F
   STORES @SCHEMA@.EVENT_INSTANCE_B_T COLUMN MESSAGE;
-- auxiliary index for LOB column MESSAGE
CREATE UNIQUE INDEX @SCHEMA@.AT21343FI
  ON @SCHEMA@.AT21343F
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column REPLY_CONTEXT
CREATE AUX TABLE @SCHEMA@.AT213440
   IN @DB_NAME@.AS213440
   STORES @SCHEMA@.EVENT_INSTANCE_B_T COLUMN REPLY_CONTEXT;
-- auxiliary index for LOB column REPLY_CONTEXT
CREATE UNIQUE INDEX @SCHEMA@.AT213440I
  ON @SCHEMA@.AT213440
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.EI_WSID1
  ON @SCHEMA@.EVENT_INSTANCE_B_T
(   
  WSID_1
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.EI_WSID2
  ON @SCHEMA@.EVENT_INSTANCE_B_T
(   
  WSID_2
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.EI_PI_PRIM_VTID
  ON @SCHEMA@.EVENT_INSTANCE_B_T
(   
  PIID, 
  IS_PRIMARY_EVENT_INSTANCE, 
  VTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.REQUEST_INSTANCE_B_T
(
 RIID CHAR(16) FOR BIT DATA NOT NULL ,
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 VTID CHAR(16) FOR BIT DATA NOT NULL ,
 ATID CHAR(16) FOR BIT DATA NOT NULL ,
 EHIID CHAR(16) FOR BIT DATA ,
 TKIID CHAR(16) FOR BIT DATA ,
 FEIID CHAR(16) FOR BIT DATA ,
 INSTANTIATING SMALLINT NOT NULL ,
 REPLY_CONTEXT BLOB(3900k) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (RIID)
) IN @DB_NAME@.INSTA08;

CREATE UNIQUE INDEX 
  @SCHEMA@.REQUEST_INSTANCE_B_P
  ON @SCHEMA@.REQUEST_INSTANCE_B_T
(   
  RIID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column REPLY_CONTEXT
CREATE AUX TABLE @SCHEMA@.AT213441
   IN @DB_NAME@.AS213441
   STORES @SCHEMA@.REQUEST_INSTANCE_B_T COLUMN REPLY_CONTEXT;
-- auxiliary index for LOB column REPLY_CONTEXT
CREATE UNIQUE INDEX @SCHEMA@.AT213441I
  ON @SCHEMA@.AT213441
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.RI_PIID_VTID_EHIID
  ON @SCHEMA@.REQUEST_INSTANCE_B_T
(   
  PIID, 
  VTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.PARTNER_LINK_INSTANCE_B_T
(
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 NAME VARCHAR(220) NOT NULL ,
 ENDPOINT_REFERENCE BLOB(3900k) ,
 SERVICE_DEFINITION BLOB(3900k) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (PIID, NAME)
) IN @DB_NAME@.INSTA09;

CREATE UNIQUE INDEX 
  @SCHEMA@.PARTNER_LINK_INSTANCE_B_P
  ON @SCHEMA@.PARTNER_LINK_INSTANCE_B_T
(   
  PIID, 
  NAME
) NOT PADDED
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column ENDPOINT_REFERENCE
CREATE AUX TABLE @SCHEMA@.AT213442
   IN @DB_NAME@.AS213442
 STORES @SCHEMA@.PARTNER_LINK_INSTANCE_B_T COLUMN ENDPOINT_REFERENCE;
-- auxiliary index for LOB column ENDPOINT_REFERENCE
CREATE UNIQUE INDEX @SCHEMA@.AT213442I
  ON @SCHEMA@.AT213442
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column SERVICE_DEFINITION
CREATE AUX TABLE @SCHEMA@.AT213443
   IN @DB_NAME@.AS213443
 STORES @SCHEMA@.PARTNER_LINK_INSTANCE_B_T COLUMN SERVICE_DEFINITION;
-- auxiliary index for LOB column SERVICE_DEFINITION
CREATE UNIQUE INDEX @SCHEMA@.AT213443I
  ON @SCHEMA@.AT213443
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.PA_PIID
  ON @SCHEMA@.PARTNER_LINK_INSTANCE_B_T
(   
  PIID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.VARIABLE_SNAPSHOT_B_T
(
 SNID CHAR(16) FOR BIT DATA NOT NULL ,
 CTID CHAR(16) FOR BIT DATA NOT NULL ,
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 DATA BLOB(1073741823) ,
 COPY_VERSION SMALLINT NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (SNID)
) IN @DB_NAME@.INSTA10;

CREATE UNIQUE INDEX 
  @SCHEMA@.VARIABLE_SNAPSHOT_B_P
  ON @SCHEMA@.VARIABLE_SNAPSHOT_B_T
(   
  SNID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column DATA
CREATE AUX TABLE @SCHEMA@.AT213444
   IN @DB_NAME@.AS213444
   STORES @SCHEMA@.VARIABLE_SNAPSHOT_B_T COLUMN DATA;
-- auxiliary index for LOB column DATA
CREATE UNIQUE INDEX @SCHEMA@.AT213444I
  ON @SCHEMA@.AT213444
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.SN_PIID_CTID
  ON @SCHEMA@.VARIABLE_SNAPSHOT_B_T
(   
  PIID, 
  CTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.SUSPENDED_MESSAGE_INSTANCE_B_T
(
 PKID CHAR(16) FOR BIT DATA NOT NULL ,
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 ENGINE_MESSAGE BLOB(1073741823) NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (PKID)
) IN @DB_NAME@.INSTA12;

CREATE UNIQUE INDEX 
  @SCHEMA@.SUSPENDED_MESSAGE_INSTANCE_B_P
  ON @SCHEMA@.SUSPENDED_MESSAGE_INSTANCE_B_T
(   
  PKID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column ENGINE_MESSAGE
CREATE AUX TABLE @SCHEMA@.AT213445
   IN @DB_NAME@.AS213445
 STORES @SCHEMA@.SUSPENDED_MESSAGE_INSTANCE_B_T COLUMN
 ENGINE_MESSAGE;
-- auxiliary index for LOB column ENGINE_MESSAGE
CREATE UNIQUE INDEX @SCHEMA@.AT213445I
  ON @SCHEMA@.AT213445
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.PIID
  ON @SCHEMA@.SUSPENDED_MESSAGE_INSTANCE_B_T
(   
  PIID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.CROSSING_LINK_INSTANCE_B_T
(
 PKID CHAR(16) FOR BIT DATA NOT NULL ,
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 SOURCE_ATID CHAR(16) FOR BIT DATA NOT NULL ,
 TARGET_ATID CHAR(16) FOR BIT DATA NOT NULL ,
 EHIID CHAR(16) FOR BIT DATA ,
 FEIID CHAR(16) FOR BIT DATA ,
 CONDITION_VALUE INTEGER NOT NULL ,
 DESCRIPTION VARCHAR(254) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (PKID)
) IN @DB_NAME@.INSTA13;

CREATE UNIQUE INDEX 
  @SCHEMA@.CROSSING_LINK_INSTANCE_B_P
  ON @SCHEMA@.CROSSING_LINK_INSTANCE_B_T
(   
  PKID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.CL_PI_TAT_EH_FE_SA
  ON @SCHEMA@.CROSSING_LINK_INSTANCE_B_T
(   
  PIID, 
  TARGET_ATID, 
  EHIID, 
  FEIID, 
  SOURCE_ATID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.INVOKE_RESULT_B_T
(
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 ATID CHAR(16) FOR BIT DATA NOT NULL ,
 STATE INTEGER NOT NULL ,
 INVOKE_RESULT BLOB(1073741823) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (PIID, ATID)
) IN @DB_NAME@.INSTA14;

CREATE UNIQUE INDEX 
  @SCHEMA@.INVOKE_RESULT_B_P
  ON @SCHEMA@.INVOKE_RESULT_B_T
(   
  PIID, 
  ATID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column INVOKE_RESULT
CREATE AUX TABLE @SCHEMA@.AT213446
   IN @DB_NAME@.AS213446
   STORES @SCHEMA@.INVOKE_RESULT_B_T COLUMN INVOKE_RESULT;
-- auxiliary index for LOB column INVOKE_RESULT
CREATE UNIQUE INDEX @SCHEMA@.AT213446I
  ON @SCHEMA@.AT213446
   USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.INVOKE_RESULT2_B_T
(
 IRID CHAR(16) FOR BIT DATA NOT NULL ,
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 ATID CHAR(16) FOR BIT DATA NOT NULL ,
 EHIID CHAR(16) FOR BIT DATA ,
 FEIID CHAR(16) FOR BIT DATA ,
 STATE INTEGER NOT NULL ,
 INVOKE_RESULT BLOB(1073741823) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (IRID)
) IN @DB_NAME@.INSTA49;

CREATE UNIQUE INDEX 
  @SCHEMA@.INVOKE_RESULT2_B_P
  ON @SCHEMA@.INVOKE_RESULT2_B_T
(   
  IRID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column INVOKE_RESULT
CREATE AUX TABLE @SCHEMA@.AT213447
   IN @DB_NAME@.AS213447
   STORES @SCHEMA@.INVOKE_RESULT2_B_T COLUMN INVOKE_RESULT;
-- auxiliary index for LOB column INVOKE_RESULT
CREATE UNIQUE INDEX @SCHEMA@.AT213447I
  ON @SCHEMA@.AT213447
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.IR2_PI_AT_EH_FE
  ON @SCHEMA@.INVOKE_RESULT2_B_T
(   
  PIID, 
  ATID, 
  EHIID, 
  FEIID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.EVENT_HANDLER_INSTANCE_B_T
(
 EHIID CHAR(16) FOR BIT DATA NOT NULL ,
 EHTID CHAR(16) FOR BIT DATA NOT NULL ,
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 SIID CHAR(16) FOR BIT DATA NOT NULL ,
 PARENT_EHIID CHAR(16) FOR BIT DATA ,
 FEIID CHAR(16) FOR BIT DATA ,
 SCHEDULER_TASK_ID VARCHAR(254) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (EHIID)
) IN @DB_NAME@.INSTA15;

CREATE UNIQUE INDEX 
  @SCHEMA@.EVENT_HANDLER_INSTANCE_B_P
  ON @SCHEMA@.EVENT_HANDLER_INSTANCE_B_T
(   
  EHIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.EHI_PIID_EHTID
  ON @SCHEMA@.EVENT_HANDLER_INSTANCE_B_T
(   
  PIID, 
  EHTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.EHI_SIID_EHTID
  ON @SCHEMA@.EVENT_HANDLER_INSTANCE_B_T
(   
  SIID, 
  EHTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.CORRELATION_SET_INSTANCE_B_T
(
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 COID CHAR(16) FOR BIT DATA NOT NULL ,
 SIID CHAR(16) FOR BIT DATA NOT NULL ,
 PROCESS_NAME VARCHAR(220) NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 STATUS INTEGER NOT NULL ,
 HASH_CODE CHAR(16) FOR BIT DATA NOT NULL ,
 DATA VARCHAR(3072) ,
 DATA_LONG CLOB(3900K) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (PIID, COID, SIID)
) IN @DB_NAME@.INST816;

CREATE UNIQUE INDEX 
  @SCHEMA@.CORRELATION_SET_INSTANCE_B_P
  ON @SCHEMA@.CORRELATION_SET_INSTANCE_B_T
(   
  PIID, 
  COID, 
  SIID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column DATA_LONG
CREATE AUX TABLE @SCHEMA@.AT213448
   IN @DB_NAME@.AS213448
   STORES @SCHEMA@.CORRELATION_SET_INSTANCE_B_T COLUMN DATA_LONG;
-- auxiliary index for LOB column DATA_LONG
CREATE UNIQUE INDEX @SCHEMA@.AT213448I
  ON @SCHEMA@.AT213448
   USING STOGROUP @STOGRP@;


CREATE UNIQUE INDEX 
  @SCHEMA@.CSIB_HASH_PN
  ON @SCHEMA@.CORRELATION_SET_INSTANCE_B_T
(   
  HASH_CODE, 
  PROCESS_NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.CSIB_PIID
  ON @SCHEMA@.CORRELATION_SET_INSTANCE_B_T
(   
  PIID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.CORRELATION_SET_PROPERTIES_B_T
(
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 COID CHAR(16) FOR BIT DATA NOT NULL ,
 SIID CHAR(16) FOR BIT DATA NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 DATA BLOB(3900K) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (PIID, COID, SIID)
) IN @DB_NAME@.INSTA17;

CREATE UNIQUE INDEX 
  @SCHEMA@.CORRELATION_SET_PROPERTIES_B_P
  ON @SCHEMA@.CORRELATION_SET_PROPERTIES_B_T
(   
  PIID, 
  COID, 
  SIID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column DATA
CREATE AUX TABLE @SCHEMA@.AT213449
   IN @DB_NAME@.AS213449
   STORES @SCHEMA@.CORRELATION_SET_PROPERTIES_B_T COLUMN DATA;
-- auxiliary index for LOB column DATA
CREATE UNIQUE INDEX @SCHEMA@.AT213449I
  ON @SCHEMA@.AT213449
   USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.UNDO_ACTION_B_T
(
 PKID CHAR(16) FOR BIT DATA NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 ATID CHAR(16) FOR BIT DATA NOT NULL ,
 PARENT_ATID CHAR(16) FOR BIT DATA ,
 PARENT_PIID CHAR(16) FOR BIT DATA ,
 PARENT_AIID CHAR(16) FOR BIT DATA ,
 PARENT_EHIID CHAR(16) FOR BIT DATA ,
 PARENT_FEIID CHAR(16) FOR BIT DATA ,
 PROCESS_NAME VARCHAR(220) NOT NULL ,
 CSCOPE_ID VARCHAR(100) NOT NULL ,
 UUID VARCHAR(100) NOT NULL ,
 COMP_CREATION_TIME TIMESTAMP NOT NULL ,
 DO_OP_WAS_TXNAL SMALLINT NOT NULL ,
 STATE INTEGER NOT NULL ,
 INPUT_DATA BLOB(1073741823) NOT NULL ,
 FAULT_DATA BLOB(1073741823) ,
 CREATED INTEGER NOT NULL ,
 PROCESS_ADMIN VARCHAR(128) NOT NULL ,
 IS_VISIBLE SMALLINT NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (PKID)
) IN @DB_NAME@.INSTA18;

CREATE UNIQUE INDEX 
  @SCHEMA@.UNDO_ACTION_B_P
  ON @SCHEMA@.UNDO_ACTION_B_T
(   
  PKID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column INPUT_DATA
CREATE AUX TABLE @SCHEMA@.AT21344A
   IN @DB_NAME@.AS21344A
   STORES @SCHEMA@.UNDO_ACTION_B_T COLUMN INPUT_DATA;
-- auxiliary index for LOB column INPUT_DATA
CREATE UNIQUE INDEX @SCHEMA@.AT21344AI
  ON @SCHEMA@.AT21344A
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column FAULT_DATA
CREATE AUX TABLE @SCHEMA@.AT21344B
   IN @DB_NAME@.AS21344B
   STORES @SCHEMA@.UNDO_ACTION_B_T COLUMN FAULT_DATA;
-- auxiliary index for LOB column FAULT_DATA
CREATE UNIQUE INDEX @SCHEMA@.AT21344BI
  ON @SCHEMA@.AT21344B
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.UA_CSID_DOOP_UUID
  ON @SCHEMA@.UNDO_ACTION_B_T
(   
  CSCOPE_ID, 
  DO_OP_WAS_TXNAL, 
  UUID
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.UA_CSID_STATE_CCT
  ON @SCHEMA@.UNDO_ACTION_B_T
(   
  CSCOPE_ID, 
  STATE, 
  UUID
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.UA_STATE_ISV
  ON @SCHEMA@.UNDO_ACTION_B_T
(   
  STATE, 
  IS_VISIBLE
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.UA_AIID_STATE_UUID
  ON @SCHEMA@.UNDO_ACTION_B_T
(   
  PARENT_AIID, 
  STATE, 
  UUID
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.UA_PIID
  ON @SCHEMA@.UNDO_ACTION_B_T
(   
  PARENT_PIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.UA_PT_AT_CS_UU_CCT
  ON @SCHEMA@.UNDO_ACTION_B_T
(   
  PTID, 
  ATID, 
  CSCOPE_ID, 
  UUID, 
  COMP_CREATION_TIME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.CUSTOM_STMT_INSTANCE_B_T
(
 PKID CHAR(16) FOR BIT DATA NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 SVIID CHAR(16) FOR BIT DATA ,
 NAMESPACE VARCHAR(220) NOT NULL ,
 LOCALNAME VARCHAR(220) NOT NULL ,
 PURPOSE VARCHAR(220) NOT NULL ,
 STATEMENT BLOB(3900K) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (PKID)
) IN @DB_NAME@.INSTA19;

CREATE UNIQUE INDEX 
  @SCHEMA@.CUSTOM_STMT_INSTANCE_B_P
  ON @SCHEMA@.CUSTOM_STMT_INSTANCE_B_T
(   
  PKID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column STATEMENT
CREATE AUX TABLE @SCHEMA@.AT21344C
   IN @DB_NAME@.AS21344C
   STORES @SCHEMA@.CUSTOM_STMT_INSTANCE_B_T COLUMN STATEMENT;
-- auxiliary index for LOB column STATEMENT
CREATE UNIQUE INDEX @SCHEMA@.AT21344CI
  ON @SCHEMA@.AT21344C
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.CSI_PIID_NS_LN_P
  ON @SCHEMA@.CUSTOM_STMT_INSTANCE_B_T
(   
  PIID, 
  NAMESPACE, 
  LOCALNAME, 
  PURPOSE
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.CSI_SVIID_NS_LN_P
  ON @SCHEMA@.CUSTOM_STMT_INSTANCE_B_T
(   
  SVIID, 
  NAMESPACE, 
  LOCALNAME, 
  PURPOSE
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.COMP_WORK_PENDING_B_T
(
 PKID CHAR(16) FOR BIT DATA NOT NULL ,
 PARENT_PIID CHAR(16) FOR BIT DATA NOT NULL ,
 PARENT_ATID CHAR(16) FOR BIT DATA NOT NULL ,
 PARENT_EHIID CHAR(16) FOR BIT DATA ,
 PARENT_FEIID CHAR(16) FOR BIT DATA ,
 STATE INTEGER NOT NULL ,
 CSCOPE_ID VARCHAR(100) NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (PKID)
) IN @DB_NAME@.INSTA20;

CREATE UNIQUE INDEX 
  @SCHEMA@.COMP_WORK_PENDING_B_P
  ON @SCHEMA@.COMP_WORK_PENDING_B_T
(   
  PKID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.CWP_PI_AT_CS_EH_FE
  ON @SCHEMA@.COMP_WORK_PENDING_B_T
(   
  PARENT_PIID, 
  PARENT_ATID, 
  CSCOPE_ID, 
  PARENT_EHIID, 
  PARENT_FEIID
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.CWP_PI_AT_EHI
  ON @SCHEMA@.COMP_WORK_PENDING_B_T
(   
  PARENT_PIID, 
  PARENT_ATID, 
  PARENT_EHIID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.COMP_PARENT_ACTIVITY_INST_B_T
(
 AIID CHAR(16) FOR BIT DATA NOT NULL ,
 SIID CHAR(16) FOR BIT DATA NOT NULL ,
 ATID CHAR(16) FOR BIT DATA ,
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 COMPLETION_NUMBER NUMERIC(20) NOT NULL ,
 STATE INTEGER NOT NULL ,
 COMPENSATE_AIID CHAR(16) FOR BIT DATA ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (AIID)
) IN @DB_NAME@.INSTA21;

CREATE UNIQUE INDEX 
  @SCHEMA@.COMP_PARENT_ACTIVITY_INST_B_P
  ON @SCHEMA@.COMP_PARENT_ACTIVITY_INST_B_T
(   
  AIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.CPAI_SI_S_CN_AI_PI
  ON @SCHEMA@.COMP_PARENT_ACTIVITY_INST_B_T
(   
  SIID, 
  STATE, 
  COMPLETION_NUMBER, 
  AIID, 
  PIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.CPAI_PIID
  ON @SCHEMA@.COMP_PARENT_ACTIVITY_INST_B_T
(   
  PIID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.RESTART_EVENT_B_T
(
 PKID CHAR(16) FOR BIT DATA NOT NULL ,
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 PORT_TYPE VARCHAR(254) NOT NULL ,
 OPERATION VARCHAR(254) NOT NULL ,
 NAMESPACE VARCHAR(254) NOT NULL ,
 INPUT_MESSAGE BLOB(1073741823) ,
 REPLY_CTX BLOB(3900k) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (PKID)
) IN @DB_NAME@.INSTA22;

CREATE UNIQUE INDEX 
  @SCHEMA@.RESTART_EVENT_B_P
  ON @SCHEMA@.RESTART_EVENT_B_T
(   
  PKID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column INPUT_MESSAGE
CREATE AUX TABLE @SCHEMA@.AT21344D
   IN @DB_NAME@.AS21344D
   STORES @SCHEMA@.RESTART_EVENT_B_T COLUMN INPUT_MESSAGE;
-- auxiliary index for LOB column INPUT_MESSAGE
CREATE UNIQUE INDEX @SCHEMA@.AT21344DI
  ON @SCHEMA@.AT21344D
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column REPLY_CTX
CREATE AUX TABLE @SCHEMA@.AT21344E
   IN @DB_NAME@.AS21344E
   STORES @SCHEMA@.RESTART_EVENT_B_T COLUMN REPLY_CTX;
-- auxiliary index for LOB column REPLY_CTX
CREATE UNIQUE INDEX @SCHEMA@.AT21344EI
  ON @SCHEMA@.AT21344E
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.REB_PIID
  ON @SCHEMA@.RESTART_EVENT_B_T
(   
  PIID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.PROGRESS_COUNTER_T
(
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 COUNTER NUMERIC(20) NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (PIID)
) IN @DB_NAME@.INSTA60;

CREATE UNIQUE INDEX 
  @SCHEMA@.PROGRESS_COUNTER_P
  ON @SCHEMA@.PROGRESS_COUNTER_T
(   
  PIID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.RELEVANT_SCOPE_ATASK_T
(
 SIID CHAR(16) FOR BIT DATA NOT NULL ,
 TKIID CHAR(16) FOR BIT DATA NOT NULL ,
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (SIID, TKIID)
) IN @DB_NAME@.INSTA61;

CREATE UNIQUE INDEX 
  @SCHEMA@.RELEVANT_SCOPE_ATASK_P
  ON @SCHEMA@.RELEVANT_SCOPE_ATASK_T
(   
  SIID, 
  TKIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.RSAT_PIID
  ON @SCHEMA@.RELEVANT_SCOPE_ATASK_T
(   
  PIID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.CONFIG_INFO_T
(
 IDENTIFIER VARCHAR(64) NOT NULL ,
 DESCRIPTION VARCHAR(128) ,
 PROPERTY INTEGER ,
 COUNTER NUMERIC(20) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (IDENTIFIER)
) IN @DB_NAME@.INSTA62;

CREATE UNIQUE INDEX 
  @SCHEMA@.CONFIG_INFO_P
  ON @SCHEMA@.CONFIG_INFO_T
(   
  IDENTIFIER
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
(
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 ATTR_KEY VARCHAR(220) NOT NULL ,
 VALUE VARCHAR(254) ,
 DATA_TYPE VARCHAR(254) ,
 DATA BLOB(1073741823) ,
 WSID_1 CHAR(16) FOR BIT DATA ,
 WSID_1_HC INTEGER ,
 WSID_2 CHAR(16) FOR BIT DATA ,
 WSID_2_HC INTEGER ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (PIID, ATTR_KEY)
) IN @DB_NAME@.INSTA23;

CREATE UNIQUE INDEX 
  @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_P
  ON @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
(   
  PIID, 
  ATTR_KEY
) NOT PADDED
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column DATA
CREATE AUX TABLE @SCHEMA@.AT21344F
   IN @DB_NAME@.AS21344F
   STORES @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T COLUMN DATA;
-- auxiliary index for LOB column DATA
CREATE UNIQUE INDEX @SCHEMA@.AT21344FI
  ON @SCHEMA@.AT21344F
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.PIA_VALUE
  ON @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
(   
  VALUE
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.PIA_DATY
  ON @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
(   
  DATA_TYPE
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.PROCESS_CONTEXT_T
(
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 SHARED SMALLINT ,
 REPLY_CONTEXT BLOB(3900K) ,
 SERVICE_CONTEXT BLOB(3900K) ,
 STARTER_EXPIRES TIMESTAMP ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (PIID)
) IN @DB_NAME@.INSTA24;

CREATE UNIQUE INDEX 
  @SCHEMA@.PROCESS_CONTEXT_P
  ON @SCHEMA@.PROCESS_CONTEXT_T
(   
  PIID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column REPLY_CONTEXT
CREATE AUX TABLE @SCHEMA@.AT213450
   IN @DB_NAME@.AS213450
   STORES @SCHEMA@.PROCESS_CONTEXT_T COLUMN REPLY_CONTEXT;
-- auxiliary index for LOB column REPLY_CONTEXT
CREATE UNIQUE INDEX @SCHEMA@.AT213450I
  ON @SCHEMA@.AT213450
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column SERVICE_CONTEXT
CREATE AUX TABLE @SCHEMA@.AT213451
   IN @DB_NAME@.AS213451
   STORES @SCHEMA@.PROCESS_CONTEXT_T COLUMN SERVICE_CONTEXT;
-- auxiliary index for LOB column SERVICE_CONTEXT
CREATE UNIQUE INDEX @SCHEMA@.AT213451I
  ON @SCHEMA@.AT213451
   USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
(
 PKID CHAR(16) FOR BIT DATA NOT NULL ,
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 ATID CHAR(16) FOR BIT DATA NOT NULL ,
 EHIID CHAR(16) FOR BIT DATA ,
 FEIID CHAR(16) FOR BIT DATA ,
 AIID CHAR(16) FOR BIT DATA ,
 ATTR_KEY VARCHAR(189) NOT NULL ,
 ATTR_VALUE VARCHAR(254) ,
 DATA_TYPE VARCHAR(254) ,
 DATA BLOB(1073741823) ,
 WSID_1 CHAR(16) FOR BIT DATA ,
 WSID_1_HC INTEGER ,
 WSID_2 CHAR(16) FOR BIT DATA ,
 WSID_2_HC INTEGER ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (PKID)
) IN @DB_NAME@.INSTA45;

CREATE UNIQUE INDEX 
  @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_P
  ON @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
(   
  PKID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column DATA
CREATE AUX TABLE @SCHEMA@.AT213452
   IN @DB_NAME@.AS213452
   STORES @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T COLUMN DATA;
-- auxiliary index for LOB column DATA
CREATE UNIQUE INDEX @SCHEMA@.AT213452I
  ON @SCHEMA@.AT213452
   USING STOGROUP @STOGRP@;


CREATE UNIQUE INDEX 
  @SCHEMA@.AIA_UNIQUE
  ON @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
(   
  PIID, 
  ATID, 
  EHIID, 
  FEIID, 
  ATTR_KEY
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.AIA_FEEIATPI
  ON @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
(   
  FEIID, 
  EHIID, 
  ATID, 
  PIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.AIA_AIID
  ON @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
(   
  AIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.AIA_VALUE
  ON @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
(   
  ATTR_VALUE
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.AIA_DATY
  ON @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
(   
  DATA_TYPE
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.NAVIGATION_EXCEPTION_T
(
 CORRELATION_ID VARCHAR(220) FOR BIT DATA NOT NULL ,
 EXCEPTION_TYPE INTEGER NOT NULL ,
 PIID CHAR(16) FOR BIT DATA ,
 OUTPUT_MESSAGE BLOB(1073741823) ,
 TYPE_SYSTEM VARCHAR(32) ,
 PROCESS_EXCEPTION BLOB(3900K) NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (CORRELATION_ID, EXCEPTION_TYPE)
) IN @DB_NAME@.INSTA26;

CREATE UNIQUE INDEX 
  @SCHEMA@.NAVIGATION_EXCEPTION_P
  ON @SCHEMA@.NAVIGATION_EXCEPTION_T
(   
  CORRELATION_ID, 
  EXCEPTION_TYPE
) NOT PADDED
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column OUTPUT_MESSAGE
CREATE AUX TABLE @SCHEMA@.AT213453
   IN @DB_NAME@.AS213453
   STORES @SCHEMA@.NAVIGATION_EXCEPTION_T COLUMN OUTPUT_MESSAGE;
-- auxiliary index for LOB column OUTPUT_MESSAGE
CREATE UNIQUE INDEX @SCHEMA@.AT213453I
  ON @SCHEMA@.AT213453
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column PROCESS_EXCEPTION
CREATE AUX TABLE @SCHEMA@.AT213454
   IN @DB_NAME@.AS213454
   STORES @SCHEMA@.NAVIGATION_EXCEPTION_T COLUMN PROCESS_EXCEPTION;
-- auxiliary index for LOB column PROCESS_EXCEPTION
CREATE UNIQUE INDEX @SCHEMA@.AT213454I
  ON @SCHEMA@.AT213454
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.NE_PIID
  ON @SCHEMA@.NAVIGATION_EXCEPTION_T
(   
  PIID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.AWAITED_INVOCATION_T
(
 CORRELATION_ID VARCHAR(254) FOR BIT DATA NOT NULL ,
 CORRELATION_INFO BLOB(3900K) NOT NULL ,
 AIID CHAR(16) FOR BIT DATA NOT NULL ,
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (CORRELATION_ID)
) IN @DB_NAME@.INSTA27;

CREATE UNIQUE INDEX 
  @SCHEMA@.AWAITED_INVOCATION_P
  ON @SCHEMA@.AWAITED_INVOCATION_T
(   
  CORRELATION_ID
) NOT PADDED
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column CORRELATION_INFO
CREATE AUX TABLE @SCHEMA@.AT213455
   IN @DB_NAME@.AS213455
   STORES @SCHEMA@.AWAITED_INVOCATION_T COLUMN CORRELATION_INFO;
-- auxiliary index for LOB column CORRELATION_INFO
CREATE UNIQUE INDEX @SCHEMA@.AT213455I
  ON @SCHEMA@.AT213455
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.AWI_PIID
  ON @SCHEMA@.AWAITED_INVOCATION_T
(   
  PIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.AWI_AIID
  ON @SCHEMA@.AWAITED_INVOCATION_T
(   
  AIID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.STORED_QUERY_T
(
 SQID CHAR(16) FOR BIT DATA NOT NULL ,
 KIND INTEGER NOT NULL ,
 NAME VARCHAR(64) NOT NULL ,
 OWNER_ID VARCHAR(128) NOT NULL ,
 SELECT_CLAUSE CLOB(20K) NOT NULL ,
 WHERE_CLAUSE CLOB(20K) ,
 ORDER_CLAUSE VARCHAR(254) ,
 THRESHOLD INTEGER ,
 TIMEZONE VARCHAR(63) ,
 CREATOR VARCHAR(128) ,
 TYPE VARCHAR(128) ,
 PROPERTY BLOB(3900K) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (SQID)
) IN @DB_NAME@.INSTA46;

CREATE UNIQUE INDEX 
  @SCHEMA@.STORED_QUERY_P
  ON @SCHEMA@.STORED_QUERY_T
(   
  SQID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column SELECT_CLAUSE
CREATE AUX TABLE @SCHEMA@.AT213456
   IN @DB_NAME@.AS213456
   STORES @SCHEMA@.STORED_QUERY_T COLUMN SELECT_CLAUSE;
-- auxiliary index for LOB column SELECT_CLAUSE
CREATE UNIQUE INDEX @SCHEMA@.AT213456I
  ON @SCHEMA@.AT213456
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column WHERE_CLAUSE
CREATE AUX TABLE @SCHEMA@.AT213457
   IN @DB_NAME@.AS213457
   STORES @SCHEMA@.STORED_QUERY_T COLUMN WHERE_CLAUSE;
-- auxiliary index for LOB column WHERE_CLAUSE
CREATE UNIQUE INDEX @SCHEMA@.AT213457I
  ON @SCHEMA@.AT213457
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column PROPERTY
CREATE AUX TABLE @SCHEMA@.AT213458
   IN @DB_NAME@.AS213458
   STORES @SCHEMA@.STORED_QUERY_T COLUMN PROPERTY;
-- auxiliary index for LOB column PROPERTY
CREATE UNIQUE INDEX @SCHEMA@.AT213458I
  ON @SCHEMA@.AT213458
   USING STOGROUP @STOGRP@;


CREATE UNIQUE INDEX 
  @SCHEMA@.SQ_NAME
  ON @SCHEMA@.STORED_QUERY_T
(   
  KIND, 
  OWNER_ID, 
  NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.FOR_EACH_INSTANCE_B_T
(
 FEIID CHAR(16) FOR BIT DATA NOT NULL ,
 PARENT_FEIID CHAR(16) FOR BIT DATA ,
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (FEIID)
) IN @DB_NAME@.INSTA48;

CREATE UNIQUE INDEX 
  @SCHEMA@.FOR_EACH_INSTANCE_B_P
  ON @SCHEMA@.FOR_EACH_INSTANCE_B_T
(   
  FEIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.FEI_PIID
  ON @SCHEMA@.FOR_EACH_INSTANCE_B_T
(   
  PIID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(
 PKID CHAR(16) FOR BIT DATA NOT NULL ,
 CTID CHAR(16) FOR BIT DATA NOT NULL ,
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 PAID CHAR(16) FOR BIT DATA NOT NULL ,
 WSID_1 CHAR(16) FOR BIT DATA ,
 WSID_1_HC INTEGER ,
 WSID_2 CHAR(16) FOR BIT DATA ,
 WSID_2_HC INTEGER ,
 VARIABLE_NAME VARCHAR(254) NOT NULL ,
 PROPERTY_NAME VARCHAR(255) NOT NULL ,
 PROPERTY_NAMESPACE VARCHAR(254) NOT NULL ,
 TYPE INTEGER NOT NULL ,
 GENERIC_VALUE VARCHAR(512) ,
 STRING_VALUE VARCHAR(512) ,
 NUMBER_VALUE NUMERIC(20) ,
 DECIMAL_VALUE DOUBLE ,
 TIMESTAMP_VALUE TIMESTAMP ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (PKID)
) IN @DB_NAME@.INSTA51;

CREATE UNIQUE INDEX 
  @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_P
  ON @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(   
  PKID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.QVI_PI_CT_PA
  ON @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(   
  PIID, 
  CTID, 
  PAID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.QVI_PI_PROPNAME
  ON @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(   
  PIID, 
  PROPERTY_NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.SYNC_T
(
 IDENTIFIER VARCHAR(254) NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (IDENTIFIER)
) IN @DB_NAME@.INSTA54;

CREATE UNIQUE INDEX 
  @SCHEMA@.SYNC_P
  ON @SCHEMA@.SYNC_T
(   
  IDENTIFIER
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.MV_CTR_T
(
 ID INTEGER NOT NULL ,
 SELECT_CLAUSE VARCHAR(1024) NOT NULL ,
 WHERE_CLAUSE VARCHAR(1024) ,
 ORDER_CLAUSE VARCHAR(512) ,
 TBL_SPACE VARCHAR(32) NOT NULL ,
 UPDATED TIMESTAMP NOT NULL ,
 UPD_STARTED TIMESTAMP ,
 AVG_UPD_TIME NUMERIC(20) ,
 UPD_INTERVAL NUMERIC(20) NOT NULL ,
 IS_UPDATING SMALLINT NOT NULL ,
 ACTIVE_MV SMALLINT NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (ID)
) IN @DB_NAME@.INSTA55;

CREATE UNIQUE INDEX 
  @SCHEMA@.MV_CTR_P
  ON @SCHEMA@.MV_CTR_T
(   
  ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.SAVED_ENGINE_MESSAGE_B_T
(
 PKID CHAR(16) FOR BIT DATA NOT NULL ,
 PIID CHAR(16) FOR BIT DATA ,
 CREATION_TIME TIMESTAMP NOT NULL ,
 REASON INTEGER NOT NULL ,
 ENGINE_MESSAGE_S VARCHAR(2000) FOR BIT DATA ,
 ENGINE_MESSAGE_L BLOB(1073741823) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (PKID)
) IN @DB_NAME@.INSTA56;

ALTER TABLE @SCHEMA@.SAVED_ENGINE_MESSAGE_B_T VOLATILE;

CREATE UNIQUE INDEX 
  @SCHEMA@.SAVED_ENGINE_MESSAGE_B_P
  ON @SCHEMA@.SAVED_ENGINE_MESSAGE_B_T
(   
  PKID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column ENGINE_MESSAGE_L
CREATE AUX TABLE @SCHEMA@.AT213459
   IN @DB_NAME@.AS213459
   STORES @SCHEMA@.SAVED_ENGINE_MESSAGE_B_T COLUMN ENGINE_MESSAGE_L;
-- auxiliary index for LOB column ENGINE_MESSAGE_L
CREATE UNIQUE INDEX @SCHEMA@.AT213459I
  ON @SCHEMA@.AT213459
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.SEM_PIID
  ON @SCHEMA@.SAVED_ENGINE_MESSAGE_B_T
(   
  PIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.SEM_REAS
  ON @SCHEMA@.SAVED_ENGINE_MESSAGE_B_T
(   
  REASON, 
  CREATION_TIME
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.NAVIGATION_CLEANUP_TIMER_B_T
(
 PKID CHAR(16) FOR BIT DATA NOT NULL ,
 SCHEDULED_TIME TIMESTAMP NOT NULL ,
 SCHEDULER_ID VARCHAR(254) NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (PKID)
) IN @DB_NAME@.INSTA57;

CREATE UNIQUE INDEX 
  @SCHEMA@.NAVIGATION_CLEANUP_TIMER_B_P
  ON @SCHEMA@.NAVIGATION_CLEANUP_TIMER_B_T
(   
  PKID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.SCHEDULER_ACTION_T
(
 SCHEDULER_ID VARCHAR(254) NOT NULL ,
 OID CHAR(16) FOR BIT DATA NOT NULL ,
 ACTION_OBJECT BLOB(3900k) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (SCHEDULER_ID)
) IN @DB_NAME@.INSTA58;

CREATE UNIQUE INDEX 
  @SCHEMA@.SCHEDULER_ACTION_P
  ON @SCHEMA@.SCHEDULER_ACTION_T
(   
  SCHEDULER_ID
) NOT PADDED
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column ACTION_OBJECT
CREATE AUX TABLE @SCHEMA@.AT21345A
   IN @DB_NAME@.AS21345A
   STORES @SCHEMA@.SCHEDULER_ACTION_T COLUMN ACTION_OBJECT;
-- auxiliary index for LOB column ACTION_OBJECT
CREATE UNIQUE INDEX @SCHEMA@.AT21345AI
  ON @SCHEMA@.AT21345A
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.SCEACT_OID
  ON @SCHEMA@.SCHEDULER_ACTION_T
(   
  OID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.QUERY_TABLE_T
(
 NAME VARCHAR(32) NOT NULL ,
 KIND INTEGER NOT NULL ,
 TYPE INTEGER NOT NULL ,
 VERSION INTEGER NOT NULL ,
 LAST_UPDATED TIMESTAMP NOT NULL ,
 PRIMARY_VIEW VARCHAR(32) ,
 DEFINITION BLOB(1073741823) NOT NULL ,
 VV_CFG BLOB(1073741823) ,
 DV_CFG BLOB(1073741823) ,
 MV_CFG BLOB(1073741823) ,
 MT_CFG BLOB(1073741823) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (NAME)
) IN @DB_NAME@.INSTA64;

CREATE UNIQUE INDEX 
  @SCHEMA@.QUERY_TABLE_P
  ON @SCHEMA@.QUERY_TABLE_T
(   
  NAME
) NOT PADDED
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column DEFINITION
CREATE AUX TABLE @SCHEMA@.AT21345B
   IN @DB_NAME@.AS21345B
   STORES @SCHEMA@.QUERY_TABLE_T COLUMN DEFINITION;
-- auxiliary index for LOB column DEFINITION
CREATE UNIQUE INDEX @SCHEMA@.AT21345BI
  ON @SCHEMA@.AT21345B
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column VV_CFG
CREATE AUX TABLE @SCHEMA@.AT21345C
   IN @DB_NAME@.AS21345C
   STORES @SCHEMA@.QUERY_TABLE_T COLUMN VV_CFG;
-- auxiliary index for LOB column VV_CFG
CREATE UNIQUE INDEX @SCHEMA@.AT21345CI
  ON @SCHEMA@.AT21345C
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column DV_CFG
CREATE AUX TABLE @SCHEMA@.AT21345D
   IN @DB_NAME@.AS21345D
   STORES @SCHEMA@.QUERY_TABLE_T COLUMN DV_CFG;
-- auxiliary index for LOB column DV_CFG
CREATE UNIQUE INDEX @SCHEMA@.AT21345DI
  ON @SCHEMA@.AT21345D
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column MV_CFG
CREATE AUX TABLE @SCHEMA@.AT21345E
   IN @DB_NAME@.AS21345E
   STORES @SCHEMA@.QUERY_TABLE_T COLUMN MV_CFG;
-- auxiliary index for LOB column MV_CFG
CREATE UNIQUE INDEX @SCHEMA@.AT21345EI
  ON @SCHEMA@.AT21345E
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column MT_CFG
CREATE AUX TABLE @SCHEMA@.AT21345F
   IN @DB_NAME@.AS21345F
   STORES @SCHEMA@.QUERY_TABLE_T COLUMN MT_CFG;
-- auxiliary index for LOB column MT_CFG
CREATE UNIQUE INDEX @SCHEMA@.AT21345FI
  ON @SCHEMA@.AT21345F
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.QT_KI
  ON @SCHEMA@.QUERY_TABLE_T
(   
  KIND
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.QT_TY
  ON @SCHEMA@.QUERY_TABLE_T
(   
  TYPE
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.QUERY_TABLE_REF_T
(
 REFEREE VARCHAR(32) NOT NULL ,
 SOURCE VARCHAR(32) NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (REFEREE, SOURCE)
) IN @DB_NAME@.INSTA65;

CREATE UNIQUE INDEX 
  @SCHEMA@.QUERY_TABLE_REF_P
  ON @SCHEMA@.QUERY_TABLE_REF_T
(   
  REFEREE, 
  SOURCE
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.QTR_SRC
  ON @SCHEMA@.QUERY_TABLE_REF_T
(   
  SOURCE
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.MIGRATION_FRONT_T
(
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 MPTID CHAR(16) FOR BIT DATA NOT NULL ,
 AIID CHAR(16) FOR BIT DATA NOT NULL ,
 STATE INTEGER NOT NULL ,
 SUB_STATE INTEGER NOT NULL ,
 STOP_REASON INTEGER NOT NULL ,
 SOURCE_ATID CHAR(16) FOR BIT DATA NOT NULL ,
 TARGET_ATID CHAR(16) FOR BIT DATA NOT NULL ,
 MIGRATION_TIME TIMESTAMP NOT NULL ,
 WSID_1 CHAR(16) FOR BIT DATA ,
 WSID_1_HC INTEGER ,
 WSID_2 CHAR(16) FOR BIT DATA ,
 WSID_2_HC INTEGER ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (PIID, MPTID, AIID)
) IN @DB_NAME@.INSTA66;

CREATE UNIQUE INDEX 
  @SCHEMA@.MIGRATION_FRONT_P
  ON @SCHEMA@.MIGRATION_FRONT_T
(   
  PIID, 
  MPTID, 
  AIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.MGF_MPTID
  ON @SCHEMA@.MIGRATION_FRONT_T
(   
  MPTID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.SCOPE_COMPLETION_COUNTER_T
(
 SIID CHAR(16) FOR BIT DATA NOT NULL ,
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 COUNTER NUMERIC(20) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (SIID)
) IN @DB_NAME@.INSTA69;

CREATE UNIQUE INDEX 
  @SCHEMA@.SCOPE_COMPLETION_COUNTER_P
  ON @SCHEMA@.SCOPE_COMPLETION_COUNTER_T
(   
  SIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.SCC_PIID
  ON @SCHEMA@.SCOPE_COMPLETION_COUNTER_T
(   
  PIID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ITERATION_COUNTER_INSTANCE_T
(
 ICIID CHAR(16) FOR BIT DATA NOT NULL ,
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 STARTED_WITH_AIID CHAR(16) FOR BIT DATA ,
 PARENT_ICIID CHAR(16) FOR BIT DATA NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (ICIID)
) IN @DB_NAME@.INSTA80;

CREATE UNIQUE INDEX 
  @SCHEMA@.ITERATION_COUNTER_INSTANCE_P
  ON @SCHEMA@.ITERATION_COUNTER_INSTANCE_T
(   
  ICIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.ICI_PIID
  ON @SCHEMA@.ITERATION_COUNTER_INSTANCE_T
(   
  PIID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.IORCOUNTER_T
(
 GATEWAY_AIID CHAR(16) FOR BIT DATA NOT NULL ,
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 COUNTER CLOB(3900) NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (GATEWAY_AIID)
) IN @DB_NAME@.INSTA81;

CREATE UNIQUE INDEX 
  @SCHEMA@.IORCOUNTER_P
  ON @SCHEMA@.IORCOUNTER_T
(   
  GATEWAY_AIID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column COUNTER
CREATE AUX TABLE @SCHEMA@.AT213460
   IN @DB_NAME@.AS213460
   STORES @SCHEMA@.IORCOUNTER_T COLUMN COUNTER;
-- auxiliary index for LOB column COUNTER
CREATE UNIQUE INDEX @SCHEMA@.AT213460I
  ON @SCHEMA@.AT213460
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.IOC_PIID
  ON @SCHEMA@.IORCOUNTER_T
(   
  PIID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.AUDIT_LOG_T
(
 ALID CHAR(16) FOR BIT DATA NOT NULL ,
 EVENT_TIME TIMESTAMP NOT NULL ,
 EVENT_TIME_UTC TIMESTAMP ,
 AUDIT_EVENT INTEGER NOT NULL ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 PIID CHAR(16) FOR BIT DATA ,
 AIID CHAR(16) FOR BIT DATA ,
 SIID CHAR(16) FOR BIT DATA ,
 VARIABLE_NAME VARCHAR(254) ,
 PROCESS_TEMPL_NAME VARCHAR(254) NOT NULL ,
 PROCESS_INST_NAME VARCHAR(254) ,
 TOP_LEVEL_PI_NAME VARCHAR(254) ,
 TOP_LEVEL_PIID CHAR(16) FOR BIT DATA ,
 PARENT_PI_NAME VARCHAR(254) ,
 PARENT_PIID CHAR(16) FOR BIT DATA ,
 VALID_FROM TIMESTAMP ,
 VALID_FROM_UTC TIMESTAMP ,
 ATID CHAR(16) FOR BIT DATA ,
 ACTIVITY_NAME VARCHAR(254) ,
 ACTIVITY_KIND INTEGER ,
 ACTIVITY_STATE INTEGER ,
 CONTROL_LINK_NAME VARCHAR(254) ,
 IMPL_NAME VARCHAR(254) ,
 PRINCIPAL VARCHAR(128) ,
 TERMINAL_NAME VARCHAR(254) ,
 VARIABLE_DATA BLOB(1073741823) ,
 EXCEPTION_TEXT CLOB(4096) ,
 DESCRIPTION VARCHAR(254) ,
 CORR_SET_INFO CLOB(4096) ,
 USER_NAME VARCHAR(128) ,
 ADDITIONAL_INFO CLOB(4096) ,
 OBJECT_META_TYPE INTEGER ,
 SNAPSHOT_ID VARCHAR(254) ,
 PROCESS_APP_ACRONYM VARCHAR(7) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (ALID)
) IN @DB_NAME@.AUDIT01;

CREATE UNIQUE INDEX 
  @SCHEMA@.AUDIT_LOG_P
  ON @SCHEMA@.AUDIT_LOG_T
(   
  ALID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column VARIABLE_DATA
CREATE AUX TABLE @SCHEMA@.AT213461
   IN @DB_NAME@.AS213461
   STORES @SCHEMA@.AUDIT_LOG_T COLUMN VARIABLE_DATA;
-- auxiliary index for LOB column VARIABLE_DATA
CREATE UNIQUE INDEX @SCHEMA@.AT213461I
  ON @SCHEMA@.AT213461
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column EXCEPTION_TEXT
CREATE AUX TABLE @SCHEMA@.AT213462
   IN @DB_NAME@.AS213462
   STORES @SCHEMA@.AUDIT_LOG_T COLUMN EXCEPTION_TEXT;
-- auxiliary index for LOB column EXCEPTION_TEXT
CREATE UNIQUE INDEX @SCHEMA@.AT213462I
  ON @SCHEMA@.AT213462
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column CORR_SET_INFO
CREATE AUX TABLE @SCHEMA@.AT213463
   IN @DB_NAME@.AS213463
   STORES @SCHEMA@.AUDIT_LOG_T COLUMN CORR_SET_INFO;
-- auxiliary index for LOB column CORR_SET_INFO
CREATE UNIQUE INDEX @SCHEMA@.AT213463I
  ON @SCHEMA@.AT213463
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column ADDITIONAL_INFO
CREATE AUX TABLE @SCHEMA@.AT213464
   IN @DB_NAME@.AS213464
   STORES @SCHEMA@.AUDIT_LOG_T COLUMN ADDITIONAL_INFO;
-- auxiliary index for LOB column ADDITIONAL_INFO
CREATE UNIQUE INDEX @SCHEMA@.AT213464I
  ON @SCHEMA@.AT213464
   USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.WORK_ITEM_T
(
 WIID CHAR(16) FOR BIT DATA NOT NULL ,
 PARENT_WIID CHAR(16) FOR BIT DATA ,
 OWNER_ID VARCHAR(128) ,
 GROUP_NAME VARCHAR(128) ,
 EVERYBODY SMALLINT NOT NULL ,
 EXCLUDE SMALLINT NOT NULL ,
 QIID CHAR(16) FOR BIT DATA ,
 OBJECT_TYPE INTEGER NOT NULL ,
 OBJECT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 ASSOCIATED_OBJECT_TYPE INTEGER NOT NULL ,
 ASSOCIATED_OID CHAR(16) FOR BIT DATA ,
 REASON INTEGER NOT NULL ,
 CREATION_TIME TIMESTAMP NOT NULL ,
 KIND INTEGER NOT NULL ,
 AUTH_INFO INTEGER NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (WIID)
) IN @DB_NAME@.WORKI01;

CREATE UNIQUE INDEX 
  @SCHEMA@.WORK_ITEM_P
  ON @SCHEMA@.WORK_ITEM_T
(   
  WIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WI_ASSOBJ_REASON
  ON @SCHEMA@.WORK_ITEM_T
(   
  ASSOCIATED_OID, 
  ASSOCIATED_OBJECT_TYPE, 
  REASON, 
  PARENT_WIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WI_OBJID_TYPE_QIID
  ON @SCHEMA@.WORK_ITEM_T
(   
  OBJECT_ID, 
  OBJECT_TYPE, 
  QIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WI_GROUP_NAME
  ON @SCHEMA@.WORK_ITEM_T
(   
  GROUP_NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WI_AUTH_L
  ON @SCHEMA@.WORK_ITEM_T
(   
  EVERYBODY, 
  GROUP_NAME, 
  OWNER_ID, 
  QIID
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WI_AUTH_U
  ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, 
  QIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WI_AUTH_O
  ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, 
  OWNER_ID DESC
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WI_AUTH_G
  ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, 
  GROUP_NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WI_AUTH_E
  ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, 
  EVERYBODY
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WI_AUTH_R
  ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, 
  REASON DESC
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WI_REASON
  ON @SCHEMA@.WORK_ITEM_T
(   
  REASON
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WI_OWNER
  ON @SCHEMA@.WORK_ITEM_T
(   
  OWNER_ID, 
  OBJECT_ID, 
  REASON, 
  OBJECT_TYPE
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WI_QIID
  ON @SCHEMA@.WORK_ITEM_T
(   
  QIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WI_QRY
  ON @SCHEMA@.WORK_ITEM_T
(   
  OBJECT_ID, 
  REASON, 
  EVERYBODY, 
  OWNER_ID
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WI_QI_OID_RS_OWN
  ON @SCHEMA@.WORK_ITEM_T
(   
  QIID, 
  OBJECT_ID, 
  REASON, 
  OWNER_ID
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WI_QI_OID_OWN
  ON @SCHEMA@.WORK_ITEM_T
(   
  QIID, 
  OBJECT_ID, 
  OWNER_ID
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WI_OT_OID_RS
  ON @SCHEMA@.WORK_ITEM_T
(   
  OBJECT_TYPE, 
  OBJECT_ID, 
  REASON
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WI_WI_QI
  ON @SCHEMA@.WORK_ITEM_T
(   
  WIID, 
  QIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WI_PWIID_OID
  ON @SCHEMA@.WORK_ITEM_T
(   
  PARENT_WIID, 
  OBJECT_ID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WI_PWIID_QIID
  ON @SCHEMA@.WORK_ITEM_T
(   
  PARENT_WIID, 
  QIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WI_AUTH_GR_O_E
  ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, 
  GROUP_NAME, 
  OWNER_ID, 
  EVERYBODY
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WI_PD1
  ON @SCHEMA@.WORK_ITEM_T
(   
  OWNER_ID, 
  AUTH_INFO, 
  OBJECT_TYPE, 
  REASON, 
  OBJECT_ID
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WI_PD2
  ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, 
  OBJECT_TYPE, 
  REASON, 
  OBJECT_ID, 
  QIID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.RETRIEVED_USER_T
(
 QIID CHAR(16) FOR BIT DATA NOT NULL ,
 OWNER_ID VARCHAR(128) NOT NULL ,
 REASON INTEGER NOT NULL ,
 ASSOCIATED_OID CHAR(16) FOR BIT DATA ,
 KIND INTEGER NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (QIID, OWNER_ID)
) IN @DB_NAME@.WORKI03;

CREATE UNIQUE INDEX 
  @SCHEMA@.RETRIEVED_USER_P
  ON @SCHEMA@.RETRIEVED_USER_T
(   
  QIID, 
  OWNER_ID
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.RUT_OWN_QIID
  ON @SCHEMA@.RETRIEVED_USER_T
(   
  OWNER_ID, 
  QIID
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.RUT_ASSOC
  ON @SCHEMA@.RETRIEVED_USER_T
(   
  ASSOCIATED_OID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.RUT_QIID
  ON @SCHEMA@.RETRIEVED_USER_T
(   
  QIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.RUT_OWN_QIDESC
  ON @SCHEMA@.RETRIEVED_USER_T
(   
  OWNER_ID, 
  QIID DESC
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.RETRIEVED_GROUP_T
(
 QIID CHAR(16) FOR BIT DATA NOT NULL ,
 GROUP_NAME VARCHAR(128) NOT NULL ,
 KIND INTEGER NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (QIID, GROUP_NAME)
) IN @DB_NAME@.WORKI04;

CREATE UNIQUE INDEX 
  @SCHEMA@.RETRIEVED_GROUP_P
  ON @SCHEMA@.RETRIEVED_GROUP_T
(   
  QIID, 
  GROUP_NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.RGR_GN
  ON @SCHEMA@.RETRIEVED_GROUP_T
(   
  GROUP_NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.WIS_META_DATA_T
(
 WSID CHAR(16) FOR BIT DATA NOT NULL ,
 HASH_CODE INTEGER NOT NULL ,
 OBJECT_TYPE INTEGER NOT NULL ,
 LAST_CHECK TIMESTAMP NOT NULL ,
 UNUSED SMALLINT NOT NULL ,
 AUTH_INFO_RETRIEVED_USER SMALLINT NOT NULL ,
 AUTH_INFO_OWNER_ID SMALLINT NOT NULL ,
 AUTH_INFO_EVERYBODY SMALLINT NOT NULL ,
 AUTH_INFO_GROUP SMALLINT NOT NULL ,
 AUTH_INFO_RETRIEVED_GROUP SMALLINT NOT NULL ,
 AUTH_INFO_EMPTY SMALLINT NOT NULL ,
 SHARING_PATTERN INTEGER NOT NULL ,
 REASONS CHAR(32) FOR BIT DATA NOT NULL ,
 PARAMETER_A INTEGER ,
 PARAMETER_B INTEGER ,
 PARAMETER_C INTEGER ,
 PARAMETER_D CHAR(16) FOR BIT DATA ,
 PARAMETER_E TIMESTAMP ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (WSID)
) IN @DB_NAME@.WORKI05;

CREATE UNIQUE INDEX 
  @SCHEMA@.WIS_META_DATA_P
  ON @SCHEMA@.WIS_META_DATA_T
(   
  WSID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WMD_HC
  ON @SCHEMA@.WIS_META_DATA_T
(   
  HASH_CODE
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.E_SWI_T
(
 PKID CHAR(16) FOR BIT DATA NOT NULL ,
 WIID CHAR(16) FOR BIT DATA NOT NULL ,
 WSID CHAR(16) FOR BIT DATA NOT NULL ,
 HASH_CODE INTEGER NOT NULL ,
 WIS_HASH_CODE INTEGER ,
 PARENT_WIID CHAR(16) FOR BIT DATA ,
 REASON INTEGER NOT NULL ,
 INHERITED SMALLINT ,
 QIID CHAR(16) FOR BIT DATA ,
 OBJECT_TYPE INTEGER NOT NULL ,
 KIND INTEGER NOT NULL ,
 SHARING_PATTERN INTEGER NOT NULL ,
 ACCESS_KEY INTEGER NOT NULL ,
 TEMPLATE_ID CHAR(16) FOR BIT DATA ,
 PARAMETER_A INTEGER ,
 PARAMETER_B INTEGER ,
 PARAMETER_C INTEGER ,
 PARAMETER_D CHAR(16) FOR BIT DATA ,
 PARAMETER_E TIMESTAMP ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (PKID)
) IN @DB_NAME@.WORKI06;

CREATE UNIQUE INDEX 
  @SCHEMA@.E_SWI_P
  ON @SCHEMA@.E_SWI_T
(   
  PKID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WE_WSID
  ON @SCHEMA@.E_SWI_T
(   
  WSID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WE_HASHCODE
  ON @SCHEMA@.E_SWI_T
(   
  HASH_CODE
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WE_WIID
  ON @SCHEMA@.E_SWI_T
(   
  WIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WE_QIID
  ON @SCHEMA@.E_SWI_T
(   
  QIID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.SWI_T
(
 PKID CHAR(16) FOR BIT DATA NOT NULL ,
 WIID CHAR(16) FOR BIT DATA NOT NULL ,
 PARENT_WIID CHAR(16) FOR BIT DATA ,
 OWNER_ID VARCHAR(128) ,
 GROUP_NAME VARCHAR(128) ,
 EVERYBODY SMALLINT NOT NULL ,
 QIID CHAR(16) FOR BIT DATA ,
 OBJECT_TYPE INTEGER NOT NULL ,
 REASON INTEGER NOT NULL ,
 KIND INTEGER NOT NULL ,
 AUTH_INFO INTEGER NOT NULL ,
 SHARING_PATTERN INTEGER NOT NULL ,
 ACCESS_KEY INTEGER NOT NULL ,
 WSID CHAR(16) FOR BIT DATA NOT NULL ,
 HASH_CODE INTEGER NOT NULL ,
 WIS_HASH_CODE INTEGER ,
 INHERITED SMALLINT ,
 TEMPLATE_ID CHAR(16) FOR BIT DATA ,
 PARAMETER_A INTEGER ,
 PARAMETER_B INTEGER ,
 PARAMETER_C INTEGER ,
 PARAMETER_D CHAR(16) FOR BIT DATA ,
 PARAMETER_E TIMESTAMP ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (PKID)
) IN @DB_NAME@.WORKI07;

CREATE UNIQUE INDEX 
  @SCHEMA@.SWI_P
  ON @SCHEMA@.SWI_T
(   
  PKID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.SWI_WSID
  ON @SCHEMA@.SWI_T
(   
  WSID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.SWI_HASHCODE
  ON @SCHEMA@.SWI_T
(   
  HASH_CODE
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.SWI_OTRPD
  ON @SCHEMA@.SWI_T
(   
  OBJECT_TYPE, 
  REASON, 
  TEMPLATE_ID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.SWI_WIID
  ON @SCHEMA@.SWI_T
(   
  WIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.SWI_QIID
  ON @SCHEMA@.SWI_T
(   
  QIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.SWI_OWN
  ON @SCHEMA@.SWI_T
(   
  OWNER_ID, 
  ACCESS_KEY, 
  WSID, 
  REASON
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.SWI_GRP
  ON @SCHEMA@.SWI_T
(   
  GROUP_NAME, 
  ACCESS_KEY, 
  WSID, 
  REASON
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.SWI_ACCK1
  ON @SCHEMA@.SWI_T
(   
  ACCESS_KEY, 
  REASON, 
  WSID, 
  QIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.SWI_ACCK2
  ON @SCHEMA@.SWI_T
(   
  ACCESS_KEY, 
  REASON, 
  QIID, 
  WSID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.SWI_ACCK3
  ON @SCHEMA@.SWI_T
(   
  ACCESS_KEY, 
  REASON, 
  OWNER_ID, 
  WSID
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.SWI_ACCK4
  ON @SCHEMA@.SWI_T
(   
  ACCESS_KEY, 
  REASON, 
  WSID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.SWI_ACCK5
  ON @SCHEMA@.SWI_T
(   
  ACCESS_KEY, 
  OWNER_ID, 
  REASON, 
  WSID
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.SWI_ACCK6
  ON @SCHEMA@.SWI_T
(   
  ACCESS_KEY, 
  GROUP_NAME, 
  REASON, 
  WSID
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.STAFF_QUERY_INSTANCE_T
(
 QIID CHAR(16) FOR BIT DATA NOT NULL ,
 QTID CHAR(16) FOR BIT DATA NOT NULL ,
 EVERYBODY SMALLINT NOT NULL ,
 NOBODY SMALLINT NOT NULL ,
 IS_SHAREABLE SMALLINT NOT NULL ,
 IS_TRANSFERRED SMALLINT NOT NULL ,
 SR_HASH_CODE INTEGER ,
 GROUP_NAME VARCHAR(128) ,
 CONTEXT_VALUES VARCHAR(3072) ,
 CONTEXT_VALUES_LONG CLOB(3096K) ,
 HASH_CODE INTEGER ,
 EXPIRES TIMESTAMP ,
 ASSOCIATED_OBJECT_TYPE INTEGER NOT NULL ,
 ASSOCIATED_OID CHAR(16) FOR BIT DATA NOT NULL ,
 NORMALIZED SMALLINT ,
 DENORMALIZED SMALLINT ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (QIID)
) IN @DB_NAME@.STAF801;

CREATE UNIQUE INDEX 
  @SCHEMA@.STAFF_QUERY_INSTANCE_P
  ON @SCHEMA@.STAFF_QUERY_INSTANCE_T
(   
  QIID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column CONTEXT_VALUES_LONG
CREATE AUX TABLE @SCHEMA@.AT213465
   IN @DB_NAME@.AS213465
   STORES @SCHEMA@.STAFF_QUERY_INSTANCE_T COLUMN CONTEXT_VALUES_LONG;
-- auxiliary index for LOB column CONTEXT_VALUES_LONG
CREATE UNIQUE INDEX @SCHEMA@.AT213465I
  ON @SCHEMA@.AT213465
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.SQI_QTID
  ON @SCHEMA@.STAFF_QUERY_INSTANCE_T
(   
  QTID, 
  HASH_CODE
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.SQI_ASSOCID
  ON @SCHEMA@.STAFF_QUERY_INSTANCE_T
(   
  ASSOCIATED_OID, 
  ASSOCIATED_OBJECT_TYPE
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.SQI_QIIDGN
  ON @SCHEMA@.STAFF_QUERY_INSTANCE_T
(   
  QIID, 
  GROUP_NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.SQI_QIIDTREX
  ON @SCHEMA@.STAFF_QUERY_INSTANCE_T
(   
  QIID, 
  IS_TRANSFERRED, 
  EXPIRES
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.SQI_ISSH
  ON @SCHEMA@.STAFF_QUERY_INSTANCE_T
(   
  IS_SHAREABLE, 
  QIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.SQI_GRP
  ON @SCHEMA@.STAFF_QUERY_INSTANCE_T
(   
  GROUP_NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.STAFF_LOCK_T
(
 QTID CHAR(16) FOR BIT DATA NOT NULL ,
 HASH_CODE INTEGER NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (QTID, HASH_CODE)
) IN @DB_NAME@.STAFF02;

CREATE UNIQUE INDEX 
  @SCHEMA@.STAFF_LOCK_P
  ON @SCHEMA@.STAFF_LOCK_T
(   
  QTID, 
  HASH_CODE
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.APPLICATION_COMPONENT_T
(
 ACOID CHAR(16) FOR BIT DATA NOT NULL ,
 NAME VARCHAR(64) NOT NULL ,
 CALENDAR_NAME VARCHAR(254) ,
 JNDI_NAME_CALENDAR VARCHAR(254) ,
 JNDI_NAME_STAFF_PROVIDER VARCHAR(254) NOT NULL ,
 DURATION_UNTIL_DELETED VARCHAR(254) ,
 EVENT_HANDLER_NAME VARCHAR(64) ,
 INSTANCE_CREATOR_QTID CHAR(16) FOR BIT DATA ,
 SUPPORTS_AUTO_CLAIM SMALLINT NOT NULL ,
 SUPPORTS_FOLLOW_ON_TASK SMALLINT NOT NULL ,
 SUPPORTS_CLAIM_SUSPENDED SMALLINT NOT NULL ,
 SUPPORTS_DELEGATION SMALLINT NOT NULL ,
 SUPPORTS_SUB_TASK SMALLINT NOT NULL ,
 BUSINESS_RELEVANCE SMALLINT NOT NULL ,
 SUBSTITUTION_POLICY INTEGER NOT NULL ,
  PRIMARY KEY (ACOID)
) IN @DB_NAME@.TEMPL31;

CREATE UNIQUE INDEX 
  @SCHEMA@.APPLICATION_COMPONENT_P
  ON @SCHEMA@.APPLICATION_COMPONENT_T
(   
  ACOID
)
USING STOGROUP @STOGRP@;

CREATE UNIQUE INDEX 
  @SCHEMA@.ACO_NAME
  ON @SCHEMA@.APPLICATION_COMPONENT_T
(   
  NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ESCALATION_TEMPLATE_T
(
 ESTID CHAR(16) FOR BIT DATA NOT NULL ,
 FIRST_ESTID CHAR(16) FOR BIT DATA ,
 PREVIOUS_ESTID CHAR(16) FOR BIT DATA ,
 TKTID CHAR(16) FOR BIT DATA NOT NULL ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 MNTID CHAR(16) FOR BIT DATA ,
 NAME VARCHAR(220) ,
 ACTIVATION_STATE INTEGER NOT NULL ,
 AT_LEAST_EXPECTED_STATE INTEGER NOT NULL ,
 DURATION_UNTIL_ESCALATION VARCHAR(254) ,
 DURATION_UNTIL_REPEATS VARCHAR(254) ,
 INCREASE_PRIORITY INTEGER NOT NULL ,
 ACTION INTEGER NOT NULL ,
 ESCALATION_RECEIVER_QTID CHAR(16) FOR BIT DATA ,
 RECEIVER_EMAIL_QTID CHAR(16) FOR BIT DATA ,
  PRIMARY KEY (ESTID)
) IN @DB_NAME@.TEMPL32;

CREATE UNIQUE INDEX 
  @SCHEMA@.ESCALATION_TEMPLATE_P
  ON @SCHEMA@.ESCALATION_TEMPLATE_T
(   
  ESTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.ET_TKTID
  ON @SCHEMA@.ESCALATION_TEMPLATE_T
(   
  TKTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.ET_CCID
  ON @SCHEMA@.ESCALATION_TEMPLATE_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ESC_TEMPL_CPROP_T
(
 ESTID CHAR(16) FOR BIT DATA NOT NULL ,
 NAME VARCHAR(220) NOT NULL ,
 TKTID CHAR(16) FOR BIT DATA NOT NULL ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 STRING_VALUE VARCHAR(254) ,
 DATA_TYPE VARCHAR(254) ,
 DATA BLOB(1073741823) ,
  PRIMARY KEY (ESTID, NAME)
) IN @DB_NAME@.TEMPL33;

CREATE UNIQUE INDEX 
  @SCHEMA@.ESC_TEMPL_CPROP_P
  ON @SCHEMA@.ESC_TEMPL_CPROP_T
(   
  ESTID, 
  NAME
) NOT PADDED
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column DATA
CREATE AUX TABLE @SCHEMA@.AT213466
   IN @DB_NAME@.AS213466
   STORES @SCHEMA@.ESC_TEMPL_CPROP_T COLUMN DATA;
-- auxiliary index for LOB column DATA
CREATE UNIQUE INDEX @SCHEMA@.AT213466I
  ON @SCHEMA@.AT213466
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.ETCP_TKTID
  ON @SCHEMA@.ESC_TEMPL_CPROP_T
(   
  TKTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.ETCP_CCID
  ON @SCHEMA@.ESC_TEMPL_CPROP_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ESC_TEMPL_LDESC_T
(
 ESTID CHAR(16) FOR BIT DATA NOT NULL ,
 LOCALE VARCHAR(32) NOT NULL ,
 TKTID CHAR(16) FOR BIT DATA NOT NULL ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 DISPLAY_NAME VARCHAR(64) ,
 DESCRIPTION VARCHAR(254) ,
 DOCUMENTATION CLOB(4096) ,
  PRIMARY KEY (ESTID, LOCALE)
) IN @DB_NAME@.TEMPL34;

CREATE UNIQUE INDEX 
  @SCHEMA@.ESC_TEMPL_LDESC_P
  ON @SCHEMA@.ESC_TEMPL_LDESC_T
(   
  ESTID, 
  LOCALE
) NOT PADDED
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column DOCUMENTATION
CREATE AUX TABLE @SCHEMA@.AT213467
   IN @DB_NAME@.AS213467
   STORES @SCHEMA@.ESC_TEMPL_LDESC_T COLUMN DOCUMENTATION;
-- auxiliary index for LOB column DOCUMENTATION
CREATE UNIQUE INDEX @SCHEMA@.AT213467I
  ON @SCHEMA@.AT213467
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.ETLD_TKTID
  ON @SCHEMA@.ESC_TEMPL_LDESC_T
(   
  TKTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.ETLD_CCID
  ON @SCHEMA@.ESC_TEMPL_LDESC_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.TTASK_MESSAGE_DEFINITION_T
(
 TMTID CHAR(16) FOR BIT DATA NOT NULL ,
 TKTID CHAR(16) FOR BIT DATA ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 KIND INTEGER NOT NULL ,
 FAULT_NAME VARCHAR(254) ,
 MESSAGE_TYPE_NS VARCHAR(220) NOT NULL ,
 MESSAGE_TYPE_NAME VARCHAR(220) NOT NULL ,
 MESSAGE_DEFINITION BLOB(3900K) ,
  PRIMARY KEY (TMTID)
) IN @DB_NAME@.TEMPL35;

CREATE UNIQUE INDEX 
  @SCHEMA@.TTASK_MESSAGE_DEFINITION_P
  ON @SCHEMA@.TTASK_MESSAGE_DEFINITION_T
(   
  TMTID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column MESSAGE_DEFINITION
CREATE AUX TABLE @SCHEMA@.AT213468
   IN @DB_NAME@.AS213468
 STORES @SCHEMA@.TTASK_MESSAGE_DEFINITION_T COLUMN
 MESSAGE_DEFINITION;
-- auxiliary index for LOB column MESSAGE_DEFINITION
CREATE UNIQUE INDEX @SCHEMA@.AT213468I
  ON @SCHEMA@.AT213468
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.TTMD_TKTID
  ON @SCHEMA@.TTASK_MESSAGE_DEFINITION_T
(   
  TKTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TTMD_CCID
  ON @SCHEMA@.TTASK_MESSAGE_DEFINITION_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.TASK_TEMPLATE_T
(
 TKTID CHAR(16) FOR BIT DATA NOT NULL ,
 NAME VARCHAR(220) NOT NULL ,
 DEFINITION_NAME VARCHAR(220) NOT NULL ,
 NAMESPACE VARCHAR(254) NOT NULL ,
 TARGET_NAMESPACE VARCHAR(254) NOT NULL ,
 VALID_FROM TIMESTAMP NOT NULL ,
 APPLICATION_NAME VARCHAR(220) ,
 APPLICATION_DEFAULTS_ID CHAR(16) FOR BIT DATA ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA ,
 SVTID CHAR(16) FOR BIT DATA ,
 KIND INTEGER NOT NULL ,
 STATE INTEGER NOT NULL ,
 AUTO_DELETE_MODE INTEGER NOT NULL ,
 IS_AD_HOC SMALLINT NOT NULL ,
 IS_INLINE SMALLINT NOT NULL ,
 IS_SHARED SMALLINT NOT NULL ,
 SUPPORTS_CLAIM_SUSPENDED SMALLINT NOT NULL ,
 SUPPORTS_AUTO_CLAIM SMALLINT NOT NULL ,
 SUPPORTS_FOLLOW_ON_TASK SMALLINT NOT NULL ,
 SUPPORTS_DELEGATION SMALLINT NOT NULL ,
 SUPPORTS_SUB_TASK SMALLINT NOT NULL ,
 CONTEXT_AUTHORIZATION INTEGER NOT NULL ,
 AUTONOMY INTEGER NOT NULL ,
 ADMIN_QTID CHAR(16) FOR BIT DATA ,
 EDITOR_QTID CHAR(16) FOR BIT DATA ,
 INSTANCE_CREATOR_QTID CHAR(16) FOR BIT DATA ,
 POTENTIAL_STARTER_QTID CHAR(16) FOR BIT DATA ,
 POTENTIAL_OWNER_QTID CHAR(16) FOR BIT DATA ,
 READER_QTID CHAR(16) FOR BIT DATA ,
 DEFAULT_LOCALE VARCHAR(32) ,
 CALENDAR_NAME VARCHAR(254) ,
 DURATION_UNTIL_DELETED VARCHAR(254) ,
 DURATION_UNTIL_DUE VARCHAR(254) ,
 DURATION_UNTIL_EXPIRES VARCHAR(254) ,
 JNDI_NAME_CALENDAR VARCHAR(254) ,
 JNDI_NAME_STAFF_PROVIDER VARCHAR(254) NOT NULL ,
 TYPE VARCHAR(254) ,
 EVENT_HANDLER_NAME VARCHAR(64) ,
 PRIORITY INTEGER ,
 PRIORITY_DEFINITION VARCHAR(254) ,
 BUSINESS_RELEVANCE SMALLINT NOT NULL ,
 SUBSTITUTION_POLICY INTEGER NOT NULL ,
 CONTACTS_QTIDS BLOB(3900k) ,
 UI_SETTINGS BLOB(3900k) ,
 ASSIGNMENT_TYPE INTEGER NOT NULL ,
 INHERITED_AUTH INTEGER NOT NULL ,
 PARALLEL_INHERITED_AUTH INTEGER NOT NULL ,
 NATIVE_LOOKUP_NAME VARCHAR(254) ,
 WORK_BASKET VARCHAR(254) ,
 EAR_VERSION INTEGER NOT NULL ,
 SCHEMA_VERSION INTEGER NOT NULL ,
 LANGUAGE_TYPE INTEGER NOT NULL ,
 DEPLOY_TYPE INTEGER NOT NULL ,
 CUSTOM_TEXT1 VARCHAR(64) ,
 CUSTOM_TEXT2 VARCHAR(64) ,
 CUSTOM_TEXT3 VARCHAR(64) ,
 CUSTOM_TEXT4 VARCHAR(64) ,
 CUSTOM_TEXT5 VARCHAR(64) ,
 CUSTOM_TEXT6 VARCHAR(64) ,
 CUSTOM_TEXT7 VARCHAR(64) ,
 CUSTOM_TEXT8 VARCHAR(64) ,
  PRIMARY KEY (TKTID)
) IN @DB_NAME@.TEMP836;

CREATE UNIQUE INDEX 
  @SCHEMA@.TASK_TEMPLATE_P
  ON @SCHEMA@.TASK_TEMPLATE_T
(   
  TKTID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column CONTACTS_QTIDS
CREATE AUX TABLE @SCHEMA@.AT213469
   IN @DB_NAME@.AS213469
   STORES @SCHEMA@.TASK_TEMPLATE_T COLUMN CONTACTS_QTIDS;
-- auxiliary index for LOB column CONTACTS_QTIDS
CREATE UNIQUE INDEX @SCHEMA@.AT213469I
  ON @SCHEMA@.AT213469
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column UI_SETTINGS
CREATE AUX TABLE @SCHEMA@.AT21346A
   IN @DB_NAME@.AS21346A
   STORES @SCHEMA@.TASK_TEMPLATE_T COLUMN UI_SETTINGS;
-- auxiliary index for LOB column UI_SETTINGS
CREATE UNIQUE INDEX @SCHEMA@.AT21346AI
  ON @SCHEMA@.AT21346A
   USING STOGROUP @STOGRP@;


CREATE UNIQUE INDEX 
  @SCHEMA@.TT_NAME_VF_NS
  ON @SCHEMA@.TASK_TEMPLATE_T
(   
  NAME, 
  VALID_FROM, 
  NAMESPACE
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TT_CCID_STATE
  ON @SCHEMA@.TASK_TEMPLATE_T
(   
  CONTAINMENT_CONTEXT_ID, 
  STATE
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TT_KND_INLN_VAL
  ON @SCHEMA@.TASK_TEMPLATE_T
(   
  KIND, 
  IS_INLINE, 
  VALID_FROM
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TT_NATLOOK_ADHOC
  ON @SCHEMA@.TASK_TEMPLATE_T
(   
  NATIVE_LOOKUP_NAME, 
  IS_AD_HOC
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.TASK_TEMPL_CPROP_T
(
 TKTID CHAR(16) FOR BIT DATA NOT NULL ,
 NAME VARCHAR(220) NOT NULL ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 DATA_TYPE VARCHAR(254) ,
 STRING_VALUE VARCHAR(254) ,
 DATA BLOB(1073741823) ,
  PRIMARY KEY (TKTID, NAME)
) IN @DB_NAME@.TEMPL37;

CREATE UNIQUE INDEX 
  @SCHEMA@.TASK_TEMPL_CPROP_P
  ON @SCHEMA@.TASK_TEMPL_CPROP_T
(   
  TKTID, 
  NAME
) NOT PADDED
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column DATA
CREATE AUX TABLE @SCHEMA@.AT21346B
   IN @DB_NAME@.AS21346B
   STORES @SCHEMA@.TASK_TEMPL_CPROP_T COLUMN DATA;
-- auxiliary index for LOB column DATA
CREATE UNIQUE INDEX @SCHEMA@.AT21346BI
  ON @SCHEMA@.AT21346B
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.TTCP_TKTID
  ON @SCHEMA@.TASK_TEMPL_CPROP_T
(   
  TKTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TTCP_CCID
  ON @SCHEMA@.TASK_TEMPL_CPROP_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.TASK_TEMPL_LDESC_T
(
 TKTID CHAR(16) FOR BIT DATA NOT NULL ,
 LOCALE VARCHAR(32) NOT NULL ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 DISPLAY_NAME VARCHAR(64) ,
 DESCRIPTION VARCHAR(254) ,
 DOCUMENTATION CLOB(4096) ,
  PRIMARY KEY (TKTID, LOCALE)
) IN @DB_NAME@.TEMPL38;

CREATE UNIQUE INDEX 
  @SCHEMA@.TASK_TEMPL_LDESC_P
  ON @SCHEMA@.TASK_TEMPL_LDESC_T
(   
  TKTID, 
  LOCALE
) NOT PADDED
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column DOCUMENTATION
CREATE AUX TABLE @SCHEMA@.AT21346C
   IN @DB_NAME@.AS21346C
   STORES @SCHEMA@.TASK_TEMPL_LDESC_T COLUMN DOCUMENTATION;
-- auxiliary index for LOB column DOCUMENTATION
CREATE UNIQUE INDEX @SCHEMA@.AT21346CI
  ON @SCHEMA@.AT21346C
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.TTLD_TKTID
  ON @SCHEMA@.TASK_TEMPL_LDESC_T
(   
  TKTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TTLD_CCID
  ON @SCHEMA@.TASK_TEMPL_LDESC_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TTLD_TT_LOC
  ON @SCHEMA@.TASK_TEMPL_LDESC_T
(   
  TKTID, 
  LOCALE DESC
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.TSERVICE_DESCRIPTION_T
(
 SVTID CHAR(16) FOR BIT DATA NOT NULL ,
 TKTID CHAR(16) FOR BIT DATA NOT NULL ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 IS_ONE_WAY SMALLINT NOT NULL ,
 SERVICE_REF_NAME VARCHAR(254) ,
 OPERATION VARCHAR(254) NOT NULL ,
 PORT VARCHAR(254) ,
 PORT_TYPE_NS VARCHAR(254) NOT NULL ,
 PORT_TYPE_NAME VARCHAR(254) NOT NULL ,
 S_BEAN_JNDI_NAME VARCHAR(254) ,
 SERVICE VARCHAR(254) ,
  PRIMARY KEY (SVTID)
) IN @DB_NAME@.TEMPL39;

CREATE UNIQUE INDEX 
  @SCHEMA@.TSERVICE_DESCRIPTION_P
  ON @SCHEMA@.TSERVICE_DESCRIPTION_T
(   
  SVTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TSD_TKTID
  ON @SCHEMA@.TSERVICE_DESCRIPTION_T
(   
  TKTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TSD_CCID
  ON @SCHEMA@.TSERVICE_DESCRIPTION_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.TASK_CELL_MAP_T
(
 TKTID CHAR(16) FOR BIT DATA NOT NULL ,
 CELL VARCHAR(220) NOT NULL ,
  PRIMARY KEY (TKTID, CELL)
) IN @DB_NAME@.TEMPL40;

CREATE UNIQUE INDEX 
  @SCHEMA@.TASK_CELL_MAP_P
  ON @SCHEMA@.TASK_CELL_MAP_T
(   
  TKTID, 
  CELL
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.TMAIL_T
(
 MNTID CHAR(16) FOR BIT DATA NOT NULL ,
 FROM_STATE INTEGER NOT NULL ,
 TO_STATE INTEGER NOT NULL ,
 LOCALE VARCHAR(32) NOT NULL ,
 HASH_CODE INTEGER NOT NULL ,
 SUBJECT VARCHAR(254) NOT NULL ,
 BODY_TEXT CLOB(4096) ,
  PRIMARY KEY (MNTID, FROM_STATE, TO_STATE, LOCALE)
) IN @DB_NAME@.TEMPL43;

CREATE UNIQUE INDEX 
  @SCHEMA@.TMAIL_P
  ON @SCHEMA@.TMAIL_T
(   
  MNTID, 
  FROM_STATE, 
  TO_STATE, 
  LOCALE
) NOT PADDED
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column BODY_TEXT
CREATE AUX TABLE @SCHEMA@.AT21346D
   IN @DB_NAME@.AS21346D
   STORES @SCHEMA@.TMAIL_T COLUMN BODY_TEXT;
-- auxiliary index for LOB column BODY_TEXT
CREATE UNIQUE INDEX @SCHEMA@.AT21346DI
  ON @SCHEMA@.AT21346D
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.EMT_HC
  ON @SCHEMA@.TMAIL_T
(   
  HASH_CODE
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.COMPLETION_TEMPLATE_T
(
 CMTID CHAR(16) FOR BIT DATA NOT NULL ,
 ORDER_NUMBER INTEGER NOT NULL ,
 TKTID CHAR(16) FOR BIT DATA NOT NULL ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 COMPL_CONDITION BLOB(3900K) ,
 CRITERION_FOR VARCHAR(254) ,
 COMPLETION_NAME VARCHAR(220) ,
 IS_DEFAULT_COMPLETION SMALLINT NOT NULL ,
 PREFIX_MAP BLOB(3900K) ,
 USE_DEFAULT_RESULT_CONSTRUCT SMALLINT NOT NULL ,
  PRIMARY KEY (CMTID)
) IN @DB_NAME@.TEMPL49;

CREATE UNIQUE INDEX 
  @SCHEMA@.COMPLETION_TEMPLATE_P
  ON @SCHEMA@.COMPLETION_TEMPLATE_T
(   
  CMTID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column COMPL_CONDITION
CREATE AUX TABLE @SCHEMA@.AT21346E
   IN @DB_NAME@.AS21346E
   STORES @SCHEMA@.COMPLETION_TEMPLATE_T COLUMN COMPL_CONDITION;
-- auxiliary index for LOB column COMPL_CONDITION
CREATE UNIQUE INDEX @SCHEMA@.AT21346EI
  ON @SCHEMA@.AT21346E
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column PREFIX_MAP
CREATE AUX TABLE @SCHEMA@.AT21346F
   IN @DB_NAME@.AS21346F
   STORES @SCHEMA@.COMPLETION_TEMPLATE_T COLUMN PREFIX_MAP;
-- auxiliary index for LOB column PREFIX_MAP
CREATE UNIQUE INDEX @SCHEMA@.AT21346FI
  ON @SCHEMA@.AT21346F
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.CMPT_TKTID_ORDER
  ON @SCHEMA@.COMPLETION_TEMPLATE_T
(   
  TKTID, 
  ORDER_NUMBER
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.CMPT_CCID
  ON @SCHEMA@.COMPLETION_TEMPLATE_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T
(
 RATID CHAR(16) FOR BIT DATA NOT NULL ,
 ORDER_NUMBER INTEGER NOT NULL ,
 CMTID CHAR(16) FOR BIT DATA NOT NULL ,
 TKTID CHAR(16) FOR BIT DATA NOT NULL ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 AGGR_PART VARCHAR(254) ,
 AGGR_LOCATION BLOB(3900K) ,
 AGGR_FUNCTION VARCHAR(254) NOT NULL ,
 AGGR_CONDITION BLOB(3900K) ,
 PREFIX_MAP BLOB(3900K) ,
  PRIMARY KEY (RATID)
) IN @DB_NAME@.TEMPL50;

CREATE UNIQUE INDEX 
  @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_P
  ON @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T
(   
  RATID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column AGGR_LOCATION
CREATE AUX TABLE @SCHEMA@.AT213470
   IN @DB_NAME@.AS213470
   STORES @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T COLUMN AGGR_LOCATION;
-- auxiliary index for LOB column AGGR_LOCATION
CREATE UNIQUE INDEX @SCHEMA@.AT213470I
  ON @SCHEMA@.AT213470
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column AGGR_CONDITION
CREATE AUX TABLE @SCHEMA@.AT213471
   IN @DB_NAME@.AS213471
 STORES @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T COLUMN AGGR_CONDITION;
-- auxiliary index for LOB column AGGR_CONDITION
CREATE UNIQUE INDEX @SCHEMA@.AT213471I
  ON @SCHEMA@.AT213471
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column PREFIX_MAP
CREATE AUX TABLE @SCHEMA@.AT213472
   IN @DB_NAME@.AS213472
   STORES @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T COLUMN PREFIX_MAP;
-- auxiliary index for LOB column PREFIX_MAP
CREATE UNIQUE INDEX @SCHEMA@.AT213472I
  ON @SCHEMA@.AT213472
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.RAGT_CMTID_ORD_TT
  ON @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T
(   
  CMTID, 
  ORDER_NUMBER, 
  TKTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.RAGT_CCID
  ON @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.PEOPLE_RESOURCE_REF_TEMPLATE_T
(
 PRRTID CHAR(16) FOR BIT DATA NOT NULL ,
 TEMPLATE_OID CHAR(16) FOR BIT DATA NOT NULL ,
 REASON INTEGER NOT NULL ,
 PRID CHAR(16) FOR BIT DATA NOT NULL ,
 PARAMETER_BINDINGS BLOB(3900K) ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
  PRIMARY KEY (PRRTID)
) IN @DB_NAME@.TEMPL57;

CREATE UNIQUE INDEX 
  @SCHEMA@.PEOPLE_RESOURCE_REF_TEMPLATE_P
  ON @SCHEMA@.PEOPLE_RESOURCE_REF_TEMPLATE_T
(   
  PRRTID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column PARAMETER_BINDINGS
CREATE AUX TABLE @SCHEMA@.AT213473
   IN @DB_NAME@.AS213473
 STORES @SCHEMA@.PEOPLE_RESOURCE_REF_TEMPLATE_T COLUMN
 PARAMETER_BINDINGS;
-- auxiliary index for LOB column PARAMETER_BINDINGS
CREATE UNIQUE INDEX @SCHEMA@.AT213473I
  ON @SCHEMA@.AT213473
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.PRRT_PRID
  ON @SCHEMA@.PEOPLE_RESOURCE_REF_TEMPLATE_T
(   
  PRID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.PRRT_ccID
  ON @SCHEMA@.PEOPLE_RESOURCE_REF_TEMPLATE_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ESCALATION_INSTANCE_T
(
 ESIID CHAR(16) FOR BIT DATA NOT NULL ,
 ESTID CHAR(16) FOR BIT DATA ,
 FIRST_ESIID CHAR(16) FOR BIT DATA ,
 PREVIOUS_ESIID CHAR(16) FOR BIT DATA ,
 TKIID CHAR(16) FOR BIT DATA NOT NULL ,
 MNTID CHAR(16) FOR BIT DATA ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 WSID_1 CHAR(16) FOR BIT DATA ,
 WSID_1_HC INTEGER ,
 WSID_2 CHAR(16) FOR BIT DATA ,
 WSID_2_HC INTEGER ,
 NAME VARCHAR(220) ,
 STATE INTEGER NOT NULL ,
 ACTIVATION_STATE INTEGER NOT NULL ,
 AT_LEAST_EXPECTED_STATE INTEGER NOT NULL ,
 ACTIVATION_TIME TIMESTAMP ,
 ESCALATION_TIME TIMESTAMP ,
 DURATION_UNTIL_ESCALATION VARCHAR(254) ,
 DURATION_UNTIL_REPEATS VARCHAR(254) ,
 INCREASE_PRIORITY INTEGER NOT NULL ,
 ACTION INTEGER NOT NULL ,
 ESCALATION_RECEIVER_QTID CHAR(16) FOR BIT DATA ,
 RECEIVER_EMAIL_QTID CHAR(16) FOR BIT DATA ,
 SCHEDULER_ID VARCHAR(254) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (ESIID)
) IN @DB_NAME@.INSTA31;

CREATE UNIQUE INDEX 
  @SCHEMA@.ESCALATION_INSTANCE_P
  ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  ESIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.ESI_FIRST
  ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  FIRST_ESIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.ESI_TKIID_ASTATE
  ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  TKIID, 
  ACTIVATION_STATE, 
  STATE
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.ESI_TKIID_STATE
  ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  TKIID, 
  STATE
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.ESI_PREV
  ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  PREVIOUS_ESIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.ESI_ESTID
  ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  ESTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.ESI_CCID
  ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.ESI_EST_ESI
  ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  ESTID, 
  ESIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.ESI_WSID1
  ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  WSID_1
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.ESI_WSID2
  ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  WSID_2
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ESC_INST_CPROP_T
(
 ESIID CHAR(16) FOR BIT DATA NOT NULL ,
 NAME VARCHAR(220) NOT NULL ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 WSID_1 CHAR(16) FOR BIT DATA ,
 WSID_1_HC INTEGER ,
 WSID_2 CHAR(16) FOR BIT DATA ,
 WSID_2_HC INTEGER ,
 STRING_VALUE VARCHAR(254) ,
 DATA_TYPE VARCHAR(254) ,
 DATA BLOB(1073741823) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (ESIID, NAME)
) IN @DB_NAME@.INSTA32;

CREATE UNIQUE INDEX 
  @SCHEMA@.ESC_INST_CPROP_P
  ON @SCHEMA@.ESC_INST_CPROP_T
(   
  ESIID, 
  NAME
) NOT PADDED
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column DATA
CREATE AUX TABLE @SCHEMA@.AT213474
   IN @DB_NAME@.AS213474
   STORES @SCHEMA@.ESC_INST_CPROP_T COLUMN DATA;
-- auxiliary index for LOB column DATA
CREATE UNIQUE INDEX @SCHEMA@.AT213474I
  ON @SCHEMA@.AT213474
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.EICP_CCID
  ON @SCHEMA@.ESC_INST_CPROP_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ESC_INST_LDESC_T
(
 ESIID CHAR(16) FOR BIT DATA NOT NULL ,
 LOCALE VARCHAR(32) NOT NULL ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 WSID_1 CHAR(16) FOR BIT DATA ,
 WSID_1_HC INTEGER ,
 WSID_2 CHAR(16) FOR BIT DATA ,
 WSID_2_HC INTEGER ,
 DISPLAY_NAME VARCHAR(64) ,
 DESCRIPTION VARCHAR(254) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (ESIID, LOCALE)
) IN @DB_NAME@.INSTA33;

CREATE UNIQUE INDEX 
  @SCHEMA@.ESC_INST_LDESC_P
  ON @SCHEMA@.ESC_INST_LDESC_T
(   
  ESIID, 
  LOCALE
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.EILD_CCID
  ON @SCHEMA@.ESC_INST_LDESC_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.EIDOCUMENTATION_T
(
 ESIID CHAR(16) FOR BIT DATA NOT NULL ,
 LOCALE VARCHAR(32) NOT NULL ,
 TKIID CHAR(16) FOR BIT DATA NOT NULL ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 DOCUMENTATION CLOB(4096) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (ESIID, LOCALE)
) IN @DB_NAME@.INSTA34;

CREATE UNIQUE INDEX 
  @SCHEMA@.EIDOCUMENTATION_P
  ON @SCHEMA@.EIDOCUMENTATION_T
(   
  ESIID, 
  LOCALE
) NOT PADDED
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column DOCUMENTATION
CREATE AUX TABLE @SCHEMA@.AT213475
   IN @DB_NAME@.AS213475
   STORES @SCHEMA@.EIDOCUMENTATION_T COLUMN DOCUMENTATION;
-- auxiliary index for LOB column DOCUMENTATION
CREATE UNIQUE INDEX @SCHEMA@.AT213475I
  ON @SCHEMA@.AT213475
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.EIDOC_CCID
  ON @SCHEMA@.EIDOCUMENTATION_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ISERVICE_DESCRIPTION_T
(
 SVTID CHAR(16) FOR BIT DATA NOT NULL ,
 TKIID CHAR(16) FOR BIT DATA NOT NULL ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 IS_ONE_WAY SMALLINT NOT NULL ,
 SERVICE_REF_NAME VARCHAR(254) ,
 OPERATION VARCHAR(254) NOT NULL ,
 PORT VARCHAR(254) ,
 PORT_TYPE_NS VARCHAR(254) NOT NULL ,
 PORT_TYPE_NAME VARCHAR(254) NOT NULL ,
 S_BEAN_JNDI_NAME VARCHAR(254) ,
 SERVICE VARCHAR(254) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (SVTID)
) IN @DB_NAME@.INSTA35;

CREATE UNIQUE INDEX 
  @SCHEMA@.ISERVICE_DESCRIPTION_P
  ON @SCHEMA@.ISERVICE_DESCRIPTION_T
(   
  SVTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.ISD_TKIID
  ON @SCHEMA@.ISERVICE_DESCRIPTION_T
(   
  TKIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.ISD_CCID
  ON @SCHEMA@.ISERVICE_DESCRIPTION_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.TASK_INSTANCE_T
(
 TKIID CHAR(16) FOR BIT DATA NOT NULL ,
 NAME VARCHAR(220) NOT NULL ,
 NAMESPACE VARCHAR(254) NOT NULL ,
 TKTID CHAR(16) FOR BIT DATA ,
 TOP_TKIID CHAR(16) FOR BIT DATA NOT NULL ,
 FOLLOW_ON_TKIID CHAR(16) FOR BIT DATA ,
 APPLICATION_NAME VARCHAR(220) ,
 APPLICATION_DEFAULTS_ID CHAR(16) FOR BIT DATA ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA ,
 PARENT_CONTEXT_ID CHAR(16) FOR BIT DATA ,
 STATE INTEGER NOT NULL ,
 KIND INTEGER NOT NULL ,
 AUTO_DELETE_MODE INTEGER NOT NULL ,
 HIERARCHY_POSITION INTEGER NOT NULL ,
 TYPE VARCHAR(254) ,
 SVTID CHAR(16) FOR BIT DATA ,
 SUPPORTS_CLAIM_SUSPENDED SMALLINT NOT NULL ,
 SUPPORTS_AUTO_CLAIM SMALLINT NOT NULL ,
 SUPPORTS_FOLLOW_ON_TASK SMALLINT NOT NULL ,
 IS_AD_HOC SMALLINT NOT NULL ,
 IS_ESCALATED SMALLINT NOT NULL ,
 IS_INLINE SMALLINT NOT NULL ,
 IS_SUSPENDED SMALLINT NOT NULL ,
 IS_WAITING_FOR_SUBTASK SMALLINT NOT NULL ,
 SUPPORTS_DELEGATION SMALLINT NOT NULL ,
 SUPPORTS_SUB_TASK SMALLINT NOT NULL ,
 IS_CHILD SMALLINT NOT NULL ,
 HAS_ESCALATIONS SMALLINT ,
 START_TIME TIMESTAMP ,
 ACTIVATION_TIME TIMESTAMP ,
 LAST_MODIFICATION_TIME TIMESTAMP ,
 LAST_STATE_CHANGE_TIME TIMESTAMP ,
 COMPLETION_TIME TIMESTAMP ,
 DUE_TIME TIMESTAMP ,
 EXPIRATION_TIME TIMESTAMP ,
 FIRST_ACTIVATION_TIME TIMESTAMP ,
 DEFAULT_LOCALE VARCHAR(32) ,
 DURATION_UNTIL_DELETED VARCHAR(254) ,
 DURATION_UNTIL_DUE VARCHAR(254) ,
 DURATION_UNTIL_EXPIRES VARCHAR(254) ,
 CALENDAR_NAME VARCHAR(254) ,
 JNDI_NAME_CALENDAR VARCHAR(254) ,
 JNDI_NAME_STAFF_PROVIDER VARCHAR(254) ,
 CONTEXT_AUTHORIZATION INTEGER NOT NULL ,
 ORIGINATOR VARCHAR(128) ,
 STARTER VARCHAR(128) ,
 OWNER VARCHAR(128) ,
 ADMIN_QTID CHAR(16) FOR BIT DATA ,
 EDITOR_QTID CHAR(16) FOR BIT DATA ,
 POTENTIAL_OWNER_QTID CHAR(16) FOR BIT DATA ,
 POTENTIAL_STARTER_QTID CHAR(16) FOR BIT DATA ,
 READER_QTID CHAR(16) FOR BIT DATA ,
 PRIORITY INTEGER ,
 SCHEDULER_ID VARCHAR(254) ,
 SERVICE_TICKET VARCHAR(254) ,
 EVENT_HANDLER_NAME VARCHAR(64) ,
 BUSINESS_RELEVANCE SMALLINT NOT NULL ,
 RESUMES TIMESTAMP ,
 SUBSTITUTION_POLICY INTEGER NOT NULL ,
 DELETION_TIME TIMESTAMP ,
 ASSIGNMENT_TYPE INTEGER NOT NULL ,
 INHERITED_AUTH INTEGER NOT NULL ,
 PARALLEL_INHERITED_AUTH INTEGER NOT NULL ,
 INVOKED_INSTANCE_ID CHAR(16) FOR BIT DATA ,
 INVOKED_INSTANCE_TYPE INTEGER NOT NULL ,
 WORK_BASKET VARCHAR(254) ,
 IS_READ SMALLINT NOT NULL ,
 IS_TRANSFERRED_TO_WORK_BASKET SMALLINT NOT NULL ,
 CREATED_WITH_VERSION INTEGER NOT NULL ,
 WSID_1 CHAR(16) FOR BIT DATA ,
 WSID_1_HC INTEGER ,
 WSID_2 CHAR(16) FOR BIT DATA ,
 WSID_2_HC INTEGER ,
 CUSTOM_TEXT1 VARCHAR(64) ,
 CUSTOM_TEXT2 VARCHAR(64) ,
 CUSTOM_TEXT3 VARCHAR(64) ,
 CUSTOM_TEXT4 VARCHAR(64) ,
 CUSTOM_TEXT5 VARCHAR(64) ,
 CUSTOM_TEXT6 VARCHAR(64) ,
 CUSTOM_TEXT7 VARCHAR(64) ,
 CUSTOM_TEXT8 VARCHAR(64) ,
 EXT_ATTR INTEGER ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (TKIID)
) IN @DB_NAME@.INST836;

CREATE UNIQUE INDEX 
  @SCHEMA@.TASK_INSTANCE_P
  ON @SCHEMA@.TASK_INSTANCE_T
(   
  TKIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TI_PARENT
  ON @SCHEMA@.TASK_INSTANCE_T
(   
  PARENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TI_SERVICET
  ON @SCHEMA@.TASK_INSTANCE_T
(   
  SERVICE_TICKET
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TI_CCID
  ON @SCHEMA@.TASK_INSTANCE_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TI_TK_TOPTK
  ON @SCHEMA@.TASK_INSTANCE_T
(   
  TKTID, 
  TKIID, 
  TOP_TKIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TI_TOPTKIID
  ON @SCHEMA@.TASK_INSTANCE_T
(   
  TOP_TKIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TI_TI_KND_ST
  ON @SCHEMA@.TASK_INSTANCE_T
(   
  TKIID, 
  KIND, 
  STATE
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TI_WOBA
  ON @SCHEMA@.TASK_INSTANCE_T
(   
  WORK_BASKET
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TI_TYPE
  ON @SCHEMA@.TASK_INSTANCE_T
(   
  TYPE
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TI_WSID1
  ON @SCHEMA@.TASK_INSTANCE_T
(   
  WSID_1, 
  KIND
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TI_WSID2
  ON @SCHEMA@.TASK_INSTANCE_T
(   
  WSID_2, 
  KIND
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TI_WSID1S
  ON @SCHEMA@.TASK_INSTANCE_T
(   
  WSID_1, 
  KIND, 
  STATE
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TI_WSID2S
  ON @SCHEMA@.TASK_INSTANCE_T
(   
  WSID_2, 
  KIND, 
  STATE
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TI_Q1
  ON @SCHEMA@.TASK_INSTANCE_T
(   
  KIND, 
  PRIORITY, 
  OWNER, 
  STARTER, 
  ORIGINATOR
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.TASK_INSTANCE_EXT_ATTR_T
(
 TKIID CHAR(16) FOR BIT DATA NOT NULL ,
 KIND INTEGER NOT NULL ,
 VALUE VARCHAR(254) ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (TKIID, KIND)
) IN @DB_NAME@.INSTA82;

CREATE UNIQUE INDEX 
  @SCHEMA@.TASK_INSTANCE_EXT_ATTR_P
  ON @SCHEMA@.TASK_INSTANCE_EXT_ATTR_T
(   
  TKIID, 
  KIND
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TIEA_CTXID
  ON @SCHEMA@.TASK_INSTANCE_EXT_ATTR_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.TASK_CONTEXT_T
(
 TKIID CHAR(16) FOR BIT DATA NOT NULL ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 SERVICE_CONTEXT BLOB(3900K) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (TKIID)
) IN @DB_NAME@.INSTA53;

CREATE UNIQUE INDEX 
  @SCHEMA@.TASK_CONTEXT_P
  ON @SCHEMA@.TASK_CONTEXT_T
(   
  TKIID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column SERVICE_CONTEXT
CREATE AUX TABLE @SCHEMA@.AT213476
   IN @DB_NAME@.AS213476
   STORES @SCHEMA@.TASK_CONTEXT_T COLUMN SERVICE_CONTEXT;
-- auxiliary index for LOB column SERVICE_CONTEXT
CREATE UNIQUE INDEX @SCHEMA@.AT213476I
  ON @SCHEMA@.AT213476
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.TC_CCID
  ON @SCHEMA@.TASK_CONTEXT_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.CONTACT_QUERIES_T
(
 TKIID CHAR(16) FOR BIT DATA NOT NULL ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 CONTACTS_QTIDS BLOB(3900k) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (TKIID)
) IN @DB_NAME@.INSTA37;

CREATE UNIQUE INDEX 
  @SCHEMA@.CONTACT_QUERIES_P
  ON @SCHEMA@.CONTACT_QUERIES_T
(   
  TKIID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column CONTACTS_QTIDS
CREATE AUX TABLE @SCHEMA@.AT213477
   IN @DB_NAME@.AS213477
   STORES @SCHEMA@.CONTACT_QUERIES_T COLUMN CONTACTS_QTIDS;
-- auxiliary index for LOB column CONTACTS_QTIDS
CREATE UNIQUE INDEX @SCHEMA@.AT213477I
  ON @SCHEMA@.AT213477
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.CQ_CCID
  ON @SCHEMA@.CONTACT_QUERIES_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.UISETTINGS_T
(
 TKIID CHAR(16) FOR BIT DATA NOT NULL ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 UI_SETTINGS BLOB(3900k) NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (TKIID)
) IN @DB_NAME@.INSTA38;

CREATE UNIQUE INDEX 
  @SCHEMA@.UISETTINGS_P
  ON @SCHEMA@.UISETTINGS_T
(   
  TKIID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column UI_SETTINGS
CREATE AUX TABLE @SCHEMA@.AT213478
   IN @DB_NAME@.AS213478
   STORES @SCHEMA@.UISETTINGS_T COLUMN UI_SETTINGS;
-- auxiliary index for LOB column UI_SETTINGS
CREATE UNIQUE INDEX @SCHEMA@.AT213478I
  ON @SCHEMA@.AT213478
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.UIS_CCID
  ON @SCHEMA@.UISETTINGS_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.REPLY_HANDLER_T
(
 TKIID CHAR(16) FOR BIT DATA NOT NULL ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 REPLY_HANDLER BLOB(3900k) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (TKIID)
) IN @DB_NAME@.INSTA39;

CREATE UNIQUE INDEX 
  @SCHEMA@.REPLY_HANDLER_P
  ON @SCHEMA@.REPLY_HANDLER_T
(   
  TKIID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column REPLY_HANDLER
CREATE AUX TABLE @SCHEMA@.AT213479
   IN @DB_NAME@.AS213479
   STORES @SCHEMA@.REPLY_HANDLER_T COLUMN REPLY_HANDLER;
-- auxiliary index for LOB column REPLY_HANDLER
CREATE UNIQUE INDEX @SCHEMA@.AT213479I
  ON @SCHEMA@.AT213479
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.RH_CCID
  ON @SCHEMA@.REPLY_HANDLER_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.TASK_TIMER_T
(
 OID CHAR(16) FOR BIT DATA NOT NULL ,
 KIND INTEGER NOT NULL ,
 SCHEDULER_ID VARCHAR(254) NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (OID, KIND)
) IN @DB_NAME@.INSTA50;

CREATE UNIQUE INDEX 
  @SCHEMA@.TASK_TIMER_P
  ON @SCHEMA@.TASK_TIMER_T
(   
  OID, 
  KIND
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.TASK_INST_CPROP_T
(
 TKIID CHAR(16) FOR BIT DATA NOT NULL ,
 WSID_1 CHAR(16) FOR BIT DATA ,
 WSID_1_HC INTEGER ,
 WSID_2 CHAR(16) FOR BIT DATA ,
 WSID_2_HC INTEGER ,
 NAME VARCHAR(220) NOT NULL ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 DATA_TYPE VARCHAR(254) ,
 STRING_VALUE VARCHAR(254) ,
 DATA BLOB(1073741823) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (TKIID, NAME)
) IN @DB_NAME@.INSTA40;

CREATE UNIQUE INDEX 
  @SCHEMA@.TASK_INST_CPROP_P
  ON @SCHEMA@.TASK_INST_CPROP_T
(   
  TKIID, 
  NAME
) NOT PADDED
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column DATA
CREATE AUX TABLE @SCHEMA@.AT21347A
   IN @DB_NAME@.AS21347A
   STORES @SCHEMA@.TASK_INST_CPROP_T COLUMN DATA;
-- auxiliary index for LOB column DATA
CREATE UNIQUE INDEX @SCHEMA@.AT21347AI
  ON @SCHEMA@.AT21347A
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.TICP_CCID
  ON @SCHEMA@.TASK_INST_CPROP_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.TASK_INST_LDESC_T
(
 TKIID CHAR(16) FOR BIT DATA NOT NULL ,
 LOCALE VARCHAR(32) NOT NULL ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 WSID_1 CHAR(16) FOR BIT DATA ,
 WSID_1_HC INTEGER ,
 WSID_2 CHAR(16) FOR BIT DATA ,
 WSID_2_HC INTEGER ,
 DISPLAY_NAME VARCHAR(64) ,
 DESCRIPTION VARCHAR(254) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (TKIID, LOCALE)
) IN @DB_NAME@.INSTA41;

CREATE UNIQUE INDEX 
  @SCHEMA@.TASK_INST_LDESC_P
  ON @SCHEMA@.TASK_INST_LDESC_T
(   
  TKIID, 
  LOCALE
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TILD_CCID
  ON @SCHEMA@.TASK_INST_LDESC_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TILD_PD1
  ON @SCHEMA@.TASK_INST_LDESC_T
(   
  LOCALE, 
  TKIID, 
  DESCRIPTION
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TILD_PD2
  ON @SCHEMA@.TASK_INST_LDESC_T
(   
  LOCALE, 
  TKIID, 
  DISPLAY_NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.TIDOCUMENTATION_T
(
 TKIID CHAR(16) FOR BIT DATA NOT NULL ,
 LOCALE VARCHAR(32) NOT NULL ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 DOCUMENTATION CLOB(4096) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (TKIID, LOCALE)
) IN @DB_NAME@.INSTA42;

CREATE UNIQUE INDEX 
  @SCHEMA@.TIDOCUMENTATION_P
  ON @SCHEMA@.TIDOCUMENTATION_T
(   
  TKIID, 
  LOCALE
) NOT PADDED
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column DOCUMENTATION
CREATE AUX TABLE @SCHEMA@.AT21347B
   IN @DB_NAME@.AS21347B
   STORES @SCHEMA@.TIDOCUMENTATION_T COLUMN DOCUMENTATION;
-- auxiliary index for LOB column DOCUMENTATION
CREATE UNIQUE INDEX @SCHEMA@.AT21347BI
  ON @SCHEMA@.AT21347B
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.TIDOC_CCID
  ON @SCHEMA@.TIDOCUMENTATION_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ITASK_MESSAGE_DEFINITION_T
(
 TMTID CHAR(16) FOR BIT DATA NOT NULL ,
 TKIID CHAR(16) FOR BIT DATA ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 FAULT_NAME VARCHAR(254) ,
 KIND INTEGER NOT NULL ,
 MESSAGE_TYPE_NS VARCHAR(220) NOT NULL ,
 MESSAGE_TYPE_NAME VARCHAR(220) NOT NULL ,
 MESSAGE_DEFINITION BLOB(3900K) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (TMTID)
) IN @DB_NAME@.INSTA43;

CREATE UNIQUE INDEX 
  @SCHEMA@.ITASK_MESSAGE_DEFINITION_P
  ON @SCHEMA@.ITASK_MESSAGE_DEFINITION_T
(   
  TMTID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column MESSAGE_DEFINITION
CREATE AUX TABLE @SCHEMA@.AT21347C
   IN @DB_NAME@.AS21347C
 STORES @SCHEMA@.ITASK_MESSAGE_DEFINITION_T COLUMN
 MESSAGE_DEFINITION;
-- auxiliary index for LOB column MESSAGE_DEFINITION
CREATE UNIQUE INDEX @SCHEMA@.AT21347CI
  ON @SCHEMA@.AT21347C
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.ITMD_IDKINSTYPE
  ON @SCHEMA@.ITASK_MESSAGE_DEFINITION_T
(   
  TKIID, 
  MESSAGE_TYPE_NS, 
  MESSAGE_TYPE_NAME, 
  KIND
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.ITMD_TKIIDKINDFN
  ON @SCHEMA@.ITASK_MESSAGE_DEFINITION_T
(   
  TKIID, 
  KIND, 
  FAULT_NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.ITMD_CCID
  ON @SCHEMA@.ITASK_MESSAGE_DEFINITION_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.TASK_MESSAGE_INSTANCE_T
(
 TMIID CHAR(16) FOR BIT DATA NOT NULL ,
 TMTID CHAR(16) FOR BIT DATA ,
 TKIID CHAR(16) FOR BIT DATA NOT NULL ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 FAULT_NAME VARCHAR(254) ,
 KIND INTEGER NOT NULL ,
 MESSAGE_TYPE_NS VARCHAR(220) NOT NULL ,
 MESSAGE_TYPE_NAME VARCHAR(220) NOT NULL ,
 DATA BLOB(1073741823) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (TMIID)
) IN @DB_NAME@.INSTA44;

CREATE UNIQUE INDEX 
  @SCHEMA@.TASK_MESSAGE_INSTANCE_P
  ON @SCHEMA@.TASK_MESSAGE_INSTANCE_T
(   
  TMIID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column DATA
CREATE AUX TABLE @SCHEMA@.AT21347D
   IN @DB_NAME@.AS21347D
   STORES @SCHEMA@.TASK_MESSAGE_INSTANCE_T COLUMN DATA;
-- auxiliary index for LOB column DATA
CREATE UNIQUE INDEX @SCHEMA@.AT21347DI
  ON @SCHEMA@.AT21347D
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.TMI_TI_K
  ON @SCHEMA@.TASK_MESSAGE_INSTANCE_T
(   
  TKIID, 
  KIND
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TMI_TMTID
  ON @SCHEMA@.TASK_MESSAGE_INSTANCE_T
(   
  TMTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TMI_CCID
  ON @SCHEMA@.TASK_MESSAGE_INSTANCE_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.TASK_AUDIT_LOG_T
(
 ALID CHAR(16) FOR BIT DATA NOT NULL ,
 AUDIT_EVENT INTEGER NOT NULL ,
 TKIID CHAR(16) FOR BIT DATA ,
 TKTID CHAR(16) FOR BIT DATA ,
 ESIID CHAR(16) FOR BIT DATA ,
 ESTID CHAR(16) FOR BIT DATA ,
 TOP_TKIID CHAR(16) FOR BIT DATA ,
 FOLLOW_ON_TKIID CHAR(16) FOR BIT DATA ,
 PARENT_TKIID CHAR(16) FOR BIT DATA ,
 PARENT_CONTEXT_ID CHAR(16) FOR BIT DATA ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA ,
 WI_REASON INTEGER ,
 NAME VARCHAR(254) ,
 NAMESPACE VARCHAR(254) ,
 VALID_FROM_UTC TIMESTAMP ,
 EVENT_TIME_UTC TIMESTAMP ,
 PARENT_TASK_NAME VARCHAR(254) ,
 PARENT_TASK_NAMESPACE VARCHAR(254) ,
 TASK_KIND INTEGER ,
 TASK_STATE INTEGER ,
 FAULT_TYPE_NAME VARCHAR(220) ,
 FAULT_NAMESPACE VARCHAR(220) ,
 FAULT_NAME VARCHAR(220) ,
 NEW_USER VARCHAR(128) ,
 OLD_USER VARCHAR(128) ,
 PRINCIPAL VARCHAR(128) ,
 USERS CLOB(8192) ,
 DESCRIPTION CLOB(8192) ,
 MESSAGE_DATA BLOB(1073741823) ,
 SNAPSHOT_ID VARCHAR(254) ,
 SNAPSHOT_NAME VARCHAR(254) ,
 PROCESS_APP_ACRONYM VARCHAR(7) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (ALID)
) IN @DB_NAME@.AUDIT02;

CREATE UNIQUE INDEX 
  @SCHEMA@.TASK_AUDIT_LOG_P
  ON @SCHEMA@.TASK_AUDIT_LOG_T
(   
  ALID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column USERS
CREATE AUX TABLE @SCHEMA@.AT21347E
   IN @DB_NAME@.AS21347E
   STORES @SCHEMA@.TASK_AUDIT_LOG_T COLUMN USERS;
-- auxiliary index for LOB column USERS
CREATE UNIQUE INDEX @SCHEMA@.AT21347EI
  ON @SCHEMA@.AT21347E
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column DESCRIPTION
CREATE AUX TABLE @SCHEMA@.AT21347F
   IN @DB_NAME@.AS21347F
   STORES @SCHEMA@.TASK_AUDIT_LOG_T COLUMN DESCRIPTION;
-- auxiliary index for LOB column DESCRIPTION
CREATE UNIQUE INDEX @SCHEMA@.AT21347FI
  ON @SCHEMA@.AT21347F
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column MESSAGE_DATA
CREATE AUX TABLE @SCHEMA@.AT213480
   IN @DB_NAME@.AS213480
   STORES @SCHEMA@.TASK_AUDIT_LOG_T COLUMN MESSAGE_DATA;
-- auxiliary index for LOB column MESSAGE_DATA
CREATE UNIQUE INDEX @SCHEMA@.AT213480I
  ON @SCHEMA@.AT213480
   USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.IMAIL_T
(
 OBJECT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 FROM_STATE INTEGER NOT NULL ,
 TO_STATE INTEGER NOT NULL ,
 LOCALE VARCHAR(32) NOT NULL ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 SUBJECT VARCHAR(254) NOT NULL ,
 URI VARCHAR(254) ,
 BODY_TEXT CLOB(4096) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (OBJECT_ID, FROM_STATE, TO_STATE, LOCALE)
) IN @DB_NAME@.INSTA52;

CREATE UNIQUE INDEX 
  @SCHEMA@.IMAIL_P
  ON @SCHEMA@.IMAIL_T
(   
  OBJECT_ID, 
  FROM_STATE, 
  TO_STATE, 
  LOCALE
) NOT PADDED
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column BODY_TEXT
CREATE AUX TABLE @SCHEMA@.AT213481
   IN @DB_NAME@.AS213481
   STORES @SCHEMA@.IMAIL_T COLUMN BODY_TEXT;
-- auxiliary index for LOB column BODY_TEXT
CREATE UNIQUE INDEX @SCHEMA@.AT213481I
  ON @SCHEMA@.AT213481
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.IMN_CTX
  ON @SCHEMA@.IMAIL_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.TASK_HISTORY_T
(
 PKID CHAR(16) FOR BIT DATA NOT NULL ,
 EVENT INTEGER NOT NULL ,
 TKIID CHAR(16) FOR BIT DATA NOT NULL ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 PARENT_TKIID CHAR(16) FOR BIT DATA ,
 ESIID CHAR(16) FOR BIT DATA ,
 REASON INTEGER NOT NULL ,
 EVENT_TIME TIMESTAMP NOT NULL ,
 NEXT_TIME TIMESTAMP ,
 WSID_1 CHAR(16) FOR BIT DATA ,
 WSID_1_HC INTEGER ,
 WSID_2 CHAR(16) FOR BIT DATA ,
 WSID_2_HC INTEGER ,
 PRINCIPAL VARCHAR(128) NOT NULL ,
 WORK_ITEM_KIND INTEGER NOT NULL ,
 FROM_ID VARCHAR(128) ,
 TO_ID VARCHAR(128) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (PKID)
) IN @DB_NAME@.INSTA63;

CREATE UNIQUE INDEX 
  @SCHEMA@.TASK_HISTORY_P
  ON @SCHEMA@.TASK_HISTORY_T
(   
  PKID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TH_TKIID
  ON @SCHEMA@.TASK_HISTORY_T
(   
  TKIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.TH_CTXID
  ON @SCHEMA@.TASK_HISTORY_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.COMPLETION_INSTANCE_T
(
 CMIID CHAR(16) FOR BIT DATA NOT NULL ,
 ORDER_NUMBER INTEGER NOT NULL ,
 TKIID CHAR(16) FOR BIT DATA NOT NULL ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 COMPL_CONDITION BLOB(3900K) ,
 CRITERION_FOR VARCHAR(254) ,
 CRITERION_FOR_TIME TIMESTAMP ,
 COMPLETION_NAME VARCHAR(220) ,
 IS_DEFAULT_COMPLETION SMALLINT NOT NULL ,
 PREFIX_MAP BLOB(3900K) ,
 USE_DEFAULT_RESULT_CONSTRUCT SMALLINT NOT NULL ,
 SCHEDULER_ID VARCHAR(254) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (CMIID)
) IN @DB_NAME@.INSTA67;

CREATE UNIQUE INDEX 
  @SCHEMA@.COMPLETION_INSTANCE_P
  ON @SCHEMA@.COMPLETION_INSTANCE_T
(   
  CMIID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column COMPL_CONDITION
CREATE AUX TABLE @SCHEMA@.AT213482
   IN @DB_NAME@.AS213482
   STORES @SCHEMA@.COMPLETION_INSTANCE_T COLUMN COMPL_CONDITION;
-- auxiliary index for LOB column COMPL_CONDITION
CREATE UNIQUE INDEX @SCHEMA@.AT213482I
  ON @SCHEMA@.AT213482
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column PREFIX_MAP
CREATE AUX TABLE @SCHEMA@.AT213483
   IN @DB_NAME@.AS213483
   STORES @SCHEMA@.COMPLETION_INSTANCE_T COLUMN PREFIX_MAP;
-- auxiliary index for LOB column PREFIX_MAP
CREATE UNIQUE INDEX @SCHEMA@.AT213483I
  ON @SCHEMA@.AT213483
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.CMPI_TKIID_ORDER
  ON @SCHEMA@.COMPLETION_INSTANCE_T
(   
  TKIID, 
  ORDER_NUMBER
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.CMPI_CCID
  ON @SCHEMA@.COMPLETION_INSTANCE_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T
(
 RAIID CHAR(16) FOR BIT DATA NOT NULL ,
 ORDER_NUMBER INTEGER NOT NULL ,
 CMIID CHAR(16) FOR BIT DATA NOT NULL ,
 TKIID CHAR(16) FOR BIT DATA NOT NULL ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 AGGR_PART VARCHAR(254) ,
 AGGR_LOCATION BLOB(3900K) ,
 AGGR_FUNCTION VARCHAR(254) NOT NULL ,
 AGGR_CONDITION BLOB(3900K) ,
 PREFIX_MAP BLOB(3900K) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (RAIID)
) IN @DB_NAME@.INSTA68;

CREATE UNIQUE INDEX 
  @SCHEMA@.RESULT_AGGREGATION_INSTANCE_P
  ON @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T
(   
  RAIID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column AGGR_LOCATION
CREATE AUX TABLE @SCHEMA@.AT213484
   IN @DB_NAME@.AS213484
   STORES @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T COLUMN AGGR_LOCATION;
-- auxiliary index for LOB column AGGR_LOCATION
CREATE UNIQUE INDEX @SCHEMA@.AT213484I
  ON @SCHEMA@.AT213484
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column AGGR_CONDITION
CREATE AUX TABLE @SCHEMA@.AT213485
   IN @DB_NAME@.AS213485
 STORES @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T COLUMN AGGR_CONDITION;
-- auxiliary index for LOB column AGGR_CONDITION
CREATE UNIQUE INDEX @SCHEMA@.AT213485I
  ON @SCHEMA@.AT213485
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column PREFIX_MAP
CREATE AUX TABLE @SCHEMA@.AT213486
   IN @DB_NAME@.AS213486
   STORES @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T COLUMN PREFIX_MAP;
-- auxiliary index for LOB column PREFIX_MAP
CREATE UNIQUE INDEX @SCHEMA@.AT213486I
  ON @SCHEMA@.AT213486
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.RAGI_CMIID_ORDER
  ON @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T
(   
  CMIID, 
  ORDER_NUMBER
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.RAGI_CCID
  ON @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.SAVED_TASK_MESSAGE_T
(
 STMID CHAR(16) FOR BIT DATA NOT NULL ,
 RELATED_OID CHAR(16) FOR BIT DATA NOT NULL ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 KIND INTEGER NOT NULL ,
 SCHEDULER_ID VARCHAR(254) ,
 CREATION_TIME TIMESTAMP NOT NULL ,
 EXPECTED_ARRIVAL_TIME TIMESTAMP NOT NULL ,
 MESSAGE BLOB(1073741823) ,
 MESSAGE_IL VARCHAR(3000) FOR BIT DATA ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (STMID)
) IN @DB_NAME@.INSTA70;

CREATE UNIQUE INDEX 
  @SCHEMA@.SAVED_TASK_MESSAGE_P
  ON @SCHEMA@.SAVED_TASK_MESSAGE_T
(   
  STMID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column MESSAGE
CREATE AUX TABLE @SCHEMA@.AT213487
   IN @DB_NAME@.AS213487
   STORES @SCHEMA@.SAVED_TASK_MESSAGE_T COLUMN MESSAGE;
-- auxiliary index for LOB column MESSAGE
CREATE UNIQUE INDEX @SCHEMA@.AT213487I
  ON @SCHEMA@.AT213487
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.STM_ROIDKIND
  ON @SCHEMA@.SAVED_TASK_MESSAGE_T
(   
  RELATED_OID, 
  KIND
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.STM_SID
  ON @SCHEMA@.SAVED_TASK_MESSAGE_T
(   
  SCHEDULER_ID
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.STM_CTXID
  ON @SCHEMA@.SAVED_TASK_MESSAGE_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.PEOPLE_RESOURCE_REF_INSTANCE_T
(
 PRRIID CHAR(16) FOR BIT DATA NOT NULL ,
 PRRTID CHAR(16) FOR BIT DATA NOT NULL ,
 INSTANCE_OID CHAR(16) FOR BIT DATA NOT NULL ,
 PARAMETER_VALUES BLOB(3900K) ,
 CONTAINMENT_CONTEXT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (PRRIID)
) IN @DB_NAME@.INSTA76;

CREATE UNIQUE INDEX 
  @SCHEMA@.PEOPLE_RESOURCE_REF_INSTANCE_P
  ON @SCHEMA@.PEOPLE_RESOURCE_REF_INSTANCE_T
(   
  PRRIID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column PARAMETER_VALUES
CREATE AUX TABLE @SCHEMA@.AT213488
   IN @DB_NAME@.AS213488
 STORES @SCHEMA@.PEOPLE_RESOURCE_REF_INSTANCE_T COLUMN
 PARAMETER_VALUES;
-- auxiliary index for LOB column PARAMETER_VALUES
CREATE UNIQUE INDEX @SCHEMA@.AT213488I
  ON @SCHEMA@.AT213488
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.PRRI_INSTOID
  ON @SCHEMA@.PEOPLE_RESOURCE_REF_INSTANCE_T
(   
  INSTANCE_OID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.PRRI_ccID
  ON @SCHEMA@.PEOPLE_RESOURCE_REF_INSTANCE_T
(   
  CONTAINMENT_CONTEXT_ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.PEOPLE_RESOURCE_T
(
 PRID CHAR(16) FOR BIT DATA NOT NULL ,
 NAMESPACE VARCHAR(254) NOT NULL ,
 NAME VARCHAR(254) NOT NULL ,
 PARAMETERS BLOB(3900K) ,
 BINDING_TYPE INTEGER NOT NULL ,
 BINDING_OID CHAR(16) FOR BIT DATA ,
 BINDING_DETAILS BLOB(3900K) ,
 APPLICATION_NAME VARCHAR(220) ,
 LAST_MODIFICATION_TIME TIMESTAMP NOT NULL ,
 EAR_VERSION INTEGER NOT NULL ,
 SCHEMA_VERSION INTEGER NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (PRID)
) IN @DB_NAME@.INSTA77;

CREATE UNIQUE INDEX 
  @SCHEMA@.PEOPLE_RESOURCE_P
  ON @SCHEMA@.PEOPLE_RESOURCE_T
(   
  PRID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column PARAMETERS
CREATE AUX TABLE @SCHEMA@.AT213489
   IN @DB_NAME@.AS213489
   STORES @SCHEMA@.PEOPLE_RESOURCE_T COLUMN PARAMETERS;
-- auxiliary index for LOB column PARAMETERS
CREATE UNIQUE INDEX @SCHEMA@.AT213489I
  ON @SCHEMA@.AT213489
   USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column BINDING_DETAILS
CREATE AUX TABLE @SCHEMA@.AT21348A
   IN @DB_NAME@.AS21348A
   STORES @SCHEMA@.PEOPLE_RESOURCE_T COLUMN BINDING_DETAILS;
-- auxiliary index for LOB column BINDING_DETAILS
CREATE UNIQUE INDEX @SCHEMA@.AT21348AI
  ON @SCHEMA@.AT21348A
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.PR_BOID
  ON @SCHEMA@.PEOPLE_RESOURCE_T
(   
  BINDING_OID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.PR_APPNAME_NS_NAME
  ON @SCHEMA@.PEOPLE_RESOURCE_T
(   
  APPLICATION_NAME, 
  NAMESPACE, 
  NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.PEOPLE_QUERY_T
(
 PQID CHAR(16) FOR BIT DATA NOT NULL ,
 NAME VARCHAR(254) NOT NULL ,
 NAMESPACE VARCHAR(254) NOT NULL ,
 TYPE INTEGER NOT NULL ,
 QUERY_DEFINITION BLOB(3900K) ,
 APPLICATION_NAME VARCHAR(220) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (PQID)
) IN @DB_NAME@.INSTA78;

CREATE UNIQUE INDEX 
  @SCHEMA@.PEOPLE_QUERY_P
  ON @SCHEMA@.PEOPLE_QUERY_T
(   
  PQID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column QUERY_DEFINITION
CREATE AUX TABLE @SCHEMA@.AT21348B
   IN @DB_NAME@.AS21348B
   STORES @SCHEMA@.PEOPLE_QUERY_T COLUMN QUERY_DEFINITION;
-- auxiliary index for LOB column QUERY_DEFINITION
CREATE UNIQUE INDEX @SCHEMA@.AT21348BI
  ON @SCHEMA@.AT21348B
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.PQ_APPNAME
  ON @SCHEMA@.PEOPLE_QUERY_T
(   
  APPLICATION_NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.PEOPLE_RESOLUTION_RESULT_T
(
 PRRID CHAR(16) FOR BIT DATA NOT NULL ,
 RELATED_OID CHAR(16) FOR BIT DATA NOT NULL ,
 RELATED_TYPE INTEGER NOT NULL ,
 CONTEXT_DATA BLOB(1073741823) ,
 CONTEXT_DATA_IL VARCHAR(1000) FOR BIT DATA ,
 CONTEXT_HASH_CODE INTEGER ,
 PARENT_PRRID CHAR(16) FOR BIT DATA ,
 EXPIRATION_TIME TIMESTAMP ,
 QIID4_UG CHAR(16) FOR BIT DATA NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (PRRID)
) IN @DB_NAME@.INSTA79;

CREATE UNIQUE INDEX 
  @SCHEMA@.PEOPLE_RESOLUTION_RESULT_P
  ON @SCHEMA@.PEOPLE_RESOLUTION_RESULT_T
(   
  PRRID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column CONTEXT_DATA
CREATE AUX TABLE @SCHEMA@.AT21348C
   IN @DB_NAME@.AS21348C
   STORES @SCHEMA@.PEOPLE_RESOLUTION_RESULT_T COLUMN CONTEXT_DATA;
-- auxiliary index for LOB column CONTEXT_DATA
CREATE UNIQUE INDEX @SCHEMA@.AT21348CI
  ON @SCHEMA@.AT21348C
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.PRR_RE_HC
  ON @SCHEMA@.PEOPLE_RESOLUTION_RESULT_T
(   
  RELATED_OID, 
  CONTEXT_HASH_CODE
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.PRR_QIID4UG
  ON @SCHEMA@.PEOPLE_RESOLUTION_RESULT_T
(   
  QIID4_UG
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.WORK_BASKET_T
(
 WBID CHAR(16) FOR BIT DATA NOT NULL ,
 WSID_1 CHAR(16) FOR BIT DATA ,
 WSID_1_HC INTEGER ,
 WSID_2 CHAR(16) FOR BIT DATA ,
 WSID_2_HC INTEGER ,
 NAME VARCHAR(254) NOT NULL ,
 TYPE INTEGER NOT NULL ,
 OWNER VARCHAR(128) ,
 SUBSTITUTION_POLICY INTEGER NOT NULL ,
 JNDI_NAME_STAFF_PROVIDER VARCHAR(254) NOT NULL ,
 DEFAULT_QUERY_TABLE VARCHAR(32) ,
 CUSTOM_TEXT1 VARCHAR(254) ,
 CUSTOM_TEXT2 VARCHAR(254) ,
 CUSTOM_TEXT3 VARCHAR(254) ,
 CUSTOM_TEXT4 VARCHAR(254) ,
 CUSTOM_TEXT5 VARCHAR(254) ,
 CUSTOM_TEXT6 VARCHAR(254) ,
 CUSTOM_TEXT7 VARCHAR(254) ,
 CUSTOM_TEXT8 VARCHAR(254) ,
 EXTENDED_DATA BLOB(3900K) ,
 CREATION_TIME TIMESTAMP NOT NULL ,
 LAST_MODIFICATION_TIME TIMESTAMP NOT NULL ,
 CREATED_WITH_VERSION INTEGER NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (WBID)
) IN @DB_NAME@.INSTA71;

CREATE UNIQUE INDEX 
  @SCHEMA@.WORK_BASKET_P
  ON @SCHEMA@.WORK_BASKET_T
(   
  WBID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column EXTENDED_DATA
CREATE AUX TABLE @SCHEMA@.AT21348D
   IN @DB_NAME@.AS21348D
   STORES @SCHEMA@.WORK_BASKET_T COLUMN EXTENDED_DATA;
-- auxiliary index for LOB column EXTENDED_DATA
CREATE UNIQUE INDEX @SCHEMA@.AT21348DI
  ON @SCHEMA@.AT21348D
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.WBK_NAME
  ON @SCHEMA@.WORK_BASKET_T
(   
  NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WBK_TYPE
  ON @SCHEMA@.WORK_BASKET_T
(   
  TYPE
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WBK_WSID1
  ON @SCHEMA@.WORK_BASKET_T
(   
  WSID_1
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WBK_WSID2
  ON @SCHEMA@.WORK_BASKET_T
(   
  WSID_2
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.WORK_BASKET_LDESC_T
(
 WBID CHAR(16) FOR BIT DATA NOT NULL ,
 LOCALE VARCHAR(32) NOT NULL ,
 WSID_1 CHAR(16) FOR BIT DATA ,
 WSID_1_HC INTEGER ,
 WSID_2 CHAR(16) FOR BIT DATA ,
 WSID_2_HC INTEGER ,
 DISPLAY_NAME VARCHAR(64) ,
 DESCRIPTION VARCHAR(254) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (WBID, LOCALE)
) IN @DB_NAME@.INSTA72;

CREATE UNIQUE INDEX 
  @SCHEMA@.WORK_BASKET_LDESC_P
  ON @SCHEMA@.WORK_BASKET_LDESC_T
(   
  WBID, 
  LOCALE
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.WORK_BASKET_DIST_TARGET_T
(
 SOURCE_WBID CHAR(16) FOR BIT DATA NOT NULL ,
 TARGET_WBID CHAR(16) FOR BIT DATA NOT NULL ,
 WSID_1 CHAR(16) FOR BIT DATA ,
 WSID_1_HC INTEGER ,
 WSID_2 CHAR(16) FOR BIT DATA ,
 WSID_2_HC INTEGER ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (SOURCE_WBID, TARGET_WBID)
) IN @DB_NAME@.INSTA73;

CREATE UNIQUE INDEX 
  @SCHEMA@.WORK_BASKET_DIST_TARGET_P
  ON @SCHEMA@.WORK_BASKET_DIST_TARGET_T
(   
  SOURCE_WBID, 
  TARGET_WBID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.WBDT_TWB
  ON @SCHEMA@.WORK_BASKET_DIST_TARGET_T
(   
  TARGET_WBID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.BUSINESS_CATEGORY_T
(
 BCID CHAR(16) FOR BIT DATA NOT NULL ,
 PARENT_BCID CHAR(16) FOR BIT DATA ,
 WSID_1 CHAR(16) FOR BIT DATA ,
 WSID_1_HC INTEGER ,
 WSID_2 CHAR(16) FOR BIT DATA ,
 WSID_2_HC INTEGER ,
 NAME VARCHAR(254) NOT NULL ,
 PRIORITY INTEGER ,
 SUBSTITUTION_POLICY INTEGER NOT NULL ,
 JNDI_NAME_STAFF_PROVIDER VARCHAR(254) NOT NULL ,
 DEFAULT_QUERY_TABLE VARCHAR(32) ,
 CUSTOM_TEXT1 VARCHAR(254) ,
 CUSTOM_TEXT2 VARCHAR(254) ,
 CUSTOM_TEXT3 VARCHAR(254) ,
 CUSTOM_TEXT4 VARCHAR(254) ,
 CUSTOM_TEXT5 VARCHAR(254) ,
 CUSTOM_TEXT6 VARCHAR(254) ,
 CUSTOM_TEXT7 VARCHAR(254) ,
 CUSTOM_TEXT8 VARCHAR(254) ,
 EXTENDED_DATA BLOB(3900K) ,
 CREATION_TIME TIMESTAMP NOT NULL ,
 LAST_MODIFICATION_TIME TIMESTAMP NOT NULL ,
 CREATED_WITH_VERSION INTEGER NOT NULL ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (BCID)
) IN @DB_NAME@.INSTA74;

CREATE UNIQUE INDEX 
  @SCHEMA@.BUSINESS_CATEGORY_P
  ON @SCHEMA@.BUSINESS_CATEGORY_T
(   
  BCID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column EXTENDED_DATA
CREATE AUX TABLE @SCHEMA@.AT21348E
   IN @DB_NAME@.AS21348E
   STORES @SCHEMA@.BUSINESS_CATEGORY_T COLUMN EXTENDED_DATA;
-- auxiliary index for LOB column EXTENDED_DATA
CREATE UNIQUE INDEX @SCHEMA@.AT21348EI
  ON @SCHEMA@.AT21348E
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.BCG_PARENTBCID
  ON @SCHEMA@.BUSINESS_CATEGORY_T
(   
  PARENT_BCID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.BCG_NAME
  ON @SCHEMA@.BUSINESS_CATEGORY_T
(   
  NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.BCG_WSID1
  ON @SCHEMA@.BUSINESS_CATEGORY_T
(   
  WSID_1
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.BCG_WSID2
  ON @SCHEMA@.BUSINESS_CATEGORY_T
(   
  WSID_2
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.BUSINESS_CATEGORY_LDESC_T
(
 BCID CHAR(16) FOR BIT DATA NOT NULL ,
 LOCALE VARCHAR(32) NOT NULL ,
 WSID_1 CHAR(16) FOR BIT DATA ,
 WSID_1_HC INTEGER ,
 WSID_2 CHAR(16) FOR BIT DATA ,
 WSID_2_HC INTEGER ,
 DISPLAY_NAME VARCHAR(64) ,
 DESCRIPTION VARCHAR(254) ,
 VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY (BCID, LOCALE)
) IN @DB_NAME@.INSTA75;

CREATE UNIQUE INDEX 
  @SCHEMA@.BUSINESS_CATEGORY_LDESC_P
  ON @SCHEMA@.BUSINESS_CATEGORY_LDESC_T
(   
  BCID, 
  LOCALE
) NOT PADDED
USING STOGROUP @STOGRP@;
-- set schema version to: 8500
INSERT INTO @SCHEMA@.SCHEMA_VERSION(SCHEMA_VERSION, DATA_MIGRATION)
 VALUES( 8500, 0 );


-- View: ProcessTemplate
CREATE VIEW @SCHEMA@.PROCESS_TEMPLATE(PTID, NAME, DISPLAY_NAME,
 VALID_FROM, TARGET_NAMESPACE, APPLICATION_NAME, VERSION, CREATED,
 STATE, EXECUTION_MODE, DESCRIPTION, CAN_RUN_SYNC, CAN_RUN_INTERRUP,
 COMP_SPHERE, CONTINUE_ON_ERROR, SNAPSHOT_ID, SNAPSHOT_NAME,
 TOP_LEVEL_TOOLKIT_ACRONYM, TOP_LEVEL_TOOLKIT_NAME, TRACK_NAME,
 PROCESS_APP_NAME, PROCESS_APP_ACRONYM, TOOLKIT_SNAPSHOT_ID,
 TOOLKIT_SNAPSHOT_NAME, TOOLKIT_NAME, TOOLKIT_ACRONYM, IS_TIP,
 CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3, CUSTOM_TEXT4, CUSTOM_TEXT5,
 CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8 ) AS
 SELECT @SCHEMA@.PROCESS_TEMPLATE_B_T.PTID,
 @SCHEMA@.PROCESS_TEMPLATE_B_T.NAME,
 @SCHEMA@.PROCESS_TEMPLATE_B_T.DISPLAY_NAME,
 @SCHEMA@.PROCESS_TEMPLATE_B_T.VALID_FROM,
 @SCHEMA@.PROCESS_TEMPLATE_B_T.TARGET_NAMESPACE,
 @SCHEMA@.PROCESS_TEMPLATE_B_T.APPLICATION_NAME,
 @SCHEMA@.PROCESS_TEMPLATE_B_T.VERSION,
 @SCHEMA@.PROCESS_TEMPLATE_B_T.CREATED,
 @SCHEMA@.PROCESS_TEMPLATE_B_T.STATE,
 @SCHEMA@.PROCESS_TEMPLATE_B_T.EXECUTION_MODE,
 @SCHEMA@.PROCESS_TEMPLATE_B_T.DESCRIPTION,
 @SCHEMA@.PROCESS_TEMPLATE_B_T.CAN_CALL,
 @SCHEMA@.PROCESS_TEMPLATE_B_T.CAN_INITIATE,
 @SCHEMA@.PROCESS_TEMPLATE_B_T.COMPENSATION_SPHERE,
 @SCHEMA@.PROCESS_TEMPLATE_B_T.CONTINUE_ON_ERROR,
 @SCHEMA@.PC_VERSION_TEMPLATE_T.SNAPSHOT_ID,
 @SCHEMA@.PC_VERSION_TEMPLATE_T.SNAPSHOT_NAME,
 @SCHEMA@.PC_VERSION_TEMPLATE_T.TOP_LEVEL_TOOLKIT_ACRONYM,
 @SCHEMA@.PC_VERSION_TEMPLATE_T.TOP_LEVEL_TOOLKIT_NAME,
 @SCHEMA@.PC_VERSION_TEMPLATE_T.TRACK_NAME,
 @SCHEMA@.PC_VERSION_TEMPLATE_T.PROCESS_APP_NAME,
 @SCHEMA@.PC_VERSION_TEMPLATE_T.PROCESS_APP_ACRONYM,
 @SCHEMA@.PC_VERSION_TEMPLATE_T.TOOLKIT_SNAPSHOT_ID,
 @SCHEMA@.PC_VERSION_TEMPLATE_T.TOOLKIT_SNAPSHOT_NAME,
 @SCHEMA@.PC_VERSION_TEMPLATE_T.TOOLKIT_NAME,
 @SCHEMA@.PC_VERSION_TEMPLATE_T.TOOLKIT_ACRONYM,
 @SCHEMA@.PC_VERSION_TEMPLATE_T.IS_TIP,
 @SCHEMA@.PROCESS_TEMPLATE_B_T.CUSTOM_TEXT1,
 @SCHEMA@.PROCESS_TEMPLATE_B_T.CUSTOM_TEXT2,
 @SCHEMA@.PROCESS_TEMPLATE_B_T.CUSTOM_TEXT3,
 @SCHEMA@.PROCESS_TEMPLATE_B_T.CUSTOM_TEXT4,
 @SCHEMA@.PROCESS_TEMPLATE_B_T.CUSTOM_TEXT5,
 @SCHEMA@.PROCESS_TEMPLATE_B_T.CUSTOM_TEXT6,
 @SCHEMA@.PROCESS_TEMPLATE_B_T.CUSTOM_TEXT7,
 @SCHEMA@.PROCESS_TEMPLATE_B_T.CUSTOM_TEXT8
 FROM @SCHEMA@.PROCESS_TEMPLATE_B_T LEFT JOIN
 @SCHEMA@.PC_VERSION_TEMPLATE_T ON
 (@SCHEMA@.PC_VERSION_TEMPLATE_T.CONTAINMENT_CONTEXT_ID =
 @SCHEMA@.PROCESS_TEMPLATE_B_T.PTID);

-- View: ProcessTemplAttr
CREATE VIEW @SCHEMA@.PROCESS_TEMPL_ATTR(PTID, NAME, VALUE ) AS
 SELECT @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T.PTID,
 @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T.ATTR_KEY,
 @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T.VALUE
 FROM @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T;

-- View: ProcessInstance
CREATE VIEW @SCHEMA@.PROCESS_INSTANCE(PTID, PIID, NAME, STATE,
 CREATED, STARTED, COMPLETED, PARENT_NAME, TOP_LEVEL_NAME,
 PARENT_PIID, TOP_LEVEL_PIID, STARTER, DESCRIPTION, TEMPLATE_NAME,
 TEMPLATE_DESCR, RESUMES, CONTINUE_ON_ERROR, IS_MIGRATED, WSID_1,
 WSID_2, CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3, CUSTOM_TEXT4,
 CUSTOM_TEXT5, CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8 ) AS
 SELECT @SCHEMA@.PROCESS_INSTANCE_B_T.PTID,
 @SCHEMA@.PROCESS_INSTANCE_B_T.PIID,
 @SCHEMA@.PROCESS_INSTANCE_B_T.NAME,
 @SCHEMA@.PROCESS_INSTANCE_B_T.STATE,
 @SCHEMA@.PROCESS_INSTANCE_B_T.CREATED,
 @SCHEMA@.PROCESS_INSTANCE_B_T.STARTED,
 @SCHEMA@.PROCESS_INSTANCE_B_T.COMPLETED,
 @SCHEMA@.PROCESS_INSTANCE_B_T.PARENT_NAME,
 @SCHEMA@.PROCESS_INSTANCE_B_T.TOP_LEVEL_NAME,
 @SCHEMA@.PROCESS_INSTANCE_B_T.PARENT_PIID,
 @SCHEMA@.PROCESS_INSTANCE_B_T.TOP_LEVEL_PIID,
 @SCHEMA@.PROCESS_INSTANCE_B_T.STARTER,
 @SCHEMA@.PROCESS_INSTANCE_B_T.DESCRIPTION,
 @SCHEMA@.PROCESS_TEMPLATE_B_T.NAME,
 @SCHEMA@.PROCESS_TEMPLATE_B_T.DESCRIPTION,
 @SCHEMA@.PROCESS_INSTANCE_B_T.RESUMES,
 @SCHEMA@.PROCESS_TEMPLATE_B_T.CONTINUE_ON_ERROR,
 @SCHEMA@.PROCESS_INSTANCE_B_T.IS_MIGRATED,
 @SCHEMA@.PROCESS_INSTANCE_B_T.WSID_1,
 @SCHEMA@.PROCESS_INSTANCE_B_T.WSID_2,
 @SCHEMA@.PROCESS_INSTANCE_B_T.CUSTOM_TEXT1,
 @SCHEMA@.PROCESS_INSTANCE_B_T.CUSTOM_TEXT2,
 @SCHEMA@.PROCESS_INSTANCE_B_T.CUSTOM_TEXT3,
 @SCHEMA@.PROCESS_INSTANCE_B_T.CUSTOM_TEXT4,
 @SCHEMA@.PROCESS_INSTANCE_B_T.CUSTOM_TEXT5,
 @SCHEMA@.PROCESS_INSTANCE_B_T.CUSTOM_TEXT6,
 @SCHEMA@.PROCESS_INSTANCE_B_T.CUSTOM_TEXT7,
 @SCHEMA@.PROCESS_INSTANCE_B_T.CUSTOM_TEXT8
 FROM @SCHEMA@.PROCESS_INSTANCE_B_T, @SCHEMA@.PROCESS_TEMPLATE_B_T
 WHERE @SCHEMA@.PROCESS_INSTANCE_B_T.PTID =
 @SCHEMA@.PROCESS_TEMPLATE_B_T.PTID;

-- View: ProcessAttribute
CREATE VIEW @SCHEMA@.PROCESS_ATTRIBUTE(PIID, NAME, VALUE, DATA_TYPE,
 WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.PIID,
 @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.ATTR_KEY,
 @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.VALUE,
 @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.DATA_TYPE,
 @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.WSID_1,
 @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.WSID_2
 FROM @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T;

-- View: Activity
CREATE VIEW @SCHEMA@.ACTIVITY(PIID, AIID, PTID, ATID, SIID, STID,
 EHIID, ENCLOSING_FEIID, KIND, COMPLETED, ACTIVATED, FIRST_ACTIVATED,
 STARTED, STATE, SUB_STATE, STOP_REASON, OWNER, DESCRIPTION, EXPIRES,
 TEMPLATE_NAME, TEMPLATE_DESCR, BUSINESS_RELEVANCE, SKIP_REQUESTED,
 CONTINUE_ON_ERROR, INVOKED_INST_ID, INVOKED_INST_TYPE,
 PREVIOUS_EXPIRATION_TIME, HAS_WORK_ITEM, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ACTIVITY_INSTANCE_B_T.PIID,
 @SCHEMA@.ACTIVITY_INSTANCE_B_T.AIID,
 @SCHEMA@.ACTIVITY_INSTANCE_B_T.PTID,
 @SCHEMA@.ACTIVITY_INSTANCE_B_T.ATID,
 @SCHEMA@.ACTIVITY_INSTANCE_B_T.SIID,
 @SCHEMA@.ACTIVITY_TEMPLATE_B_T.PARENT_STID,
 @SCHEMA@.ACTIVITY_INSTANCE_B_T.EHIID,
 @SCHEMA@.ACTIVITY_INSTANCE_B_T.ENCLOSING_FEIID,
 @SCHEMA@.ACTIVITY_TEMPLATE_B_T.KIND,
 @SCHEMA@.ACTIVITY_INSTANCE_B_T.FINISHED,
 @SCHEMA@.ACTIVITY_INSTANCE_B_T.ACTIVATED,
 @SCHEMA@.ACTIVITY_INSTANCE_B_T.FIRST_ACTIVATED,
 @SCHEMA@.ACTIVITY_INSTANCE_B_T.STARTED,
 @SCHEMA@.ACTIVITY_INSTANCE_B_T.STATE,
 @SCHEMA@.ACTIVITY_INSTANCE_B_T.SUB_STATE,
 @SCHEMA@.ACTIVITY_INSTANCE_B_T.STOP_REASON,
 @SCHEMA@.ACTIVITY_INSTANCE_B_T.OWNER,
 @SCHEMA@.ACTIVITY_INSTANCE_B_T.DESCRIPTION,
 @SCHEMA@.ACTIVITY_INSTANCE_B_T.EXPIRES,
 @SCHEMA@.ACTIVITY_TEMPLATE_B_T.NAME,
 @SCHEMA@.ACTIVITY_TEMPLATE_B_T.DESCRIPTION,
 @SCHEMA@.ACTIVITY_TEMPLATE_B_T.BUSINESS_RELEVANCE,
 @SCHEMA@.ACTIVITY_INSTANCE_B_T.SKIP_REQUESTED,
 @SCHEMA@.ACTIVITY_INSTANCE_B_T.CONTINUE_ON_ERROR,
 @SCHEMA@.ACTIVITY_INSTANCE_B_T.INVOKED_INSTANCE_ID,
 @SCHEMA@.ACTIVITY_INSTANCE_B_T.INVOKED_INSTANCE_TYPE,
 @SCHEMA@.ACTIVITY_INSTANCE_B_T.PREVIOUS_EXPIRATION_DATE,
 @SCHEMA@.ACTIVITY_INSTANCE_B_T.HAS_WORK_ITEM,
 @SCHEMA@.ACTIVITY_INSTANCE_B_T.WSID_1,
 @SCHEMA@.ACTIVITY_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.ACTIVITY_INSTANCE_B_T, @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 WHERE @SCHEMA@.ACTIVITY_INSTANCE_B_T.ATID =
 @SCHEMA@.ACTIVITY_TEMPLATE_B_T.ATID;

-- View: ActivityAttribute
CREATE VIEW @SCHEMA@.ACTIVITY_ATTRIBUTE(AIID, NAME, VALUE, DATA_TYPE,
 WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.AIID,
 @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.ATTR_KEY,
 @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.ATTR_VALUE,
 @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.DATA_TYPE,
 @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.WSID_1,
 @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.WSID_2
 FROM @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T;

-- View: Event
CREATE VIEW @SCHEMA@.EVENT(EIID, AIID, PIID, EHTID, SIID, NAME,
 WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.EVENT_INSTANCE_B_T.EIID,
 @SCHEMA@.EVENT_INSTANCE_B_T.AIID, @SCHEMA@.EVENT_INSTANCE_B_T.PIID,
 @SCHEMA@.EVENT_INSTANCE_B_T.EHTID, @SCHEMA@.EVENT_INSTANCE_B_T.SIID,
 @SCHEMA@.SERVICE_TEMPLATE_B_T.NAME,
 @SCHEMA@.EVENT_INSTANCE_B_T.WSID_1,
 @SCHEMA@.EVENT_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.EVENT_INSTANCE_B_T, @SCHEMA@.SERVICE_TEMPLATE_B_T
 WHERE @SCHEMA@.EVENT_INSTANCE_B_T.STATE = 2 AND
 @SCHEMA@.EVENT_INSTANCE_B_T.VTID =
 @SCHEMA@.SERVICE_TEMPLATE_B_T.VTID;

-- View: WorkItem
CREATE VIEW @SCHEMA@.WORK_ITEM(WIID, OWNER_ID, GROUP_NAME, EVERYBODY,
 OBJECT_TYPE, OBJECT_ID, ASSOC_OBJECT_TYPE, ASSOC_OID, REASON,
 CREATION_TIME, QIID, KIND ) AS
 SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.WORK_ITEM_T.OWNER_ID,
 @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY,
 @SCHEMA@.WORK_ITEM_T.OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.OBJECT_ID,
 @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE,
 @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WORK_ITEM_T.REASON,
 @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID,
 @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T
 WHERE @SCHEMA@.WORK_ITEM_T.AUTH_INFO IN (1,2,3)
 UNION ALL SELECT @SCHEMA@.WORK_ITEM_T.WIID,
 @SCHEMA@.RETRIEVED_USER_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME,
 @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WORK_ITEM_T.OBJECT_TYPE,
 @SCHEMA@.WORK_ITEM_T.OBJECT_ID,
 @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE,
 @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WORK_ITEM_T.REASON,
 @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID,
 @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T, @SCHEMA@.RETRIEVED_USER_T
 WHERE @SCHEMA@.WORK_ITEM_T.AUTH_INFO IN (0,6) AND
 @SCHEMA@.WORK_ITEM_T.QIID = @SCHEMA@.RETRIEVED_USER_T.QIID
 UNION ALL SELECT @SCHEMA@.WORK_ITEM_T.WIID,
 @SCHEMA@.WORK_ITEM_T.OWNER_ID, @SCHEMA@.RETRIEVED_GROUP_T.GROUP_NAME,
 @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WORK_ITEM_T.OBJECT_TYPE,
 @SCHEMA@.WORK_ITEM_T.OBJECT_ID,
 @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE,
 @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WORK_ITEM_T.REASON,
 @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID,
 @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T, @SCHEMA@.RETRIEVED_GROUP_T
 WHERE @SCHEMA@.WORK_ITEM_T.AUTH_INFO IN (4,6) AND
 @SCHEMA@.WORK_ITEM_T.QIID = @SCHEMA@.RETRIEVED_GROUP_T.QIID;

-- View: SharedWorkItem
CREATE VIEW @SCHEMA@.SHARED_WORK_ITEM(WSID, OWNER_ID, GROUP_NAME,
 EVERYBODY, REASON ) AS
 SELECT @SCHEMA@.SWI_T.WSID, @SCHEMA@.SWI_T.OWNER_ID,
 @SCHEMA@.SWI_T.GROUP_NAME, @SCHEMA@.SWI_T.EVERYBODY,
 @SCHEMA@.SWI_T.REASON
 FROM @SCHEMA@.SWI_T
 WHERE @SCHEMA@.SWI_T.AUTH_INFO IN ( 1,2,3 )
 UNION ALL SELECT @SCHEMA@.SWI_T.WSID,
 @SCHEMA@.RETRIEVED_USER_T.OWNER_ID, @SCHEMA@.SWI_T.GROUP_NAME,
 @SCHEMA@.SWI_T.EVERYBODY, @SCHEMA@.SWI_T.REASON
 FROM @SCHEMA@.SWI_T, @SCHEMA@.RETRIEVED_USER_T
 WHERE @SCHEMA@.SWI_T.QIID = @SCHEMA@.RETRIEVED_USER_T.QIID AND
 @SCHEMA@.SWI_T.AUTH_INFO IN (0,4)
 UNION ALL SELECT @SCHEMA@.SWI_T.WSID, @SCHEMA@.SWI_T.OWNER_ID,
 @SCHEMA@.RETRIEVED_GROUP_T.GROUP_NAME, @SCHEMA@.SWI_T.EVERYBODY,
 @SCHEMA@.SWI_T.REASON
 FROM @SCHEMA@.SWI_T, @SCHEMA@.RETRIEVED_GROUP_T
 WHERE @SCHEMA@.SWI_T.QIID = @SCHEMA@.RETRIEVED_GROUP_T.QIID AND
 @SCHEMA@.SWI_T.AUTH_INFO IN (4,6);

-- View: ActivityService
CREATE VIEW @SCHEMA@.ACTIVITY_SERVICE(EIID, AIID, PIID, VTID,
 PORT_TYPE, NAME_SPACE_URI, OPERATION, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.EVENT_INSTANCE_B_T.EIID,
 @SCHEMA@.EVENT_INSTANCE_B_T.AIID, @SCHEMA@.EVENT_INSTANCE_B_T.PIID,
 @SCHEMA@.EVENT_INSTANCE_B_T.VTID,
 @SCHEMA@.SERVICE_TEMPLATE_B_T.PORT_TYPE_NAME,
 @SCHEMA@.URI_TEMPLATE_B_T.URI,
 @SCHEMA@.SERVICE_TEMPLATE_B_T.OPERATION_NAME,
 @SCHEMA@.EVENT_INSTANCE_B_T.WSID_1,
 @SCHEMA@.EVENT_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.EVENT_INSTANCE_B_T, @SCHEMA@.SERVICE_TEMPLATE_B_T,
 @SCHEMA@.URI_TEMPLATE_B_T
 WHERE @SCHEMA@.EVENT_INSTANCE_B_T.STATE = 2 AND
 @SCHEMA@.EVENT_INSTANCE_B_T.VTID = @SCHEMA@.SERVICE_TEMPLATE_B_T.VTID
 AND @SCHEMA@.SERVICE_TEMPLATE_B_T.PORT_TYPE_UTID =
 @SCHEMA@.URI_TEMPLATE_B_T.UTID;

-- View: QueryProperty
CREATE VIEW @SCHEMA@.QUERY_PROPERTY(PIID, VARIABLE_NAME, NAME,
 NAMESPACE, GENERIC_VALUE, STRING_VALUE, NUMBER_VALUE, DECIMAL_VALUE,
 TIMESTAMP_VALUE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.PIID,
 @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.VARIABLE_NAME,
 @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.PROPERTY_NAME,
 @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.PROPERTY_NAMESPACE,
 @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.GENERIC_VALUE,
 @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.STRING_VALUE,
 @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.NUMBER_VALUE,
 @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.DECIMAL_VALUE,
 @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.TIMESTAMP_VALUE,
 @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.WSID_1,
 @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.WSID_2
 FROM @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T;

-- View: QueryPropTempl
CREATE VIEW @SCHEMA@.QUERY_PROP_TEMPL(PTID, NAME, PROPERTY_NAME, URI,
 QUERY_TYPE, JAVA_TYPE ) AS
 SELECT @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.PTID,
 @SCHEMA@.VARIABLE_TEMPLATE_B_T.NAME,
 @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.PROPERTY_NAME,
 @SCHEMA@.URI_TEMPLATE_B_T.URI,
 @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.QUERY_TYPE,
 @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.JAVA_TYPE
 FROM @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T,
 @SCHEMA@.VARIABLE_TEMPLATE_B_T, @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T,
 @SCHEMA@.URI_TEMPLATE_B_T
 WHERE @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.CTID =
 @SCHEMA@.VARIABLE_TEMPLATE_B_T.CTID AND
 @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.PAID =
 @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.PAID AND
 @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.PROPERTY_UTID =
 @SCHEMA@.URI_TEMPLATE_B_T.UTID;

-- View: MigrationFront
CREATE VIEW @SCHEMA@.MIGRATION_FRONT(PIID, AIID, SOURCE_PTID,
 TARGET_PTID, STATE, SUB_STATE, STOP_REASON, SOURCE_ATID, TARGET_ATID,
 MIGRATION_TIME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.MIGRATION_FRONT_T.PIID,
 @SCHEMA@.MIGRATION_FRONT_T.AIID,
 @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T.SOURCE_PTID,
 @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T.TARGET_PTID,
 @SCHEMA@.MIGRATION_FRONT_T.STATE,
 @SCHEMA@.MIGRATION_FRONT_T.SUB_STATE,
 @SCHEMA@.MIGRATION_FRONT_T.STOP_REASON,
 @SCHEMA@.MIGRATION_FRONT_T.SOURCE_ATID,
 @SCHEMA@.MIGRATION_FRONT_T.TARGET_ATID,
 @SCHEMA@.MIGRATION_FRONT_T.MIGRATION_TIME,
 @SCHEMA@.MIGRATION_FRONT_T.WSID_1, @SCHEMA@.MIGRATION_FRONT_T.WSID_2
 FROM @SCHEMA@.MIGRATION_FRONT_T, @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
 WHERE @SCHEMA@.MIGRATION_FRONT_T.MPTID =
 @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T.MPTID;

-- View: AuditLog
CREATE VIEW @SCHEMA@.AUDIT_LOG(ALID, EVENT_TIME, EVENT_TIME_UTC,
 AUDIT_EVENT, PTID, PIID, AIID, SIID, SCOPE_NAME, PROCESS_TEMPL_NAME,
 PROCESS_INST_NAME, TOP_LEVEL_PI_NAME, TOP_LEVEL_PIID, PARENT_PI_NAME,
 PARENT_PIID, VALID_FROM, VALID_FROM_UTC, ACTIVITY_NAME,
 ACTIVITY_KIND, ACTIVITY_STATE, CONTROL_LINK_NAME, IMPL_NAME,
 PRINCIPAL, TERMINAL_NAME, VARIABLE_DATA, EXCEPTION_TEXT, DESCRIPTION,
 CORR_SET_INFO, USER_NAME, ATID, ADDITIONAL_INFO, OBJECT_META_TYPE )
 AS
 SELECT @SCHEMA@.AUDIT_LOG_T.ALID, @SCHEMA@.AUDIT_LOG_T.EVENT_TIME,
 @SCHEMA@.AUDIT_LOG_T.EVENT_TIME_UTC,
 @SCHEMA@.AUDIT_LOG_T.AUDIT_EVENT, @SCHEMA@.AUDIT_LOG_T.PTID,
 @SCHEMA@.AUDIT_LOG_T.PIID, @SCHEMA@.AUDIT_LOG_T.AIID,
 @SCHEMA@.AUDIT_LOG_T.SIID, @SCHEMA@.AUDIT_LOG_T.VARIABLE_NAME,
 @SCHEMA@.AUDIT_LOG_T.PROCESS_TEMPL_NAME,
 @SCHEMA@.AUDIT_LOG_T.PROCESS_INST_NAME,
 @SCHEMA@.AUDIT_LOG_T.TOP_LEVEL_PI_NAME,
 @SCHEMA@.AUDIT_LOG_T.TOP_LEVEL_PIID,
 @SCHEMA@.AUDIT_LOG_T.PARENT_PI_NAME,
 @SCHEMA@.AUDIT_LOG_T.PARENT_PIID, @SCHEMA@.AUDIT_LOG_T.VALID_FROM,
 @SCHEMA@.AUDIT_LOG_T.VALID_FROM_UTC,
 @SCHEMA@.AUDIT_LOG_T.ACTIVITY_NAME,
 @SCHEMA@.AUDIT_LOG_T.ACTIVITY_KIND,
 @SCHEMA@.AUDIT_LOG_T.ACTIVITY_STATE,
 @SCHEMA@.AUDIT_LOG_T.CONTROL_LINK_NAME,
 @SCHEMA@.AUDIT_LOG_T.IMPL_NAME, @SCHEMA@.AUDIT_LOG_T.PRINCIPAL,
 @SCHEMA@.AUDIT_LOG_T.IMPL_NAME, @SCHEMA@.AUDIT_LOG_T.VARIABLE_DATA,
 @SCHEMA@.AUDIT_LOG_T.EXCEPTION_TEXT,
 @SCHEMA@.AUDIT_LOG_T.DESCRIPTION, @SCHEMA@.AUDIT_LOG_T.CORR_SET_INFO,
 @SCHEMA@.AUDIT_LOG_T.USER_NAME, @SCHEMA@.AUDIT_LOG_T.ATID,
 @SCHEMA@.AUDIT_LOG_T.ADDITIONAL_INFO,
 @SCHEMA@.AUDIT_LOG_T.OBJECT_META_TYPE
 FROM @SCHEMA@.AUDIT_LOG_T;

-- View: AuditLogB
CREATE VIEW @SCHEMA@.AUDIT_LOG_B(ALID, EVENT_TIME, EVENT_TIME_UTC,
 AUDIT_EVENT, PTID, PIID, AIID, SIID, VARIABLE_NAME,
 PROCESS_TEMPL_NAME, TOP_LEVEL_PIID, PARENT_PIID, VALID_FROM,
 VALID_FROM_UTC, ATID, ACTIVITY_NAME, ACTIVITY_KIND, ACTIVITY_STATE,
 CONTROL_LINK_NAME, PRINCIPAL, VARIABLE_DATA, EXCEPTION_TEXT,
 DESCRIPTION, CORR_SET_INFO, USER_NAME, ADDITIONAL_INFO, SNAPSHOT_ID,
 SNAPSHOT_NAME, PROCESS_APP_ACRONYM ) AS
 SELECT @SCHEMA@.AUDIT_LOG_T.ALID, @SCHEMA@.AUDIT_LOG_T.EVENT_TIME,
 @SCHEMA@.AUDIT_LOG_T.EVENT_TIME_UTC,
 @SCHEMA@.AUDIT_LOG_T.AUDIT_EVENT, @SCHEMA@.AUDIT_LOG_T.PTID,
 @SCHEMA@.AUDIT_LOG_T.PIID, @SCHEMA@.AUDIT_LOG_T.AIID,
 @SCHEMA@.AUDIT_LOG_T.SIID, @SCHEMA@.AUDIT_LOG_T.VARIABLE_NAME,
 @SCHEMA@.AUDIT_LOG_T.PROCESS_TEMPL_NAME,
 @SCHEMA@.AUDIT_LOG_T.TOP_LEVEL_PIID,
 @SCHEMA@.AUDIT_LOG_T.PARENT_PIID, @SCHEMA@.AUDIT_LOG_T.VALID_FROM,
 @SCHEMA@.AUDIT_LOG_T.VALID_FROM_UTC, @SCHEMA@.AUDIT_LOG_T.ATID,
 @SCHEMA@.AUDIT_LOG_T.ACTIVITY_NAME,
 @SCHEMA@.AUDIT_LOG_T.ACTIVITY_KIND,
 @SCHEMA@.AUDIT_LOG_T.ACTIVITY_STATE,
 @SCHEMA@.AUDIT_LOG_T.CONTROL_LINK_NAME,
 @SCHEMA@.AUDIT_LOG_T.PRINCIPAL, @SCHEMA@.AUDIT_LOG_T.VARIABLE_DATA,
 @SCHEMA@.AUDIT_LOG_T.EXCEPTION_TEXT,
 @SCHEMA@.AUDIT_LOG_T.DESCRIPTION, @SCHEMA@.AUDIT_LOG_T.CORR_SET_INFO,
 @SCHEMA@.AUDIT_LOG_T.USER_NAME, @SCHEMA@.AUDIT_LOG_T.ADDITIONAL_INFO,
 @SCHEMA@.AUDIT_LOG_T.SNAPSHOT_ID, @SCHEMA@.AUDIT_LOG_T.TERMINAL_NAME,
 @SCHEMA@.AUDIT_LOG_T.PROCESS_APP_ACRONYM
 FROM @SCHEMA@.AUDIT_LOG_T
 WHERE @SCHEMA@.AUDIT_LOG_T.OBJECT_META_TYPE = 1;

-- View: ApplicationComp
CREATE VIEW @SCHEMA@.APPLICATION_COMP(ACOID, BUSINESS_RELEVANCE,
 NAME, SUPPORT_AUTOCLAIM, SUPPORT_CLAIM_SUSP, SUPPORT_DELEGATION,
 SUPPORT_SUB_TASK, SUPPORT_FOLLOW_ON ) AS
 SELECT @SCHEMA@.APPLICATION_COMPONENT_T.ACOID,
 @SCHEMA@.APPLICATION_COMPONENT_T.BUSINESS_RELEVANCE,
 @SCHEMA@.APPLICATION_COMPONENT_T.NAME,
 @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_AUTO_CLAIM,
 @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_CLAIM_SUSPENDED,
 @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_DELEGATION,
 @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_SUB_TASK,
 @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_FOLLOW_ON_TASK
 FROM @SCHEMA@.APPLICATION_COMPONENT_T;

-- View: Task
CREATE VIEW @SCHEMA@.TASK(TKIID, ACTIVATED, APPLIC_DEFAULTS_ID,
 APPLIC_NAME, BUSINESS_RELEVANCE, COMPLETED, CONTAINMENT_CTX_ID,
 CTX_AUTHORIZATION, DUE, EXPIRES, FIRST_ACTIVATED, FOLLOW_ON_TKIID,
 IS_AD_HOC, IS_ESCALATED, IS_INLINE, IS_WAIT_FOR_SUB_TK, KIND,
 LAST_MODIFIED, LAST_STATE_CHANGE, NAME, NAME_SPACE, ORIGINATOR,
 OWNER, PARENT_CONTEXT_ID, PRIORITY, STARTED, STARTER, STATE,
 SUPPORT_AUTOCLAIM, SUPPORT_CLAIM_SUSP, SUPPORT_DELEGATION,
 SUPPORT_SUB_TASK, SUPPORT_FOLLOW_ON, HIERARCHY_POSITION, IS_CHILD,
 SUSPENDED, TKTID, TOP_TKIID, TYPE, RESUMES, ASSIGNMENT_TYPE,
 INHERITED_AUTH, INVOKED_INSTANCE_ID, INVOKED_INSTANCE_TYPE,
 WORK_BASKET, IS_READ, IS_TRANSFERRED_TO_WORK_BASKET, WSID_1, WSID_2,
 CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3, CUSTOM_TEXT4, CUSTOM_TEXT5,
 CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8 ) AS
 SELECT @SCHEMA@.TASK_INSTANCE_T.TKIID,
 @SCHEMA@.TASK_INSTANCE_T.ACTIVATION_TIME,
 @SCHEMA@.TASK_INSTANCE_T.APPLICATION_DEFAULTS_ID,
 @SCHEMA@.TASK_INSTANCE_T.APPLICATION_NAME,
 @SCHEMA@.TASK_INSTANCE_T.BUSINESS_RELEVANCE,
 @SCHEMA@.TASK_INSTANCE_T.COMPLETION_TIME,
 @SCHEMA@.TASK_INSTANCE_T.CONTAINMENT_CONTEXT_ID,
 @SCHEMA@.TASK_INSTANCE_T.CONTEXT_AUTHORIZATION,
 @SCHEMA@.TASK_INSTANCE_T.DUE_TIME,
 @SCHEMA@.TASK_INSTANCE_T.EXPIRATION_TIME,
 @SCHEMA@.TASK_INSTANCE_T.FIRST_ACTIVATION_TIME,
 @SCHEMA@.TASK_INSTANCE_T.FOLLOW_ON_TKIID,
 @SCHEMA@.TASK_INSTANCE_T.IS_AD_HOC,
 @SCHEMA@.TASK_INSTANCE_T.IS_ESCALATED,
 @SCHEMA@.TASK_INSTANCE_T.IS_INLINE,
 @SCHEMA@.TASK_INSTANCE_T.IS_WAITING_FOR_SUBTASK,
 @SCHEMA@.TASK_INSTANCE_T.KIND,
 @SCHEMA@.TASK_INSTANCE_T.LAST_MODIFICATION_TIME,
 @SCHEMA@.TASK_INSTANCE_T.LAST_STATE_CHANGE_TIME,
 @SCHEMA@.TASK_INSTANCE_T.NAME, @SCHEMA@.TASK_INSTANCE_T.NAMESPACE,
 @SCHEMA@.TASK_INSTANCE_T.ORIGINATOR, @SCHEMA@.TASK_INSTANCE_T.OWNER,
 @SCHEMA@.TASK_INSTANCE_T.PARENT_CONTEXT_ID,
 @SCHEMA@.TASK_INSTANCE_T.PRIORITY,
 @SCHEMA@.TASK_INSTANCE_T.START_TIME,
 @SCHEMA@.TASK_INSTANCE_T.STARTER, @SCHEMA@.TASK_INSTANCE_T.STATE,
 @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_AUTO_CLAIM,
 @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_CLAIM_SUSPENDED,
 @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_DELEGATION,
 @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_SUB_TASK,
 @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_FOLLOW_ON_TASK,
 @SCHEMA@.TASK_INSTANCE_T.HIERARCHY_POSITION,
 @SCHEMA@.TASK_INSTANCE_T.IS_CHILD,
 @SCHEMA@.TASK_INSTANCE_T.IS_SUSPENDED,
 @SCHEMA@.TASK_INSTANCE_T.TKTID, @SCHEMA@.TASK_INSTANCE_T.TOP_TKIID,
 @SCHEMA@.TASK_INSTANCE_T.TYPE, @SCHEMA@.TASK_INSTANCE_T.RESUMES,
 @SCHEMA@.TASK_INSTANCE_T.ASSIGNMENT_TYPE,
 @SCHEMA@.TASK_INSTANCE_T.INHERITED_AUTH,
 @SCHEMA@.TASK_INSTANCE_T.INVOKED_INSTANCE_ID,
 @SCHEMA@.TASK_INSTANCE_T.INVOKED_INSTANCE_TYPE,
 @SCHEMA@.TASK_INSTANCE_T.WORK_BASKET,
 @SCHEMA@.TASK_INSTANCE_T.IS_READ,
 @SCHEMA@.TASK_INSTANCE_T.IS_TRANSFERRED_TO_WORK_BASKET,
 @SCHEMA@.TASK_INSTANCE_T.WSID_1, @SCHEMA@.TASK_INSTANCE_T.WSID_2,
 @SCHEMA@.TASK_INSTANCE_T.CUSTOM_TEXT1,
 @SCHEMA@.TASK_INSTANCE_T.CUSTOM_TEXT2,
 @SCHEMA@.TASK_INSTANCE_T.CUSTOM_TEXT3,
 @SCHEMA@.TASK_INSTANCE_T.CUSTOM_TEXT4,
 @SCHEMA@.TASK_INSTANCE_T.CUSTOM_TEXT5,
 @SCHEMA@.TASK_INSTANCE_T.CUSTOM_TEXT6,
 @SCHEMA@.TASK_INSTANCE_T.CUSTOM_TEXT7,
 @SCHEMA@.TASK_INSTANCE_T.CUSTOM_TEXT8
 FROM @SCHEMA@.TASK_INSTANCE_T;

-- View: TaskTempl
CREATE VIEW @SCHEMA@.TASK_TEMPL(TKTID, APPLIC_DEFAULTS_ID,
 APPLIC_NAME, BUSINESS_RELEVANCE, CONTAINMENT_CTX_ID,
 CTX_AUTHORIZATION, DEFINITION_NAME, DEFINITION_NS, IS_AD_HOC,
 IS_INLINE, KIND, NAME, NAMESPACE, PRIORITY, STATE, SUPPORT_AUTOCLAIM,
 SUPPORT_CLAIM_SUSP, SUPPORT_DELEGATION, SUPPORT_SUB_TASK,
 SUPPORT_FOLLOW_ON, TYPE, VALID_FROM, AUTONOMY, ASSIGNMENT_TYPE,
 INHERITED_AUTH, WORK_BASKET, SNAPSHOT_ID, SNAPSHOT_NAME,
 TOP_LEVEL_TOOLKIT_ACRONYM, TOP_LEVEL_TOOLKIT_NAME, TRACK_NAME,
 PROCESS_APP_NAME, PROCESS_APP_ACRONYM, TOOLKIT_SNAPSHOT_ID,
 TOOLKIT_SNAPSHOT_NAME, TOOLKIT_NAME, TOOLKIT_ACRONYM, IS_TIP,
 CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3, CUSTOM_TEXT4, CUSTOM_TEXT5,
 CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8 ) AS
 SELECT @SCHEMA@.TASK_TEMPLATE_T.TKTID,
 @SCHEMA@.TASK_TEMPLATE_T.APPLICATION_DEFAULTS_ID,
 @SCHEMA@.TASK_TEMPLATE_T.APPLICATION_NAME,
 @SCHEMA@.TASK_TEMPLATE_T.BUSINESS_RELEVANCE,
 @SCHEMA@.TASK_TEMPLATE_T.CONTAINMENT_CONTEXT_ID,
 @SCHEMA@.TASK_TEMPLATE_T.CONTEXT_AUTHORIZATION,
 @SCHEMA@.TASK_TEMPLATE_T.DEFINITION_NAME,
 @SCHEMA@.TASK_TEMPLATE_T.TARGET_NAMESPACE,
 @SCHEMA@.TASK_TEMPLATE_T.IS_AD_HOC,
 @SCHEMA@.TASK_TEMPLATE_T.IS_INLINE, @SCHEMA@.TASK_TEMPLATE_T.KIND,
 @SCHEMA@.TASK_TEMPLATE_T.NAME, @SCHEMA@.TASK_TEMPLATE_T.NAMESPACE,
 @SCHEMA@.TASK_TEMPLATE_T.PRIORITY, @SCHEMA@.TASK_TEMPLATE_T.STATE,
 @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_AUTO_CLAIM,
 @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_CLAIM_SUSPENDED,
 @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_DELEGATION,
 @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_SUB_TASK,
 @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_FOLLOW_ON_TASK,
 @SCHEMA@.TASK_TEMPLATE_T.TYPE, @SCHEMA@.TASK_TEMPLATE_T.VALID_FROM,
 @SCHEMA@.TASK_TEMPLATE_T.AUTONOMY,
 @SCHEMA@.TASK_TEMPLATE_T.ASSIGNMENT_TYPE,
 @SCHEMA@.TASK_TEMPLATE_T.INHERITED_AUTH,
 @SCHEMA@.TASK_TEMPLATE_T.WORK_BASKET,
 @SCHEMA@.PC_VERSION_TEMPLATE_T.SNAPSHOT_ID,
 @SCHEMA@.PC_VERSION_TEMPLATE_T.SNAPSHOT_NAME,
 @SCHEMA@.PC_VERSION_TEMPLATE_T.TOP_LEVEL_TOOLKIT_ACRONYM,
 @SCHEMA@.PC_VERSION_TEMPLATE_T.TOP_LEVEL_TOOLKIT_NAME,
 @SCHEMA@.PC_VERSION_TEMPLATE_T.TRACK_NAME,
 @SCHEMA@.PC_VERSION_TEMPLATE_T.PROCESS_APP_NAME,
 @SCHEMA@.PC_VERSION_TEMPLATE_T.PROCESS_APP_ACRONYM,
 @SCHEMA@.PC_VERSION_TEMPLATE_T.TOOLKIT_SNAPSHOT_ID,
 @SCHEMA@.PC_VERSION_TEMPLATE_T.TOOLKIT_SNAPSHOT_NAME,
 @SCHEMA@.PC_VERSION_TEMPLATE_T.TOOLKIT_NAME,
 @SCHEMA@.PC_VERSION_TEMPLATE_T.TOOLKIT_ACRONYM,
 @SCHEMA@.PC_VERSION_TEMPLATE_T.IS_TIP,
 @SCHEMA@.TASK_TEMPLATE_T.CUSTOM_TEXT1,
 @SCHEMA@.TASK_TEMPLATE_T.CUSTOM_TEXT2,
 @SCHEMA@.TASK_TEMPLATE_T.CUSTOM_TEXT3,
 @SCHEMA@.TASK_TEMPLATE_T.CUSTOM_TEXT4,
 @SCHEMA@.TASK_TEMPLATE_T.CUSTOM_TEXT5,
 @SCHEMA@.TASK_TEMPLATE_T.CUSTOM_TEXT6,
 @SCHEMA@.TASK_TEMPLATE_T.CUSTOM_TEXT7,
 @SCHEMA@.TASK_TEMPLATE_T.CUSTOM_TEXT8
 FROM @SCHEMA@.TASK_TEMPLATE_T LEFT JOIN
 @SCHEMA@.PC_VERSION_TEMPLATE_T ON
 (@SCHEMA@.PC_VERSION_TEMPLATE_T.CONTAINMENT_CONTEXT_ID =
 @SCHEMA@.TASK_TEMPLATE_T.TKTID);

-- View: Escalation
CREATE VIEW @SCHEMA@.ESCALATION(ESIID, ACTION, ACTIVATION_STATE,
 ACTIVATION_TIME, ESCALATION_TIME, AT_LEAST_EXP_STATE, ESTID,
 FIRST_ESIID, INCREASE_PRIORITY, NAME, STATE, TKIID, WSID_1, WSID_2 )
 AS
 SELECT @SCHEMA@.ESCALATION_INSTANCE_T.ESIID,
 @SCHEMA@.ESCALATION_INSTANCE_T.ACTION,
 @SCHEMA@.ESCALATION_INSTANCE_T.ACTIVATION_STATE,
 @SCHEMA@.ESCALATION_INSTANCE_T.ACTIVATION_TIME,
 @SCHEMA@.ESCALATION_INSTANCE_T.ESCALATION_TIME,
 @SCHEMA@.ESCALATION_INSTANCE_T.AT_LEAST_EXPECTED_STATE,
 @SCHEMA@.ESCALATION_INSTANCE_T.ESTID,
 @SCHEMA@.ESCALATION_INSTANCE_T.FIRST_ESIID,
 @SCHEMA@.ESCALATION_INSTANCE_T.INCREASE_PRIORITY,
 @SCHEMA@.ESCALATION_INSTANCE_T.NAME,
 @SCHEMA@.ESCALATION_INSTANCE_T.STATE,
 @SCHEMA@.ESCALATION_INSTANCE_T.TKIID,
 @SCHEMA@.ESCALATION_INSTANCE_T.WSID_1,
 @SCHEMA@.ESCALATION_INSTANCE_T.WSID_2
 FROM @SCHEMA@.ESCALATION_INSTANCE_T;

-- View: EscTempl
CREATE VIEW @SCHEMA@.ESC_TEMPL(ESTID, FIRST_ESTID, PREVIOUS_ESTID,
 TKTID, CONTAINMENT_CTX_ID, NAME, ACTIVATION_STATE,
 AT_LEAST_EXP_STATE, INCREASE_PRIORITY, ACTION ) AS
 SELECT @SCHEMA@.ESCALATION_TEMPLATE_T.ESTID,
 @SCHEMA@.ESCALATION_TEMPLATE_T.FIRST_ESTID,
 @SCHEMA@.ESCALATION_TEMPLATE_T.PREVIOUS_ESTID,
 @SCHEMA@.ESCALATION_TEMPLATE_T.TKTID,
 @SCHEMA@.ESCALATION_TEMPLATE_T.CONTAINMENT_CONTEXT_ID,
 @SCHEMA@.ESCALATION_TEMPLATE_T.NAME,
 @SCHEMA@.ESCALATION_TEMPLATE_T.ACTIVATION_STATE,
 @SCHEMA@.ESCALATION_TEMPLATE_T.AT_LEAST_EXPECTED_STATE,
 @SCHEMA@.ESCALATION_TEMPLATE_T.INCREASE_PRIORITY,
 @SCHEMA@.ESCALATION_TEMPLATE_T.ACTION
 FROM @SCHEMA@.ESCALATION_TEMPLATE_T;

-- View: EscTemplDesc
CREATE VIEW @SCHEMA@.ESC_TEMPL_DESC(ESTID, LOCALE, TKTID,
 DISPLAY_NAME, DESCRIPTION ) AS
 SELECT @SCHEMA@.ESC_TEMPL_LDESC_T.ESTID,
 @SCHEMA@.ESC_TEMPL_LDESC_T.LOCALE, @SCHEMA@.ESC_TEMPL_LDESC_T.TKTID,
 @SCHEMA@.ESC_TEMPL_LDESC_T.DISPLAY_NAME,
 @SCHEMA@.ESC_TEMPL_LDESC_T.DESCRIPTION
 FROM @SCHEMA@.ESC_TEMPL_LDESC_T;

-- View: TaskTemplCProp
CREATE VIEW @SCHEMA@.TASK_TEMPL_CPROP(TKTID, NAME, DATA_TYPE,
 STRING_VALUE ) AS
 SELECT @SCHEMA@.TASK_TEMPL_CPROP_T.TKTID,
 @SCHEMA@.TASK_TEMPL_CPROP_T.NAME,
 @SCHEMA@.TASK_TEMPL_CPROP_T.DATA_TYPE,
 @SCHEMA@.TASK_TEMPL_CPROP_T.STRING_VALUE
 FROM @SCHEMA@.TASK_TEMPL_CPROP_T;

-- View: EscTemplCProp
CREATE VIEW @SCHEMA@.ESC_TEMPL_CPROP(ESTID, NAME, TKTID, DATA_TYPE,
 VALUE ) AS
 SELECT @SCHEMA@.ESC_TEMPL_CPROP_T.ESTID,
 @SCHEMA@.ESC_TEMPL_CPROP_T.NAME, @SCHEMA@.ESC_TEMPL_CPROP_T.TKTID,
 @SCHEMA@.ESC_TEMPL_CPROP_T.DATA_TYPE,
 @SCHEMA@.ESC_TEMPL_CPROP_T.STRING_VALUE
 FROM @SCHEMA@.ESC_TEMPL_CPROP_T;

-- View: TaskTemplDesc
CREATE VIEW @SCHEMA@.TASK_TEMPL_DESC(TKTID, LOCALE, DESCRIPTION,
 DISPLAY_NAME ) AS
 SELECT @SCHEMA@.TASK_TEMPL_LDESC_T.TKTID,
 @SCHEMA@.TASK_TEMPL_LDESC_T.LOCALE,
 @SCHEMA@.TASK_TEMPL_LDESC_T.DESCRIPTION,
 @SCHEMA@.TASK_TEMPL_LDESC_T.DISPLAY_NAME
 FROM @SCHEMA@.TASK_TEMPL_LDESC_T;

-- View: TaskCProp
CREATE VIEW @SCHEMA@.TASK_CPROP(TKIID, NAME, DATA_TYPE, STRING_VALUE,
 WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_INST_CPROP_T.TKIID,
 @SCHEMA@.TASK_INST_CPROP_T.NAME,
 @SCHEMA@.TASK_INST_CPROP_T.DATA_TYPE,
 @SCHEMA@.TASK_INST_CPROP_T.STRING_VALUE,
 @SCHEMA@.TASK_INST_CPROP_T.WSID_1, @SCHEMA@.TASK_INST_CPROP_T.WSID_2
 FROM @SCHEMA@.TASK_INST_CPROP_T;

-- View: TaskDesc
CREATE VIEW @SCHEMA@.TASK_DESC(TKIID, LOCALE, DESCRIPTION,
 DISPLAY_NAME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_INST_LDESC_T.TKIID,
 @SCHEMA@.TASK_INST_LDESC_T.LOCALE,
 @SCHEMA@.TASK_INST_LDESC_T.DESCRIPTION,
 @SCHEMA@.TASK_INST_LDESC_T.DISPLAY_NAME,
 @SCHEMA@.TASK_INST_LDESC_T.WSID_1, @SCHEMA@.TASK_INST_LDESC_T.WSID_2
 FROM @SCHEMA@.TASK_INST_LDESC_T;

-- View: EscalationCProp
CREATE VIEW @SCHEMA@.ESCALATION_CPROP(ESIID, NAME, DATA_TYPE,
 STRING_VALUE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ESC_INST_CPROP_T.ESIID,
 @SCHEMA@.ESC_INST_CPROP_T.NAME, @SCHEMA@.ESC_INST_CPROP_T.DATA_TYPE,
 @SCHEMA@.ESC_INST_CPROP_T.STRING_VALUE,
 @SCHEMA@.ESC_INST_CPROP_T.WSID_1, @SCHEMA@.ESC_INST_CPROP_T.WSID_2
 FROM @SCHEMA@.ESC_INST_CPROP_T;

-- View: TaskHistory
CREATE VIEW @SCHEMA@.TASK_HISTORY(TKIID, ESIID, PARENT_TKIID, EVENT,
 REASON, EVENT_TIME, NEXT_TIME, PRINCIPAL, WORK_ITEM_KIND, FROM_ID,
 TO_ID, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_HISTORY_T.TKIID, @SCHEMA@.TASK_HISTORY_T.ESIID,
 @SCHEMA@.TASK_HISTORY_T.PARENT_TKIID, @SCHEMA@.TASK_HISTORY_T.EVENT,
 @SCHEMA@.TASK_HISTORY_T.REASON, @SCHEMA@.TASK_HISTORY_T.EVENT_TIME,
 @SCHEMA@.TASK_HISTORY_T.NEXT_TIME, @SCHEMA@.TASK_HISTORY_T.PRINCIPAL,
 @SCHEMA@.TASK_HISTORY_T.WORK_ITEM_KIND,
 @SCHEMA@.TASK_HISTORY_T.FROM_ID, @SCHEMA@.TASK_HISTORY_T.TO_ID,
 @SCHEMA@.TASK_HISTORY_T.WSID_1, @SCHEMA@.TASK_HISTORY_T.WSID_2
 FROM @SCHEMA@.TASK_HISTORY_T;

-- View: EscalationDesc
CREATE VIEW @SCHEMA@.ESCALATION_DESC(ESIID, LOCALE, DESCRIPTION,
 DISPLAY_NAME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ESC_INST_LDESC_T.ESIID,
 @SCHEMA@.ESC_INST_LDESC_T.LOCALE,
 @SCHEMA@.ESC_INST_LDESC_T.DESCRIPTION,
 @SCHEMA@.ESC_INST_LDESC_T.DISPLAY_NAME,
 @SCHEMA@.ESC_INST_LDESC_T.WSID_1, @SCHEMA@.ESC_INST_LDESC_T.WSID_2
 FROM @SCHEMA@.ESC_INST_LDESC_T;

-- View: TaskAuditLog
CREATE VIEW @SCHEMA@.TASK_AUDIT_LOG(ALID, AUDIT_EVENT,
 CONTAINMENT_CTX_ID, ESIID, ESTID, EVENT_TIME, FAULT_NAME,
 FAULT_TYPE_NAME, FAULT_NAME_SPACE, FOLLOW_ON_TKIID, NAME, NAMESPACE,
 NEW_USER, OLD_USER, PARENT_CONTEXT_ID, PARENT_TASK_NAME,
 PARENT_TASK_NAMESP, PARENT_TKIID, PRINCIPAL, TASK_KIND, TASK_STATE,
 TKIID, TKTID, TOP_TKIID, VAILD_FROM, WORK_ITEM_REASON, USERS,
 DESCRIPTION, MESSAGE_DATA, SNAPSHOT_ID, SNAPSHOT_NAME,
 PROCESS_APP_ACRONYM ) AS
 SELECT @SCHEMA@.TASK_AUDIT_LOG_T.ALID,
 @SCHEMA@.TASK_AUDIT_LOG_T.AUDIT_EVENT,
 @SCHEMA@.TASK_AUDIT_LOG_T.CONTAINMENT_CONTEXT_ID,
 @SCHEMA@.TASK_AUDIT_LOG_T.ESIID, @SCHEMA@.TASK_AUDIT_LOG_T.ESTID,
 @SCHEMA@.TASK_AUDIT_LOG_T.EVENT_TIME_UTC,
 @SCHEMA@.TASK_AUDIT_LOG_T.FAULT_NAME,
 @SCHEMA@.TASK_AUDIT_LOG_T.FAULT_TYPE_NAME,
 @SCHEMA@.TASK_AUDIT_LOG_T.FAULT_NAMESPACE,
 @SCHEMA@.TASK_AUDIT_LOG_T.FOLLOW_ON_TKIID,
 @SCHEMA@.TASK_AUDIT_LOG_T.NAME, @SCHEMA@.TASK_AUDIT_LOG_T.NAMESPACE,
 @SCHEMA@.TASK_AUDIT_LOG_T.NEW_USER,
 @SCHEMA@.TASK_AUDIT_LOG_T.OLD_USER,
 @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_CONTEXT_ID,
 @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_TASK_NAME,
 @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_TASK_NAMESPACE,
 @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_TKIID,
 @SCHEMA@.TASK_AUDIT_LOG_T.PRINCIPAL,
 @SCHEMA@.TASK_AUDIT_LOG_T.TASK_KIND,
 @SCHEMA@.TASK_AUDIT_LOG_T.TASK_STATE,
 @SCHEMA@.TASK_AUDIT_LOG_T.TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.TKTID,
 @SCHEMA@.TASK_AUDIT_LOG_T.TOP_TKIID,
 @SCHEMA@.TASK_AUDIT_LOG_T.VALID_FROM_UTC,
 @SCHEMA@.TASK_AUDIT_LOG_T.WI_REASON, @SCHEMA@.TASK_AUDIT_LOG_T.USERS,
 @SCHEMA@.TASK_AUDIT_LOG_T.DESCRIPTION,
 @SCHEMA@.TASK_AUDIT_LOG_T.MESSAGE_DATA,
 @SCHEMA@.TASK_AUDIT_LOG_T.SNAPSHOT_ID,
 @SCHEMA@.TASK_AUDIT_LOG_T.SNAPSHOT_NAME,
 @SCHEMA@.TASK_AUDIT_LOG_T.PROCESS_APP_ACRONYM
 FROM @SCHEMA@.TASK_AUDIT_LOG_T;

-- View: WorkBasket
CREATE VIEW @SCHEMA@.WORK_BASKET(WBID, NAME, TYPE, OWNER,
 DEFAULT_QUERY_TABLE, CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3,
 CUSTOM_TEXT4, CUSTOM_TEXT5, CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8,
 CREATED, LAST_MODIFIED, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.WORK_BASKET_T.WBID, @SCHEMA@.WORK_BASKET_T.NAME,
 @SCHEMA@.WORK_BASKET_T.TYPE, @SCHEMA@.WORK_BASKET_T.OWNER,
 @SCHEMA@.WORK_BASKET_T.DEFAULT_QUERY_TABLE,
 @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT1,
 @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT2,
 @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT3,
 @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT4,
 @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT5,
 @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT6,
 @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT7,
 @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT8,
 @SCHEMA@.WORK_BASKET_T.CREATION_TIME,
 @SCHEMA@.WORK_BASKET_T.LAST_MODIFICATION_TIME,
 @SCHEMA@.WORK_BASKET_T.WSID_1, @SCHEMA@.WORK_BASKET_T.WSID_2
 FROM @SCHEMA@.WORK_BASKET_T;

-- View: WorkBasketLDesc
CREATE VIEW @SCHEMA@.WORK_BASKET_LDESC(WBID, LOCALE, DISPLAY_NAME,
 DESCRIPTION, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.WORK_BASKET_LDESC_T.WBID,
 @SCHEMA@.WORK_BASKET_LDESC_T.LOCALE,
 @SCHEMA@.WORK_BASKET_LDESC_T.DISPLAY_NAME,
 @SCHEMA@.WORK_BASKET_LDESC_T.DESCRIPTION,
 @SCHEMA@.WORK_BASKET_LDESC_T.WSID_1,
 @SCHEMA@.WORK_BASKET_LDESC_T.WSID_2
 FROM @SCHEMA@.WORK_BASKET_LDESC_T;

-- View: WorkBasketDistTarget
CREATE VIEW @SCHEMA@.WORK_BASKET_DIST_TARGET(WBID, NAME, TYPE, OWNER,
 DEFAULT_QUERY_TABLE, CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3,
 CUSTOM_TEXT4, CUSTOM_TEXT5, CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8,
 CREATED, LAST_MODIFIED, SOURCE_WBID, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.WORK_BASKET_DIST_TARGET_T.TARGET_WBID,
 @SCHEMA@.WORK_BASKET_T.NAME, @SCHEMA@.WORK_BASKET_T.TYPE,
 @SCHEMA@.WORK_BASKET_T.OWNER,
 @SCHEMA@.WORK_BASKET_T.DEFAULT_QUERY_TABLE,
 @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT1,
 @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT2,
 @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT3,
 @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT4,
 @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT5,
 @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT6,
 @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT7,
 @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT8,
 @SCHEMA@.WORK_BASKET_T.CREATION_TIME,
 @SCHEMA@.WORK_BASKET_T.LAST_MODIFICATION_TIME,
 @SCHEMA@.WORK_BASKET_DIST_TARGET_T.SOURCE_WBID,
 @SCHEMA@.WORK_BASKET_T.WSID_1, @SCHEMA@.WORK_BASKET_T.WSID_2
 FROM @SCHEMA@.WORK_BASKET_DIST_TARGET_T, @SCHEMA@.WORK_BASKET_T
 WHERE @SCHEMA@.WORK_BASKET_T.WBID =
 @SCHEMA@.WORK_BASKET_DIST_TARGET_T.TARGET_WBID;

-- View: BusinessCategory
CREATE VIEW @SCHEMA@.BUSINESS_CATEGORY(BCID, PARENT_BCID, NAME,
 PRIORITY, DEFAULT_QUERY_TABLE, CUSTOM_TEXT1, CUSTOM_TEXT2,
 CUSTOM_TEXT3, CUSTOM_TEXT4, CUSTOM_TEXT5, CUSTOM_TEXT6, CUSTOM_TEXT7,
 CUSTOM_TEXT8, CREATED, LAST_MODIFIED, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.BUSINESS_CATEGORY_T.BCID,
 @SCHEMA@.BUSINESS_CATEGORY_T.PARENT_BCID,
 @SCHEMA@.BUSINESS_CATEGORY_T.NAME,
 @SCHEMA@.BUSINESS_CATEGORY_T.PRIORITY,
 @SCHEMA@.BUSINESS_CATEGORY_T.DEFAULT_QUERY_TABLE,
 @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT1,
 @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT2,
 @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT3,
 @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT4,
 @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT5,
 @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT6,
 @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT7,
 @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT8,
 @SCHEMA@.BUSINESS_CATEGORY_T.CREATION_TIME,
 @SCHEMA@.BUSINESS_CATEGORY_T.LAST_MODIFICATION_TIME,
 @SCHEMA@.BUSINESS_CATEGORY_T.WSID_1,
 @SCHEMA@.BUSINESS_CATEGORY_T.WSID_2
 FROM @SCHEMA@.BUSINESS_CATEGORY_T;

-- View: BusinessCategoryLDesc
CREATE VIEW @SCHEMA@.BUSINESS_CATEGORY_LDESC(BCID, LOCALE,
 DISPLAY_NAME, DESCRIPTION, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.BCID,
 @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.LOCALE,
 @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.DISPLAY_NAME,
 @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.DESCRIPTION,
 @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.WSID_1,
 @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.WSID_2
 FROM @SCHEMA@.BUSINESS_CATEGORY_LDESC_T;


-- start import scheduler DDL: createSchemaDB2ZOS.ddl


CREATE TABLE @SCHEMA@.SCHED_TASK
(
      TASKID           NUMERIC(19)    NOT NULL , 
      VERSION          VARCHAR(5)     NOT NULL , 
      ROW_VERSION      INTEGER        NOT NULL , 
      TASKTYPE         INTEGER        NOT NULL , 
      TASKSUSPENDED    SMALLINT       NOT NULL , 
      CANCELLED        SMALLINT       NOT NULL , 
      NEXTFIRETIME     NUMERIC(19)    NOT NULL , 
      STARTBYINTERVAL  VARCHAR(254)    , 
      STARTBYTIME      NUMERIC(19)     , 
      VALIDFROMTIME    NUMERIC(19)     , 
      VALIDTOTIME      NUMERIC(19)     , 
      REPEATINTERVAL   VARCHAR(254)    , 
      MAXREPEATS       INTEGER        NOT NULL , 
      REPEATSLEFT      INTEGER        NOT NULL , 
      TASKINFO         BLOB(102400)    , 
      NAME             VARCHAR(254)   NOT NULL ,
      AUTOPURGE        INTEGER        NOT NULL , 
      FAILUREACTION    INTEGER         , 
      MAXATTEMPTS      INTEGER         , 
      QOS              INTEGER         , 
      PARTITIONID      INTEGER         ,
      OWNERTOKEN       VARCHAR(200)   NOT NULL ,
      CREATETIME       NUMERIC(19)    NOT NULL , 
      ROW_ID           ROWID          NOT NULL GENERATED ALWAYS,
      PRIMARY KEY ( TASKID )
)
IN @DB_NAME@.SCHEDTS; 


CREATE UNIQUE INDEX @SCHEMA@.SCHED_TASKPK 
   ON @SCHEMA@.SCHED_TASK
( 
    TASKID
) 
USING STOGROUP @STOGRP@;
                

CREATE INDEX @SCHEMA@.SCHED_TASK_IDX1
  ON @SCHEMA@.SCHED_TASK
(
    TASKID,OWNERTOKEN
)
USING STOGROUP @STOGRP@;
 

CREATE INDEX @SCHEMA@.SCHED_TASK_IDX2
  ON @SCHEMA@.SCHED_TASK
(
    NEXTFIRETIME ASC, REPEATSLEFT, PARTITIONID
)
USING STOGROUP @STOGRP@;


CREATE AUX TABLE @SCHEMA@.SCHED_TASK1
   IN @DB_NAME@.SCHEDTS1
   STORES  @SCHEMA@.SCHED_TASK COLUMN TASKINFO;
CREATE UNIQUE INDEX @SCHEMA@.SCHED_TASK1I ON @SCHEMA@.SCHED_TASK1
   USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.SCHED_TREG
(
    REGKEY                       VARCHAR(254)         NOT NULL ,
    REGVALUE                     VARCHAR(254)         ,
    PRIMARY KEY ( REGKEY )
)
 IN @DB_NAME@.SCHEDTS; 

 -- unique index for primary key
CREATE UNIQUE INDEX @SCHEMA@.SCHED_TREGPK 
   ON @SCHEMA@.SCHED_TREG
( 
    REGKEY
) 
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.SCHED_LMGR
(
    LEASENAME                         VARCHAR(254) NOT NULL,
    LEASEOWNER                        VARCHAR(254) NOT NULL,
    LEASE_EXPIRE_TIME                 NUMERIC(19),
    DISABLED                          VARCHAR(5),
    PRIMARY KEY ( LEASENAME )
)
 IN @DB_NAME@.SCHEDTS; 


CREATE UNIQUE INDEX @SCHEMA@.SCHED_LMGR_IDX1 ON @SCHEMA@.SCHED_LMGR
(
    LEASENAME
)
USING STOGROUP @STOGRP@;


CREATE TABLE @SCHEMA@.SCHED_LMPR
(
    LEASENAME                         VARCHAR(254) NOT NULL,
    NAME                              VARCHAR(254) NOT NULL,
    VALUE                             VARCHAR(254) NOT NULL
)
 IN @DB_NAME@.SCHEDTS; 

CREATE INDEX @SCHEMA@.SCHED_LMPR_IDX1 ON @SCHEMA@.SCHED_LMPR
(
    LEASENAME
)
USING STOGROUP @STOGRP@;

-- end import scheduler DDL: createSchemaDB2ZOS.ddl

